@@ -1,11 +1,11 @@
 #!/usr/bin/env sh
 #
 # This little script rebuilds and runs the SimGrid archive in parallel, extracting a log
-# This is almost an internal script, but others may find this useful
+# This is almost a personal script, but others may find this useful
 #
-# Copyright (c) 2017-2021 The SimGrid Team. Licence: LGPL of WDFPL, as you want.
+# Copyright (c) 2017-2022 The SimGrid Team. Licence: LGPL of WDFPL, as you want.
 
-if [ ! -e Makefile ] ; then
+if [ ! -e Makefile ] && [ ! -e build.ninja ]; then
   if [ -e build/default/Makefile ] ; then
     cd build/default
   else
@@ -23,10 +23,16 @@ if [ -e ${install_path} ] && [ -d ${install_path} ] && [ -x ${install_path} ] &&
   target=install
 fi
 
+if [ -e build.ninja ] ; then
+  builder="ninja"
+else
+  builder="make"
+fi
+
 (
   echo "install_path: ${install_path}"
   echo "Target: ${target}"
   echo "Cores: ${ncores}"
-  (nice make -j${ncores} ${target} tests || make ${target} tests) && nice ctest -j${ncores} --output-on-failure ; date
+  (nice ${builder} -j${ncores} ${target} tests || make ${target} tests) && nice ctest -j${ncores} --output-on-failure ; date
 ) 2>&1 | tee BuildSimGrid.sh.log
 
