@@ -36,7 +36,7 @@ copyright = u'2002-2022, The SimGrid Team'
 author = u'The SimGrid Team'
 
 # The short X.Y version
-version = u'3.30'
+version = u'3.32'
 
 # -- General configuration ---------------------------------------------------
 
@@ -97,6 +97,8 @@ nitpick_ignore = [
   ('cpp:identifier', 'kernel::resource::Action::State'),
   ('cpp:identifier', 'kernel::resource::LinkImpl'),
   ('cpp:identifier', 'kernel::resource::NetworkAction'),
+  ('cpp:identifier', 'kernel::resource::SplitDuplexLinkImpl'),
+  ('cpp:identifier', 'kernel::resource::StandardLinkImpl'),
   ('cpp:identifier', 'kernel::routing'),
   ('cpp:identifier', 'kernel::routing::NetPoint'),
   ('cpp:identifier', 'ns3'),
@@ -107,6 +109,7 @@ nitpick_ignore = [
   ('cpp:identifier', 's4u_Barrier'),
   ('cpp:identifier', 's4u_Comm'),
   ('cpp:identifier', 's4u_ConditionVariable'),
+  ('cpp:identifier', 's4u_Disk'),
   ('cpp:identifier', 's4u_Exec'),
   ('cpp:identifier', 's4u_File'),
   ('cpp:identifier', 's4u_Host'),
