@@ -8,6 +8,7 @@
 /* ************************************************************************* */
 
 #include <simgrid/s4u.hpp>
+namespace sg4 = simgrid::s4u;
 
 XBT_LOG_NEW_DEFAULT_CATEGORY(s4u_app_masterworker, "Messages specific for this example");
 
@@ -19,15 +20,15 @@ static void master(std::vector<std::string> args)
   long tasks_count        = std::stol(args[1]);
   double compute_cost     = std::stod(args[2]);
   long communication_cost = std::stol(args[3]);
-  std::vector<simgrid::s4u::Mailbox*> workers;
+  std::vector<sg4::Mailbox*> workers;
   for (unsigned int i = 4; i < args.size(); i++)
-    workers.push_back(simgrid::s4u::Mailbox::by_name(args[i]));
+    workers.push_back(sg4::Mailbox::by_name(args[i]));
 
   XBT_INFO("Got %zu workers and %ld tasks to process", workers.size(), tasks_count);
 
   for (int i = 0; i < tasks_count; i++) { /* For each task to be executed: */
     /* - Select a worker in a round-robin way */
-    simgrid::s4u::Mailbox* mailbox = workers[i % workers.size()];
+    sg4::Mailbox* mailbox = workers[i % workers.size()];
 
     /* - Send the computation cost to that worker */
     XBT_INFO("Sending task %d of %ld to mailbox '%s'", i, tasks_count, mailbox->get_cname());
@@ -37,7 +38,7 @@ static void master(std::vector<std::string> args)
   XBT_INFO("All tasks have been dispatched. Request all workers to stop.");
   for (unsigned int i = 0; i < workers.size(); i++) {
     /* The workers stop when receiving a negative compute_cost */
-    simgrid::s4u::Mailbox* mailbox = workers[i % workers.size()];
+    sg4::Mailbox* mailbox = workers[i % workers.size()];
 
     mailbox->put(new double(-1.0), 0);
   }
@@ -49,8 +50,8 @@ static void worker(std::vector<std::string> args)
 {
   xbt_assert(args.size() == 1, "The worker expects no argument");
 
-  const simgrid::s4u::Host* my_host = simgrid::s4u::this_actor::get_host();
-  simgrid::s4u::Mailbox* mailbox   = simgrid::s4u::Mailbox::by_name(my_host->get_name());
+  const sg4::Host* my_host = sg4::this_actor::get_host();
+  sg4::Mailbox* mailbox    = sg4::Mailbox::by_name(my_host->get_name());
 
   double compute_cost;
   do {
@@ -58,7 +59,7 @@ static void worker(std::vector<std::string> args)
     compute_cost = *msg;
 
     if (compute_cost > 0) /* If compute_cost is valid, execute a computation of that cost */
-      simgrid::s4u::this_actor::execute(compute_cost);
+      sg4::this_actor::execute(compute_cost);
   } while (compute_cost > 0); /* Stop when receiving an invalid compute_cost */
 
   XBT_INFO("Exiting now.");
@@ -68,7 +69,7 @@ static void worker(std::vector<std::string> args)
 // main-begin
 int main(int argc, char* argv[])
 {
-  simgrid::s4u::Engine e(&argc, argv);
+  sg4::Engine e(&argc, argv);
   xbt_assert(argc > 2, "Usage: %s platform_file deployment_file\n", argv[0]);
 
   /* Register the functions representing the actors */
