@@ -8,27 +8,28 @@
 #include "simgrid/s4u/VirtualMachine.hpp"
 
 XBT_LOG_NEW_DEFAULT_CATEGORY(s4u_cloud_migration, "Messages specific for this example");
+namespace sg4 = simgrid::s4u;
 
-static void vm_migrate(simgrid::s4u::VirtualMachine* vm, simgrid::s4u::Host* dst_pm)
+static void vm_migrate(sg4::VirtualMachine* vm, sg4::Host* dst_pm)
 {
-  const simgrid::s4u::Host* src_pm = vm->get_pm();
-  double mig_sta             = simgrid::s4u::Engine::get_clock();
+  const sg4::Host* src_pm = vm->get_pm();
+  double mig_sta          = sg4::Engine::get_clock();
   sg_vm_migrate(vm, dst_pm);
-  double mig_end = simgrid::s4u::Engine::get_clock();
+  double mig_end = sg4::Engine::get_clock();
 
   XBT_INFO("%s migrated: %s->%s in %g s", vm->get_cname(), src_pm->get_cname(), dst_pm->get_cname(), mig_end - mig_sta);
 }
 
-static void vm_migrate_async(simgrid::s4u::VirtualMachine* vm, simgrid::s4u::Host* dst_pm)
+static void vm_migrate_async(sg4::VirtualMachine* vm, sg4::Host* dst_pm)
 {
-  simgrid::s4u::Actor::create("mig_wrk", simgrid::s4u::Host::current(), vm_migrate, vm, dst_pm);
+  sg4::Actor::create("mig_wrk", sg4::Host::current(), vm_migrate, vm, dst_pm);
 }
 
 static void master_main()
 {
-  simgrid::s4u::Host* pm0 = simgrid::s4u::Host::by_name("Fafard");
-  simgrid::s4u::Host* pm1 = simgrid::s4u::Host::by_name("Tremblay");
-  simgrid::s4u::Host* pm2 = simgrid::s4u::Host::by_name("Bourassa");
+  sg4::Host* pm0 = sg4::Host::by_name("Fafard");
+  sg4::Host* pm1 = sg4::Host::by_name("Tremblay");
+  sg4::Host* pm2 = sg4::Host::by_name("Bourassa");
 
   auto* vm0 = pm0->create_vm("VM0", 1);
   vm0->set_ramsize(1e9); // 1Gbytes
@@ -59,7 +60,7 @@ static void master_main()
   XBT_INFO("Test: Migrate two VMs at once from PM0 to PM1");
   vm_migrate_async(vm0, pm1);
   vm_migrate_async(vm1, pm1);
-  simgrid::s4u::this_actor::sleep_for(10000);
+  sg4::this_actor::sleep_for(10000);
 
   vm0->destroy();
   vm1->destroy();
@@ -75,7 +76,7 @@ static void master_main()
   XBT_INFO("Test: Migrate two VMs at once to different PMs");
   vm_migrate_async(vm0, pm1);
   vm_migrate_async(vm1, pm2);
-  simgrid::s4u::this_actor::sleep_for(10000);
+  sg4::this_actor::sleep_for(10000);
 
   vm0->destroy();
   vm1->destroy();
@@ -84,17 +85,17 @@ static void master_main()
 int main(int argc, char* argv[])
 {
   /* Get the arguments */
-  simgrid::s4u::Engine e(&argc, argv);
+  sg4::Engine e(&argc, argv);
   sg_vm_live_migration_plugin_init();
 
   /* load the platform file */
   e.load_platform(argv[1]);
 
-  simgrid::s4u::Actor::create("master_", simgrid::s4u::Host::by_name("Fafard"), master_main);
+  sg4::Actor::create("master_", sg4::Host::by_name("Fafard"), master_main);
 
   e.run();
 
-  XBT_INFO("Bye (simulation time %g)", simgrid::s4u::Engine::get_clock());
+  XBT_INFO("Bye (simulation time %g)", sg4::Engine::get_clock());
 
   return 0;
 }
