@@ -7,34 +7,34 @@
 #include <vector>
 
 XBT_LOG_NEW_DEFAULT_CATEGORY(s4u_test, "Messages specific for this s4u example");
+namespace sg4 = simgrid::s4u;
 
 static void worker()
 {
   // Define an amount of work that should take 1 second to execute.
-  double computation_amount = simgrid::s4u::this_actor::get_host()->get_speed();
+  double computation_amount = sg4::this_actor::get_host()->get_speed();
 
   // Create an unassigned activity and start it
-  simgrid::s4u::ExecPtr exec =
-      simgrid::s4u::Exec::init()->set_flops_amount(computation_amount)->set_name("exec")->vetoable_start();
+  sg4::ExecPtr exec = sg4::Exec::init()->set_flops_amount(computation_amount)->set_name("exec")->vetoable_start();
 
   // Wait for a while
-  simgrid::s4u::this_actor::sleep_for(10);
+  sg4::this_actor::sleep_for(10);
 
   // Assign the activity to the current host. This triggers its start, then waits for it completion.
-  exec->set_host(simgrid::s4u::Host::current())->wait();
+  exec->set_host(sg4::Host::current())->wait();
   XBT_INFO("Exec '%s' is complete", exec->get_cname());
 }
 
 int main(int argc, char* argv[])
 {
-  simgrid::s4u::Engine e(&argc, argv);
+  sg4::Engine e(&argc, argv);
   e.load_platform(argv[1]);
 
-  simgrid::s4u::Actor::create("worker", e.host_by_name("Fafard"), worker);
+  sg4::Actor::create("worker", e.host_by_name("Fafard"), worker);
 
   e.run();
 
-  XBT_INFO("Simulation time %g", simgrid::s4u::Engine::get_clock());
+  XBT_INFO("Simulation time %g", sg4::Engine::get_clock());
 
   return 0;
 }
