@@ -16,9 +16,8 @@
 
 #include <simgrid/s4u.hpp>
 
-namespace sg4 = simgrid::s4u;
-
 XBT_LOG_NEW_DEFAULT_CATEGORY(disk_test, "Messages specific for this simulation");
+namespace sg4 = simgrid::s4u;
 
 /** @brief Calculates the bandwidth for disk doing async operations */
 static void estimate_bw(const sg4::Disk* disk, int n_flows, bool read)
@@ -89,11 +88,9 @@ static double ssd_dynamic_sharing(const sg4::Disk* /*disk*/, const std::string&
                                                                             {15, 239.}}}};
 
   const auto& data = SSD_SPEED.at(op);
+  const auto value = data.find(n);
   /* no special bandwidth for this disk sharing N flows, just returns maximal capacity */
-  if (data.find(n) != data.end())
-    capacity = data.at(n);
-
-  return capacity;
+  return value == data.end() ? capacity : value->second;
 }
 
 /**
@@ -143,10 +140,10 @@ int main(int argc, char** argv)
   create_sata_disk(bob, "Griffon (SATA II)");
   zone->seal();
 
-  simgrid::s4u::Actor::create("", bob, host);
+  sg4::Actor::create("", bob, host);
 
   e.run();
-  XBT_INFO("Simulated time: %g", simgrid::s4u::Engine::get_clock());
+  XBT_INFO("Simulated time: %g", sg4::Engine::get_clock());
 
   return 0;
 }
