@@ -11,6 +11,8 @@
 #include "simgrid/instr.h"
 #include "simgrid/s4u.hpp"
 
+namespace sg4 = simgrid::s4u;
+
 static void trace_fun()
 {
   // set initial values for the link user variables this example only shows for links identified by "6" and "3" in the
@@ -25,7 +27,7 @@ static void trace_fun()
 
   // run the simulation, update my variables accordingly
   for (int i = 0; i < 10; i++) {
-    simgrid::s4u::this_actor::execute(1e6);
+    sg4::this_actor::execute(1e6);
 
     // Add to link user variables
     simgrid::instr::add_link_variable("3", "Link_Utilization", 5.6);
@@ -33,7 +35,7 @@ static void trace_fun()
   }
 
   for (int i = 0; i < 10; i++) {
-    simgrid::s4u::this_actor::execute(1e6);
+    sg4::this_actor::execute(1e6);
 
     // Subtract from link user variables
     simgrid::instr::sub_link_variable("3", "Link_Utilization", 3.4);
@@ -43,7 +45,7 @@ static void trace_fun()
 
 int main(int argc, char* argv[])
 {
-  simgrid::s4u::Engine e(&argc, argv);
+  sg4::Engine e(&argc, argv);
   xbt_assert(argc > 1, "Usage: %s platform_file\n \tExample: %s small_platform.xml\n", argv[0], argv[0]);
 
   e.load_platform(argv[1]);
@@ -52,12 +54,12 @@ int main(int argc, char* argv[])
   simgrid::instr::declare_link_variable("Link_Capacity");
   simgrid::instr::declare_link_variable("Link_Utilization", "0.9 0.1 0.1");
 
-  simgrid::s4u::Actor::create("master", e.host_by_name("Tremblay"), trace_fun);
-  simgrid::s4u::Actor::create("worker", e.host_by_name("Tremblay"), trace_fun);
-  simgrid::s4u::Actor::create("worker", e.host_by_name("Jupiter"), trace_fun);
-  simgrid::s4u::Actor::create("worker", e.host_by_name("Fafard"), trace_fun);
-  simgrid::s4u::Actor::create("worker", e.host_by_name("Ginette"), trace_fun);
-  simgrid::s4u::Actor::create("worker", e.host_by_name("Bourassa"), trace_fun);
+  sg4::Actor::create("master", e.host_by_name("Tremblay"), trace_fun);
+  sg4::Actor::create("worker", e.host_by_name("Tremblay"), trace_fun);
+  sg4::Actor::create("worker", e.host_by_name("Jupiter"), trace_fun);
+  sg4::Actor::create("worker", e.host_by_name("Fafard"), trace_fun);
+  sg4::Actor::create("worker", e.host_by_name("Ginette"), trace_fun);
+  sg4::Actor::create("worker", e.host_by_name("Bourassa"), trace_fun);
 
   e.run();
   return 0;
