@@ -115,6 +115,7 @@ using ActorCode = std::function<void()>;
 // Create an ActorCode from the parameters parsed in the XML file (or elsewhere)
 using ActorCodeFactory = std::function<ActorCode(std::vector<std::string> args)>;
 
+class Simcall;
 class SimcallObserver;
 } // namespace actor
 
@@ -125,6 +126,13 @@ namespace activity {
   XBT_PUBLIC void intrusive_ptr_add_ref(ActivityImpl* activity);
   XBT_PUBLIC void intrusive_ptr_release(ActivityImpl* activity);
 
+  class BarrierImpl;
+  using BarrierImplPtr = boost::intrusive_ptr<BarrierImpl>;
+  XBT_PUBLIC void intrusive_ptr_add_ref(BarrierImpl* cond);
+  XBT_PUBLIC void intrusive_ptr_release(BarrierImpl* cond);
+  class BarrierAcquisitionImpl;
+  using BarrierAcquisitionImplPtr = boost::intrusive_ptr<BarrierAcquisitionImpl>;
+
   class ConditionVariableImpl;
   using ConditionVariableImplPtr = boost::intrusive_ptr<ConditionVariableImpl>;
   XBT_PUBLIC void intrusive_ptr_add_ref(ConditionVariableImpl* cond);
@@ -138,12 +146,16 @@ namespace activity {
   using IoImplPtr = boost::intrusive_ptr<IoImpl>;
   class MutexImpl;
   using MutexImplPtr = boost::intrusive_ptr<MutexImpl>;
+  class MutexAcquisitionImpl;
+  using MutexAcquisitionImplPtr = boost::intrusive_ptr<MutexAcquisitionImpl>;
   XBT_PUBLIC void intrusive_ptr_add_ref(MutexImpl* mutex);
   XBT_PUBLIC void intrusive_ptr_release(MutexImpl* mutex);
-  class RawImpl;
-  using RawImplPtr = boost::intrusive_ptr<RawImpl>;
+  class SynchroImpl;
+  using SynchroImplPtr = boost::intrusive_ptr<SynchroImpl>;
   class SemaphoreImpl;
   using SemaphoreImplPtr = boost::intrusive_ptr<SemaphoreImpl>;
+  class SemAcquisitionImpl;
+  using SemAcquisitionImplPtr = boost::intrusive_ptr<SemAcquisitionImpl>;
   XBT_PUBLIC void intrusive_ptr_add_ref(SemaphoreImpl* sem);
   XBT_PUBLIC void intrusive_ptr_release(SemaphoreImpl* sem);
   class SleepImpl;
@@ -195,7 +207,7 @@ class Profile;
 } // namespace profile
 } // namespace kernel
 namespace mc {
-class CommunicationDeterminismChecker;
+class State;
 }
 } // namespace simgrid
 
@@ -214,13 +226,19 @@ using s4u_Disk              = simgrid::s4u::Disk;
 using s4u_NetZone           = simgrid::s4u::NetZone;
 using s4u_VM                = simgrid::s4u::VirtualMachine;
 
-using smx_timer_t    = simgrid::kernel::timer::Timer*;
-using smx_actor_t    = simgrid::kernel::actor::ActorImpl*;
+using smx_timer_t
+    XBT_ATTRIB_DEPRECATED_v335("Please use simgrid::kernel::timer::Timer*") = simgrid::kernel::timer::Timer*;
+using smx_actor_t
+    XBT_ATTRIB_DEPRECATED_v335("Please use simgrid::kernel::actor::ActorImpl*") = simgrid::kernel::actor::ActorImpl*;
 using smx_activity_t = simgrid::kernel::activity::ActivityImpl*;
-using smx_cond_t     = simgrid::kernel::activity::ConditionVariableImpl*;
-using smx_mailbox_t  = simgrid::kernel::activity::MailboxImpl*;
-using smx_mutex_t    = simgrid::kernel::activity::MutexImpl*;
-using smx_sem_t      = simgrid::kernel::activity::SemaphoreImpl*;
+using smx_cond_t XBT_ATTRIB_DEPRECATED_v335("Please use simgrid::kernel::activity::ConditionVariableImpl*") =
+    simgrid::kernel::activity::ConditionVariableImpl*;
+using smx_mailbox_t XBT_ATTRIB_DEPRECATED_v335("Please use simgrid::kernel::activity::MailboxImpl*") =
+    simgrid::kernel::activity::MailboxImpl*;
+using smx_mutex_t XBT_ATTRIB_DEPRECATED_v335("Please use simgrid::kernel::activity::MutexImpl*") =
+    simgrid::kernel::activity::MutexImpl*;
+using smx_sem_t XBT_ATTRIB_DEPRECATED_v335("Please use simgrid::kernel::activity::SemaphoreImpl*") =
+    simgrid::kernel::activity::SemaphoreImpl*;
 #else
 
 typedef struct s4u_Actor s4u_Actor;
@@ -238,22 +256,22 @@ typedef struct s4u_Disk s4u_Disk;
 typedef struct s4u_NetZone s4u_NetZone;
 typedef struct s4u_VM s4u_VM;
 
-typedef struct s_smx_timer* smx_timer_t;
-typedef struct s_smx_actor* smx_actor_t;
+XBT_ATTRIB_DEPRECATED_v335("Please stop using this type alias") typedef struct s_smx_timer* smx_timer_t;
+XBT_ATTRIB_DEPRECATED_v335("Please stop using this type alias") typedef struct s_smx_actor* smx_actor_t;
 typedef struct s_smx_activity* smx_activity_t;
-typedef struct s_smx_cond_t* smx_cond_t;
-typedef struct s_smx_mailbox* smx_mailbox_t;
-typedef struct s_smx_mutex* smx_mutex_t;
-typedef struct s_smx_sem* smx_sem_t;
+XBT_ATTRIB_DEPRECATED_v335("Please stop using this type alias") typedef struct s_smx_cond_t* smx_cond_t;
+XBT_ATTRIB_DEPRECATED_v335("Please stop using this type alias") typedef struct s_smx_mailbox* smx_mailbox_t;
+XBT_ATTRIB_DEPRECATED_v335("Please stop using this type alias") typedef struct s_smx_mutex* smx_mutex_t;
+XBT_ATTRIB_DEPRECATED_v335("Please stop using this type alias") typedef struct s_smx_sem* smx_sem_t;
 
 #endif
 
 /** Pointer to a SimGrid barrier object */
 typedef s4u_Barrier* sg_bar_t;
 /** Constant pointer to a SimGrid barrier object */
-typedef const s4u_Barrier* const_sg_bar_t;
+XBT_ATTRIB_DEPRECATED_v335("Please stop using this type alias") typedef const s4u_Barrier* const_sg_bar_t;
 typedef s4u_Comm* sg_comm_t;
-typedef const s4u_Comm* const_sg_comm_t;
+XBT_ATTRIB_DEPRECATED_v335("Please stop using this type alias") typedef const s4u_Comm* const_sg_comm_t;
 typedef s4u_Exec* sg_exec_t;
 typedef const s4u_Exec* const_sg_exec_t;
 typedef s4u_ConditionVariable* sg_cond_t;
@@ -283,8 +301,6 @@ typedef s4u_Actor* sg_actor_t;
 /** Pointer to a constant actor object */
 typedef const s4u_Actor* const_sg_actor_t;
 
-typedef struct s_smx_simcall* smx_simcall_t;
-
 /** @ingroup m_datatypes_management_details
  * @brief Type for any simgrid size
  */
@@ -308,4 +324,6 @@ typedef enum {
   SG_ERROR_VM
 } sg_error_t;
 
+XBT_PUBLIC int SMPI_is_inited();
+
 #endif /* SIMGRID_TYPES_H */
