@@ -6,7 +6,8 @@
 #ifndef INSTR_H_
 #define INSTR_H_
 
-#include <simgrid/msg.h>
+#include <simgrid/engine.h>
+#include <xbt/dynar.h> // XBT_ATTRIB_DEPRECATED_v334
 
 #ifdef __cplusplus
 #include <set>
@@ -64,6 +65,8 @@ XBT_PUBLIC const std::set<std::string, std::less<>>& get_tracing_categories();
 
 /* Function used by graphicator (transform a SimGrid platform file in a graphviz dot file with the network topology) */
 XBT_PUBLIC void platform_graph_export_graphviz(const std::string& output_filename);
+/* Function used by graphicator (transform a SimGrid platform file in a CSV file with the network topology) */
+XBT_PUBLIC void platform_graph_export_csv(const std::string& output_filename);
 } // namespace instr
 } // namespace simgrid
 
