@@ -52,9 +52,6 @@ class XBT_PRIVATE RoutedZone : public NetZoneImpl {
 public:
   explicit RoutedZone(const std::string& name);
 
-  void get_graph(const s_xbt_graph_t* graph, std::map<std::string, xbt_node_t, std::less<>>* nodes,
-                 std::map<std::string, xbt_edge_t, std::less<>>* edges) override;
-
 protected:
   Route* new_extended_route(RoutingMode hierarchy, NetPoint* gw_src, NetPoint* gw_dst,
                             const std::vector<resource::StandardLinkImpl*>& link_list, bool preserve_order);
@@ -66,9 +63,4 @@ protected:
 } // namespace kernel
 } // namespace simgrid
 
-XBT_PRIVATE xbt_node_t new_xbt_graph_node(const s_xbt_graph_t* graph, const char* name,
-                                          std::map<std::string, xbt_node_t, std::less<>>* nodes);
-XBT_PRIVATE xbt_edge_t new_xbt_graph_edge(const s_xbt_graph_t* graph, xbt_node_t s, xbt_node_t d,
-                                          std::map<std::string, xbt_edge_t, std::less<>>* edges);
-
 #endif /* SIMGRID_ROUTING_GENERIC_HPP_ */
