@@ -23,6 +23,7 @@ class XBT_PRIVATE WifiZone : public RoutedZone {
   NetPoint* access_point_        = nullptr; // Zone's gateway to the external world
 
   void do_seal() override;
+  resource::StandardLinkImpl* do_create_link(const std::string& name, const std::vector<double>& bandwidths) override;
 
 public:
   using RoutedZone::RoutedZone;
@@ -30,7 +31,6 @@ public:
   WifiZone& operator=(const WifiZone) = delete;
 
   void get_local_route(const NetPoint* src, const NetPoint* dst, Route* into, double* latency) override;
-  s4u::Link* create_link(const std::string& name, const std::vector<double>& bandwidths) override;
   NetPoint* get_access_point() const { return access_point_; }
 };
 } // namespace routing
