@@ -19,108 +19,73 @@ namespace s4u {
  * Represents all asynchronous communications, that you can test or wait onto.
  */
 class XBT_PUBLIC Comm : public Activity_T<Comm> {
+  friend Mailbox; // Factory of comms
+  /* specified for normal mailbox-based communications*/
   Mailbox* mailbox_                   = nullptr;
-  kernel::actor::ActorImpl* sender_   = nullptr; /* specified for normal mailbox-based communications*/
+  kernel::actor::ActorImpl* sender_   = nullptr;
   kernel::actor::ActorImpl* receiver_ = nullptr;
-  Host* from_                         = nullptr; /* specified only for direct host-to-host communications */
-  Host* to_                           = nullptr;
   double rate_                        = -1;
   void* dst_buff_                     = nullptr;
   size_t dst_buff_size_               = 0;
   void* src_buff_                     = nullptr;
   size_t src_buff_size_               = sizeof(void*);
+
   /* FIXME: expose these elements in the API */
   bool detached_                                                          = false;
-  bool (*match_fun_)(void*, void*, kernel::activity::CommImpl*)           = nullptr;
-  void (*clean_fun_)(void*)                                               = nullptr;
-  void (*copy_data_function_)(kernel::activity::CommImpl*, void*, size_t) = nullptr;
+  std::function<bool(void*, void*, kernel::activity::CommImpl*)> match_fun_;
+  std::function<void(void*)> clean_fun_;
+  std::function<void(kernel::activity::CommImpl*, void*, size_t)> copy_data_function_;
 
   Comm() = default;
 
 public:
-#ifndef DOXYGEN
-  friend Mailbox; // Factory of comms
-#endif
-
-  ~Comm() override;
-
-  /*! Creates a communication that bypasses the mailbox mechanism. */
-  static CommPtr sendto_init();
-  /*! Creates a communication beween the two given hosts, bypassing the mailbox mechanism. */
-  static CommPtr sendto_init(Host* from, Host* to);
-  /** Do an asynchronous communication between two arbitrary hosts.
-   *
-   * This initializes a communication that completely bypass the mailbox and actors mechanism.
-   * There is really no limit on the hosts involved. In particular, the actor does not have to be on one of the involved
-   * hosts.
-   */
-  static CommPtr sendto_async(Host* from, Host* to, uint64_t simulated_size_in_bytes);
-  /** Do a blocking communication between two arbitrary hosts.
-   *
-   * This starts a blocking communication right away, bypassing the mailbox and actors mechanism.
-   * The calling actor is blocked until the end of the communication; there is really no limit on the hosts involved.
-   * In particular, the actor does not have to be on one of the involved hosts. Enjoy the comfort of the simulator :)
-   */
-  static void sendto(Host* from, Host* to, uint64_t simulated_size_in_bytes);
-
-  static void on_send_cb(const std::function<void(Comm const&)>& cb) { on_send.connect(cb); }
-  static void on_recv_cb(const std::function<void(Comm const&)>& cb) { on_recv.connect(cb); }
-  static void on_start_cb(const std::function<void(Comm const&)>& cb) { on_start.connect(cb); }
-  static void on_completion_cb(const std::function<void(Activity const&)>& cb) { on_completion.connect(cb); }
+  /* signals and related callbacks */
 #ifndef DOXYGEN
   /* FIXME signals should be private */
   static xbt::signal<void(Comm const&)> on_send;
   static xbt::signal<void(Comm const&)> on_recv;
   static xbt::signal<void(Comm const&)> on_start;
-  static xbt::signal<void(Comm const&)> on_completion;
 #endif
 
-  /*! take a vector s4u::CommPtr and return when one of them is finished.
-   * The return value is the rank of the first finished CommPtr. */
-  static ssize_t wait_any(const std::vector<CommPtr>& comms) { return wait_any_for(comms, -1); }
-  /*! Same as wait_any, but with a timeout. Return -1 if the timeout occurs.*/
-  static ssize_t wait_any_for(const std::vector<CommPtr>& comms, double timeout);
+  static void on_send_cb(const std::function<void(Comm const&)>& cb) { on_send.connect(cb); }
+  static void on_recv_cb(const std::function<void(Comm const&)>& cb) { on_recv.connect(cb); }
+  static void on_start_cb(const std::function<void(Comm const&)>& cb) { on_start.connect(cb); }
+  /* More callbacks */
+  CommPtr set_copy_data_callback(const std::function<void(kernel::activity::CommImpl*, void*, size_t)>& callback);
+  static void copy_buffer_callback(kernel::activity::CommImpl*, void*, size_t);
+  static void copy_pointer_callback(kernel::activity::CommImpl*, void*, size_t);
 
-  /*! take a vector s4u::CommPtr and return when all of them is finished. */
-  static void wait_all(const std::vector<CommPtr>& comms);
-  /*! Same as wait_all, but with a timeout. Return the number of terminated comm (less than comms.size() if the timeout
-   * occurs). */
-  static size_t wait_all_for(const std::vector<CommPtr>& comms, double timeout);
-  /*! take a vector s4u::CommPtr and return the rank of the first finished one (or -1 if none is done). */
-  static ssize_t test_any(const std::vector<CommPtr>& comms);
+  ~Comm() override;
 
-#ifndef DOXYGEN
-  XBT_ATTRIB_DEPRECATED_v332("Please use a plain vector for parameter")
-  static int wait_any(const std::vector<CommPtr>* comms) { return static_cast<int>(wait_any_for(*comms, -1)); }
-  XBT_ATTRIB_DEPRECATED_v332("Please use a plain vector for first parameter")
-  static int wait_any_for(const std::vector<CommPtr>* comms, double timeout) { return static_cast<int>(wait_any_for(*comms, timeout)); }
-  XBT_ATTRIB_DEPRECATED_v332("Please use a plain vector for parameter")
-  static void wait_all(const std::vector<CommPtr>* comms) { wait_all(*comms); }
-  XBT_ATTRIB_DEPRECATED_v332("Please use a plain vector for parameter")
-  static int test_any(const std::vector<CommPtr>* comms) { return static_cast<int>(test_any(*comms)); }
-#endif
+  static void send(kernel::actor::ActorImpl* sender, const Mailbox* mbox, double task_size, double rate, void* src_buff,
+                   size_t src_buff_size,
+                   const std::function<bool(void*, void*, simgrid::kernel::activity::CommImpl*)>& match_fun,
+                   const std::function<void(simgrid::kernel::activity::CommImpl*, void*, size_t)>& copy_data_fun,
+                   void* data, double timeout);
+  static void recv(kernel::actor::ActorImpl* receiver, const Mailbox* mbox, void* dst_buff, size_t* dst_buff_size,
+                   const std::function<bool(void*, void*, simgrid::kernel::activity::CommImpl*)>& match_fun,
+                   const std::function<void(simgrid::kernel::activity::CommImpl*, void*, size_t)>& copy_data_fun,
+                   void* data, double timeout, double rate);
 
-  Comm* start() override;
-  Comm* wait_for(double timeout) override;
-  bool test() override;
+  /* "One-sided" communications. This way of communicating bypasses the mailbox and actors mechanism. It creates a
+   * communication (vetoabled, asynchronous, or synchronous) directly between two hosts. There is really no limit on
+   * the hosts involved. In particular, the actor creating such a communication does not have to be on one of the
+   * involved hosts! Enjoy the comfort of the simulator :)
+   */
+  static CommPtr sendto_init(); /* Source and Destination hosts have to be set before the communication can start */
+  static CommPtr sendto_init(Host* from, Host* to);
+  static CommPtr sendto_async(Host* from, Host* to, uint64_t simulated_size_in_bytes);
+  static void sendto(Host* from, Host* to, uint64_t simulated_size_in_bytes);
 
-  /** Start the comm, and ignore its result. It can be completely forgotten after that. */
-  Comm* detach();
-  /** Start the comm, and ignore its result. It can be completely forgotten after that. */
-  Comm* detach(void (*clean_function)(void*))
-  {
-    clean_fun_ = clean_function;
-    return detach();
-  }
-
-  /** Set the source and destination of communications that bypass the mailbox mechanism */
   CommPtr set_source(Host* from);
-  Host* get_source() const { return from_; }
+  Host* get_source() const;
   CommPtr set_destination(Host* to);
-  Host* get_destination() const { return to_; }
+  Host* get_destination() const;
 
-  /** Sets the maximal communication rate (in byte/sec). Must be done before start */
-  CommPtr set_rate(double rate);
+  /* Mailbox-based communications */
+  CommPtr set_mailbox(Mailbox* mailbox);
+  /** Retrieve the mailbox on which this comm acts */
+  Mailbox* get_mailbox() const { return mailbox_; }
 
   /** Specify the data to send.
    *
@@ -142,16 +107,6 @@ public:
    * @endrst
    */
   CommPtr set_src_data_size(size_t size);
-
-  /** Specify the amount of bytes which exchange should be simulated (not to be mixed with set_src_data_size())
-   *
-   * @beginrst
-   * That's the size of the simulated data, that's completely related from the actual data size (given by
-   * :cpp:func:`simgrid::s4u::Comm::set_src_data_size`).
-   * @endrst
-   */
-  CommPtr set_payload_size(uint64_t bytes);
-
   /** Specify the data to send and its size (not to be mixed with set_payload_size())
    *
    * @beginrst
@@ -172,20 +127,53 @@ public:
    * That's a buffer where the sent data will be copied  */
   CommPtr set_dst_data(void** buff, size_t size);
   /** Retrieve where the data will be copied on the receiver side */
-  void* get_dst_data();
-
-  /** Retrieve the mailbox on which this comm acts */
-  Mailbox* get_mailbox() const;
+  void* get_dst_data() const { return dst_buff_; }
   /** Retrieve the size of the received data. Not to be mixed with @ref Activity::set_remaining()  */
-  size_t get_dst_data_size() const;
+  size_t get_dst_data_size() const { return dst_buff_size_; }
 
+  /* Common functions */
+
+  /** Specify the amount of bytes which exchange should be simulated (not to be mixed with set_src_data_size())
+   *
+   * @beginrst
+   * That's the size of the simulated data, that's completely unrelated from the actual data size (given by
+   * :cpp:func:`simgrid::s4u::Comm::set_src_data_size`).
+   * @endrst
+   */
+  CommPtr set_payload_size(uint64_t bytes);
+  /** Sets the maximal communication rate (in byte/sec). Must be done before start */
+  CommPtr set_rate(double rate);
+
+  bool is_assigned() const override;
   Actor* get_sender() const;
 
-  bool is_assigned() const override { return (to_ != nullptr && from_ != nullptr) || (mailbox_ != nullptr); }
+  /* Comm life cycle */
+  Comm* start() override;
+  /** Start the comm, and ignore its result. It can be completely forgotten after that. */
+  Comm* detach();
+  /** Start the comm, and ignore its result. It can be completely forgotten after that. */
+  Comm* detach(const std::function<void(void*)>& clean_function)
+  {
+    clean_fun_ = clean_function;
+    return detach();
+  }
 
-  CommPtr set_copy_data_callback(void (*callback)(kernel::activity::CommImpl*, void*, size_t));
-  static void copy_buffer_callback(kernel::activity::CommImpl*, void*, size_t);
-  static void copy_pointer_callback(kernel::activity::CommImpl*, void*, size_t);
+  Comm* wait_for(double timeout) override;
+
+  /*! take a vector s4u::CommPtr and return the rank of the first finished one (or -1 if none is done). */
+  static ssize_t test_any(const std::vector<CommPtr>& comms);
+
+  /*! take a vector s4u::CommPtr and return when one of them is finished.
+   * The return value is the rank of the first finished CommPtr. */
+  static ssize_t wait_any(const std::vector<CommPtr>& comms) { return wait_any_for(comms, -1); }
+  /*! Same as wait_any, but with a timeout. Return -1 if the timeout occurs.*/
+  static ssize_t wait_any_for(const std::vector<CommPtr>& comms, double timeout);
+
+  /*! take a vector s4u::CommPtr and return when all of them is finished. */
+  static void wait_all(const std::vector<CommPtr>& comms);
+  /*! Same as wait_all, but with a timeout. Return the number of terminated comm (less than comms.size() if the timeout
+   * occurs). */
+  static size_t wait_all_for(const std::vector<CommPtr>& comms, double timeout);
 };
 } // namespace s4u
 } // namespace simgrid
