@@ -35,7 +35,7 @@ class XBT_PUBLIC VirtualMachine : public s4u::Host {
   kernel::resource::VirtualMachineImpl* const pimpl_vm_;
 
   /* Signals about the life cycle of the VM */
-  static xbt::signal<void(VirtualMachine&)> on_creation;
+  static xbt::signal<void(VirtualMachine&)> on_vm_creation;
   static xbt::signal<void(VirtualMachine const&)> on_start;
   static xbt::signal<void(VirtualMachine const&)> on_started;
   static xbt::signal<void(VirtualMachine const&)> on_shutdown;
@@ -43,10 +43,19 @@ class XBT_PUBLIC VirtualMachine : public s4u::Host {
   static xbt::signal<void(VirtualMachine const&)> on_resume;
   static xbt::signal<void(VirtualMachine const&)> on_migration_start;
   static xbt::signal<void(VirtualMachine const&)> on_migration_end;
-  static xbt::signal<void(VirtualMachine const&)> on_destruction;
+  static xbt::signal<void(VirtualMachine const&)> on_vm_destruction;
+
+#ifndef DOXYGEN
+  friend kernel::resource::VirtualMachineImpl; // calls signals from Impl
+  friend kernel::resource::HostImpl;           // call private constructor
+  explicit VirtualMachine(kernel::resource::VirtualMachineImpl* impl);
+#endif
 
 public:
-  explicit VirtualMachine(const std::string& name, Host* physical_host, int core_amount, size_t ramsize = 1024);
+  XBT_ATTRIB_DEPRECATED_v336("Please use s4u::Host::create_vm") explicit VirtualMachine(const std::string& name,
+                                                                                        Host* physical_host,
+                                                                                        int core_amount,
+                                                                                        size_t ramsize = 1024);
 
 #ifndef DOXYGEN
   // No copy/move
@@ -61,9 +70,6 @@ public:
     SUSPENDED, /**< Suspend/resume does not involve disk I/O, so we assume there is no transition states. */
     DESTROYED
   );
-#ifndef DOXYGEN
-  using state XBT_ATTRIB_DEPRECATED_v332("Please use VirtualMachine::State") = State;
-#endif
 
   kernel::resource::VirtualMachineImpl* get_vm_impl() const { return pimpl_vm_; }
   void start();
@@ -83,13 +89,13 @@ public:
   State get_state() const;
 
   /* Callbacks on signals */
-  static void on_creation_cb(const std::function<void(VirtualMachine&)>& cb) { on_creation.connect(cb); }
+  static void on_creation_cb(const std::function<void(VirtualMachine&)>& cb) { on_vm_creation.connect(cb); }
   static void on_start_cb(const std::function<void(VirtualMachine const&)>& cb) { on_start.connect(cb); }
   static void on_started_cb(const std::function<void(VirtualMachine const&)>& cb) { on_started.connect(cb); }
   static void on_shutdown_cb(const std::function<void(VirtualMachine const&)>& cb) { on_shutdown.connect(cb); }
   static void on_suspend_cb(const std::function<void(VirtualMachine const&)>& cb) { on_suspend.connect(cb); }
   static void on_resume_cb(const std::function<void(VirtualMachine const&)>& cb) { on_resume.connect(cb); }
-  static void on_destruction_cb(const std::function<void(VirtualMachine const&)>& cb) { on_destruction.connect(cb); }
+  static void on_destruction_cb(const std::function<void(VirtualMachine const&)>& cb) { on_vm_destruction.connect(cb); }
   static void on_migration_start_cb(const std::function<void(VirtualMachine const&)>& cb)
   {
     on_migration_start.connect(cb);
