@@ -15,9 +15,7 @@
 
 #include "jmsg.hpp"
 
-namespace simgrid {
-namespace kernel {
-namespace context {
+namespace simgrid::kernel::context {
 
 class JavaContext;
 class JavacontextFactory;
@@ -33,7 +31,7 @@ public:
   JavaContext(std::function<void()>&& code, actor::ActorImpl* actor);
 
   void start_hook() override;
-  void stop_hook() override;
+  void stop() override;
 };
 
 class JavaContextFactory : public ContextFactory {
@@ -41,14 +39,12 @@ public:
   JavaContextFactory();
   ~JavaContextFactory() override;
   Context* create_context(std::function<void()>&& code, actor::ActorImpl* actor) override;
-  void run_all() override;
+  void run_all(std::vector<actor::ActorImpl*> const& actors) override;
 };
 
 XBT_PRIVATE ContextFactory* java_factory();
 XBT_PRIVATE void java_main_jprocess(jobject process);
 
-} // namespace context
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::context
 
 #endif /* SIMGRID_JAVA_JAVA_CONTEXT_HPP */
