@@ -24,9 +24,9 @@
 
 #include "simgrid/kernel/ProfileBuilder.hpp"
 #include "simgrid/kernel/routing/NetPoint.hpp"
-#include "src/kernel/context/Context.hpp"
 #include <simgrid/Exception.hpp>
 #include <simgrid/s4u/Actor.hpp>
+#include <simgrid/s4u/Barrier.hpp>
 #include <simgrid/s4u/Comm.hpp>
 #include <simgrid/s4u/Disk.hpp>
 #include <simgrid/s4u/Engine.hpp>
@@ -34,7 +34,9 @@
 #include <simgrid/s4u/Host.hpp>
 #include <simgrid/s4u/Link.hpp>
 #include <simgrid/s4u/Mailbox.hpp>
+#include <simgrid/s4u/Mutex.hpp>
 #include <simgrid/s4u/NetZone.hpp>
+#include <simgrid/s4u/Semaphore.hpp>
 #include <simgrid/version.h>
 
 #include <algorithm>
@@ -45,10 +47,18 @@
 namespace py = pybind11;
 using simgrid::s4u::Actor;
 using simgrid::s4u::ActorPtr;
+using simgrid::s4u::Barrier;
+using simgrid::s4u::BarrierPtr;
+using simgrid::s4u::Comm;
+using simgrid::s4u::CommPtr;
 using simgrid::s4u::Engine;
 using simgrid::s4u::Host;
 using simgrid::s4u::Link;
 using simgrid::s4u::Mailbox;
+using simgrid::s4u::Mutex;
+using simgrid::s4u::MutexPtr;
+using simgrid::s4u::Semaphore;
+using simgrid::s4u::SemaphorePtr;
 
 XBT_LOG_NEW_DEFAULT_CATEGORY(python, "python");
 
@@ -89,6 +99,11 @@ PYBIND11_MODULE(simgrid, m)
 
   py::register_exception<simgrid::NetworkFailureException>(m, "NetworkFailureException");
   py::register_exception<simgrid::TimeoutException>(m, "TimeoutException");
+  py::register_exception<simgrid::HostFailureException>(m, "HostFailureException");
+  py::register_exception<simgrid::StorageFailureException>(m, "StorageFailureException");
+  py::register_exception<simgrid::VmFailureException>(m, "VmFailureException");
+  py::register_exception<simgrid::CancelException>(m, "CancelException");
+  py::register_exception<simgrid::AssertionError>(m, "AssertionError");
 
   /* this_actor namespace */
   m.def_submodule("this_actor", "Bindings of the s4u::this_actor namespace. See the C++ documentation for details.")
@@ -96,6 +111,8 @@ PYBIND11_MODULE(simgrid, m)
           "debug", [](const char* s) { XBT_DEBUG("%s", s); }, "Display a logging message of 'debug' priority.")
       .def(
           "info", [](const char* s) { XBT_INFO("%s", s); }, "Display a logging message of 'info' priority.")
+      .def(
+          "warning", [](const char* s) { XBT_WARN("%s", s); }, "Display a logging message of 'warning' priority.")
       .def(
           "error", [](const char* s) { XBT_ERROR("%s", s); }, "Display a logging message of 'error' priority.")
       .def("execute", py::overload_cast<double, double>(&simgrid::s4u::this_actor::execute),
@@ -104,6 +121,16 @@ PYBIND11_MODULE(simgrid, m)
            py::arg("priority") = 1)
       .def("exec_init", py::overload_cast<double>(&simgrid::s4u::this_actor::exec_init),
            py::call_guard<py::gil_scoped_release>())
+      .def("exec_async", py::overload_cast<double>(&simgrid::s4u::this_actor::exec_async),
+           py::call_guard<py::gil_scoped_release>())
+      .def("parallel_execute", &simgrid::s4u::this_actor::parallel_execute,
+           py::call_guard<py::gil_scoped_release>(),
+           "Run a parallel task (requires the 'ptask_L07' model)")
+      .def("exec_init",
+           py::overload_cast<const std::vector<simgrid::s4u::Host*>&, const std::vector<double>&,
+           const std::vector<double>&>  (&simgrid::s4u::this_actor::exec_init),
+           py::call_guard<py::gil_scoped_release>(),
+           "Initiate a parallel task (requires the 'ptask_L07' model)")
       .def("get_host", &simgrid::s4u::this_actor::get_host, "Retrieves host on which the current actor is located")
       .def("set_host", &simgrid::s4u::this_actor::set_host, py::call_guard<py::gil_scoped_release>(),
            "Moves the current actor to another host.", py::arg("dest"))
@@ -122,16 +149,18 @@ PYBIND11_MODULE(simgrid, m)
           [](py::object cb) {
             py::function fun = py::reinterpret_borrow<py::function>(cb);
             fun.inc_ref(); // FIXME: why is this needed for tests like actor-kill and actor-lifetime?
-            simgrid::s4u::this_actor::on_exit([fun](bool /*failed*/) {
+            simgrid::s4u::this_actor::on_exit([fun](bool failed) {
+              py::gil_scoped_acquire py_context; // need a new context for callback
               try {
-                py::gil_scoped_acquire py_context; // need a new context for callback
-                fun();
+                fun(failed);
               } catch (const py::error_already_set& e) {
                 xbt_die("Error while executing the on_exit lambda: %s", e.what());
               }
             });
           },
-          py::call_guard<py::gil_scoped_release>(), "")
+          py::call_guard<py::gil_scoped_release>(),
+          "Define a lambda to be called when the actor ends. It takes a bool parameter indicating whether the actor "
+          "was killed. If False, the actor finished peacefully.")
       .def("get_pid", &simgrid::s4u::this_actor::get_pid, "Retrieves PID of the current actor")
       .def("get_ppid", &simgrid::s4u::this_actor::get_ppid,
            "Retrieves PPID of the current actor (i.e., the PID of its parent).");
@@ -147,11 +176,12 @@ PYBIND11_MODULE(simgrid, m)
            }),
            "The constructor should take the parameters from the command line, as is ")
       .def_static("get_clock",
-                  [](pybind11::object& self) // XBT_ATTRIB_DEPRECATED_v334
+                  []() // XBT_ATTRIB_DEPRECATED_v334
                   {
-                    PyErr_WarnEx(PyExc_DeprecationWarning,
-                                 "get_clock() is deprecated and  will be dropped after v3.33, use clock instead.", 1);
-                    return self.attr("clock");
+                    PyErr_WarnEx(
+                        PyExc_DeprecationWarning,
+                        "get_clock() is deprecated and  will be dropped after v3.33, use `Engine.clock` instead.", 1);
+                    return Engine::get_clock();
                   })
       .def_property_readonly_static(
           "clock", [](py::object /* self */) { return Engine::get_clock(); },
@@ -159,15 +189,17 @@ PYBIND11_MODULE(simgrid, m)
       .def_property_readonly_static(
           "instance", [](py::object /* self */) { return Engine::get_instance(); }, "Retrieve the simulation engine")
       .def("get_all_hosts",
-           [](pybind11::object& self) // XBT_ATTRIB_DEPRECATED_v334
+           [](py::object self) // XBT_ATTRIB_DEPRECATED_v334
            {
              PyErr_WarnEx(PyExc_DeprecationWarning,
                           "get_all_hosts() is deprecated and  will be dropped after v3.33, use all_hosts instead.", 1);
              return self.attr("all_hosts");
            })
+      .def("host_by_name", &Engine::host_by_name_or_null, py::call_guard<py::gil_scoped_release>(),
+           "Retrieve a host by its name, or None if it does not exist in the platform.")
       .def_property_readonly("all_hosts", &Engine::get_all_hosts, "Returns the list of all hosts found in the platform")
       .def("get_all_links",
-           [](pybind11::object& self) // XBT_ATTRIB_DEPRECATED_v334
+           [](py::object self) // XBT_ATTRIB_DEPRECATED_v334
            {
              PyErr_WarnEx(PyExc_DeprecationWarning,
                           "get_all_links() is deprecated and  will be dropped after v3.33, use all_links instead.", 1);
@@ -175,7 +207,7 @@ PYBIND11_MODULE(simgrid, m)
            })
       .def_property_readonly("all_links", &Engine::get_all_links, "Returns the list of all links found in the platform")
       .def("get_all_netpoints",
-           [](pybind11::object& self) // XBT_ATTRIB_DEPRECATED_v334
+           [](py::object self) // XBT_ATTRIB_DEPRECATED_v334
            {
              PyErr_WarnEx(
                  PyExc_DeprecationWarning,
@@ -184,7 +216,7 @@ PYBIND11_MODULE(simgrid, m)
            })
       .def_property_readonly("all_netpoints", &Engine::get_all_netpoints)
       .def("get_netzone_root",
-           [](pybind11::object& self) // XBT_ATTRIB_DEPRECATED_v334
+           [](py::object self) // XBT_ATTRIB_DEPRECATED_v334
            {
              PyErr_WarnEx(PyExc_DeprecationWarning,
                           "get_netzone_root() is deprecated and  will be dropped after v3.3, use netzone_root instead.",
@@ -195,8 +227,14 @@ PYBIND11_MODULE(simgrid, m)
                              "Retrieve the root netzone, containing all others.")
       .def("netpoint_by_name", &Engine::netpoint_by_name_or_null)
       .def("netzone_by_name", &Engine::netzone_by_name_or_null)
+      .def("set_config", py::overload_cast<const std::string&>(&Engine::set_config),
+           "Change one of SimGrid's configurations")
       .def("load_platform", &Engine::load_platform, "Load a platform file describing the environment")
       .def("load_deployment", &Engine::load_deployment, "Load a deployment file and launch the actors that it contains")
+      .def("mailbox_by_name_or_create", &Engine::mailbox_by_name_or_create,
+           py::call_guard<py::gil_scoped_release>(),
+           py::arg("name"),
+           "Find a mailbox from its name or create one if it does not exist")
       .def("run", &Engine::run, py::call_guard<py::gil_scoped_release>(), "Run the simulation until its end")
       .def("run_until", py::overload_cast<double>(&Engine::run_until, py::const_),
            py::call_guard<py::gil_scoped_release>(), "Run the simulation until the given date",
@@ -205,8 +243,8 @@ PYBIND11_MODULE(simgrid, m)
           "register_actor",
           [](Engine* e, const std::string& name, py::object fun_or_class) {
             e->register_actor(name, [fun_or_class](std::vector<std::string> args) {
+              py::gil_scoped_acquire py_context;
               try {
-                py::gil_scoped_acquire py_context;
                 /* Convert the std::vector into a py::tuple */
                 py::tuple params(args.size() - 1);
                 for (size_t i = 1; i < args.size(); i++)
@@ -277,7 +315,7 @@ PYBIND11_MODULE(simgrid, m)
       .def("set_parent", &simgrid::s4u::NetZone::set_parent, "Set the parent of this zone")
       .def("set_property", &simgrid::s4u::NetZone::set_property, "Add a property to this zone")
       .def("get_netpoint",
-           [](pybind11::object& self) // XBT_ATTRIB_DEPRECATED_v334
+           [](py::object self) // XBT_ATTRIB_DEPRECATED_v334
            {
              PyErr_WarnEx(PyExc_DeprecationWarning,
                           "get_netpoint() is deprecated and  will be dropped after v3.33, use netpoint instead.", 1);
@@ -309,7 +347,7 @@ PYBIND11_MODULE(simgrid, m)
   /* Class Host */
   py::class_<simgrid::s4u::Host, std::unique_ptr<Host, py::nodelete>> host(
       m, "Host", "Simulated host. See the C++ documentation for details.");
-  host.def("by_name", &Host::by_name, "Retrieves a host from its name, or die")
+  host.def_static("by_name", &Host::by_name, py::arg("name"), "Retrieves a host from its name, or die")
       .def(
           "route_to",
           [](const simgrid::s4u::Host* h, const simgrid::s4u::Host* to) {
@@ -356,7 +394,7 @@ PYBIND11_MODULE(simgrid, m)
           "The second function parameter is the periodicity: the time to wait after the last event to start again over "
           "the list. Set it to -1 to not loop over.")
       .def("get_pstate_count",
-           [](pybind11::object& self) // XBT_ATTRIB_DEPRECATED_v334
+           [](py::object self) // XBT_ATTRIB_DEPRECATED_v334
            {
              PyErr_WarnEx(
                  PyExc_DeprecationWarning,
@@ -365,7 +403,7 @@ PYBIND11_MODULE(simgrid, m)
            })
       .def_property_readonly("pstate_count", &Host::get_pstate_count, "Retrieve the count of defined pstate levels")
       .def("get_pstate_speed",
-           [](pybind11::object& self, int state) // XBT_ATTRIB_DEPRECATED_v334
+           [](py::object self, int state) // XBT_ATTRIB_DEPRECATED_v334
            {
              PyErr_WarnEx(
                  PyExc_DeprecationWarning,
@@ -375,7 +413,7 @@ PYBIND11_MODULE(simgrid, m)
       .def("pstate_speed", &Host::get_pstate_speed, py::call_guard<py::gil_scoped_release>(),
            "Retrieve the maximal speed at the given pstate")
       .def("get_netpoint",
-           [](pybind11::object& self) // XBT_ATTRIB_DEPRECATED_v334
+           [](py::object self) // XBT_ATTRIB_DEPRECATED_v334
            {
              PyErr_WarnEx(PyExc_DeprecationWarning,
                           "get_netpoint() is deprecated and  will be dropped after v3.33, use netpoint instead.", 1);
@@ -384,7 +422,7 @@ PYBIND11_MODULE(simgrid, m)
       .def_property_readonly("netpoint", &Host::get_netpoint, "Retrieve the netpoint associated to this zone")
       .def("get_disks", &Host::get_disks, "Retrieve the list of disks in this host")
       .def("set_core_count",
-           [](pybind11::object& self, double count) // XBT_ATTRIB_DEPRECATED_v334
+           [](py::object self, double count) // XBT_ATTRIB_DEPRECATED_v334
            {
              PyErr_WarnEx(PyExc_DeprecationWarning,
                           "set_core_count() is deprecated and  will be dropped after v3.33, use core_count instead.",
@@ -415,7 +453,7 @@ PYBIND11_MODULE(simgrid, m)
             h->set_pstate(i);
           },
           "The current pstate (read/write property).")
-      .def("current", &Host::current, py::call_guard<py::gil_scoped_release>(),
+      .def_static("current", &Host::current, py::call_guard<py::gil_scoped_release>(),
            "Retrieves the host on which the running actor is located.")
       .def_property_readonly(
           "name",
@@ -434,13 +472,13 @@ PYBIND11_MODULE(simgrid, m)
                              "Get the available speed ratio, between 0 and 1.\n"
                              "This accounts for external load (see :py:func:`set_speed_profile() "
                              "<simgrid.Host.set_speed_profile>`) (read-only property).")
-      .def(
+      .def_static(
           "on_creation_cb",
           [](py::object cb) {
             Host::on_creation_cb([cb](Host& h) {
               py::function fun = py::reinterpret_borrow<py::function>(cb);
+              py::gil_scoped_acquire py_context; // need a new context for callback
               try {
-                py::gil_scoped_acquire py_context; // need a new context for callback
                 fun(&h);
               } catch (const py::error_already_set& e) {
                 xbt_die("Error while executing the on_creation lambda : %s", e.what());
@@ -596,7 +634,7 @@ PYBIND11_MODULE(simgrid, m)
   py::class_<simgrid::s4u::SplitDuplexLink, Link, std::unique_ptr<simgrid::s4u::SplitDuplexLink, py::nodelete>>(
       m, "SplitDuplexLink", "Network split-duplex link")
       .def("get_link_up",
-           [](pybind11::object& self) // XBT_ATTRIB_DEPRECATED_v334
+           [](py::object self) // XBT_ATTRIB_DEPRECATED_v334
            {
              PyErr_WarnEx(PyExc_DeprecationWarning,
                           "get_link_up() is deprecated and  will be dropped after v3.33, use link_up instead.", 1);
@@ -604,7 +642,7 @@ PYBIND11_MODULE(simgrid, m)
            })
       .def_property_readonly("link_up", &simgrid::s4u::SplitDuplexLink::get_link_up, "Get link direction up")
       .def("get_link_down",
-           [](pybind11::object& self) // XBT_ATTRIB_DEPRECATED_v334
+           [](py::object self) // XBT_ATTRIB_DEPRECATED_v334
            {
              PyErr_WarnEx(PyExc_DeprecationWarning,
                           "get_link_down() is deprecated and  will be dropped after v3.33, use link_down instead.", 1);
@@ -618,45 +656,58 @@ PYBIND11_MODULE(simgrid, m)
       .def(
           "__str__", [](const Mailbox* self) { return std::string("Mailbox(") + self->get_cname() + ")"; },
           "Textual representation of the Mailbox`")
-      .def("by_name", &Mailbox::by_name, py::call_guard<py::gil_scoped_release>(), "Retrieve a Mailbox from its name")
+      .def_static("by_name", &Mailbox::by_name,
+                  py::call_guard<py::gil_scoped_release>(),
+                  py::arg("name"),
+                  "Retrieve a Mailbox from its name")
       .def_property_readonly(
           "name",
           [](const Mailbox* self) {
             return std::string(self->get_name().c_str()); // Convert from xbt::string because of MC
           },
           "The name of that mailbox (read-only property).")
+      .def_property_readonly("ready", &Mailbox::ready, py::call_guard<py::gil_scoped_release>(),
+                             "Check if there is a communication ready to be consumed from a mailbox.")
       .def(
           "put",
-          [](Mailbox* self, py::object data, int size, double timeout) {
+          [](Mailbox* self, py::object data, uint64_t size, double timeout) {
             data.inc_ref();
             self->put(data.ptr(), size, timeout);
           },
           py::call_guard<py::gil_scoped_release>(), "Blocking data transmission with a timeout")
       .def(
           "put",
-          [](Mailbox* self, py::object data, int size) {
+          [](Mailbox* self, py::object data, uint64_t size) {
             data.inc_ref();
             self->put(data.ptr(), size);
           },
           py::call_guard<py::gil_scoped_release>(), "Blocking data transmission")
       .def(
           "put_async",
-          [](Mailbox* self, py::object data, int size) {
+          [](Mailbox* self, py::object data, uint64_t size) {
             data.inc_ref();
             return self->put_async(data.ptr(), size);
           },
           py::call_guard<py::gil_scoped_release>(), "Non-blocking data transmission")
+      .def(
+          "put_init",
+          [](Mailbox* self, py::object data, uint64_t size) {
+            data.inc_ref();
+            return self->put_init(data.ptr(), size);
+          },
+          py::call_guard<py::gil_scoped_release>(),
+          "Creates (but don’t start) a data transmission to that mailbox.")
       .def(
           "get",
           [](Mailbox* self) {
-            py::object data = pybind11::reinterpret_steal<py::object>(self->get<PyObject>());
+            py::object data = py::reinterpret_steal<py::object>(self->get<PyObject>());
             // data.dec_ref(); // FIXME: why does it break python-actor-create?
             return data;
           },
           py::call_guard<py::gil_scoped_release>(), "Blocking data reception")
       .def(
           "get_async",
-          [](Mailbox* self) -> std::tuple<simgrid::s4u::CommPtr, PyGetAsync> {
+          [](Mailbox* self) -> std::tuple<CommPtr, PyGetAsync> {
             PyGetAsync wrap;
             auto comm = self->get_async(wrap.get());
             return std::make_tuple(std::move(comm), std::move(wrap));
@@ -675,20 +726,93 @@ PYBIND11_MODULE(simgrid, m)
           "Get python object after async communication in receiver side");
 
   /* Class Comm */
-  py::class_<simgrid::s4u::Comm, simgrid::s4u::CommPtr>(m, "Comm",
-                                                        "Communication. See the C++ documentation for details.")
-      .def("test", &simgrid::s4u::Comm::test, py::call_guard<py::gil_scoped_release>(),
+  py::class_<Comm, CommPtr>(m, "Comm", "Communication. See the C++ documentation for details.")
+      .def_property_readonly("dst_data_size", &Comm::get_dst_data_size,
+                             py::call_guard<py::gil_scoped_release>(),
+                             "Retrieve the size of the received data.")
+      .def_property_readonly("mailbox", &Comm::get_mailbox,
+                             py::call_guard<py::gil_scoped_release>(),
+                             "Retrieve the mailbox on which this comm acts.")
+      .def_property_readonly("sender", &Comm::get_sender,
+                             py::call_guard<py::gil_scoped_release>())
+      .def_property_readonly("state_str", [](const Comm* self){ return std::string(self->get_state_str()); },
+                             py::call_guard<py::gil_scoped_release>(),
+                             "Retrieve the Comm state as string")
+      .def_property_readonly("remaining",  &Comm::get_remaining,
+                             py::call_guard<py::gil_scoped_release>(),
+                             "Remaining amount of work that this Comm entails")
+      .def_property_readonly("start_time",  &Comm::get_start_time,
+                             py::call_guard<py::gil_scoped_release>(),
+                             "Time at which this Comm started")
+      .def_property_readonly("finish_time",  &Comm::get_finish_time,
+                             py::call_guard<py::gil_scoped_release>(),
+                             "Time at which this Comm finished")
+      .def("set_payload_size", &Comm::set_payload_size, py::call_guard<py::gil_scoped_release>(),
+           py::arg("bytes"),
+           "Specify the amount of bytes which exchange should be simulated.")
+      .def("set_rate", &Comm::set_rate, py::call_guard<py::gil_scoped_release>(),
+           py::arg("rate"),
+           "Sets the maximal communication rate (in byte/sec). Must be done before start")
+      .def("cancel", [](Comm* self){ return self->cancel(); },
+           py::call_guard<py::gil_scoped_release>(), py::return_value_policy::reference_internal,
+           "Cancel the activity.")
+      .def("start", [](Comm* self){ return self->start(); },
+           py::call_guard<py::gil_scoped_release>(), py::return_value_policy::reference_internal,
+           "Starts a previously created activity. This function is optional: you can call wait() even if you didn't "
+           "call start()")
+      .def("suspend", [](Comm* self){ return self->suspend(); },
+          py::call_guard<py::gil_scoped_release>(), py::return_value_policy::reference_internal,
+          "Suspend the activity.")
+      .def("resume", [](Comm* self){ return self->resume(); },
+          py::call_guard<py::gil_scoped_release>(), py::return_value_policy::reference_internal,
+          "Resume the activity.")
+      .def("test", &Comm::test, py::call_guard<py::gil_scoped_release>(),
            "Test whether the communication is terminated.")
-      .def("wait", &simgrid::s4u::Comm::wait, py::call_guard<py::gil_scoped_release>(),
+      .def("wait", &Comm::wait, py::call_guard<py::gil_scoped_release>(),
            "Block until the completion of that communication.")
-      // use py::overload_cast for wait_all/wait_any, until the overload marked XBT_ATTRIB_DEPRECATED_v332 is removed
-      .def_static(
-          "wait_all", py::overload_cast<const std::vector<simgrid::s4u::CommPtr>&>(&simgrid::s4u::Comm::wait_all),
-          py::call_guard<py::gil_scoped_release>(), "Block until the completion of all communications in the list.")
-      .def_static(
-          "wait_any", py::overload_cast<const std::vector<simgrid::s4u::CommPtr>&>(&simgrid::s4u::Comm::wait_any),
-          py::call_guard<py::gil_scoped_release>(),
-          "Block until the completion of any communication in the list and return the index of the terminated one.");
+      .def("wait_for", &Comm::wait_for, py::call_guard<py::gil_scoped_release>(),
+           py::arg("timeout"),
+           "Block until the completion of that communication, or raises TimeoutException after the specified timeout.")
+      .def("wait_until", &Comm::wait_until, py::call_guard<py::gil_scoped_release>(),
+           py::arg("time_limit"),
+           "Block until the completion of that communication, or raises TimeoutException after the specified time.")
+      .def("detach", [](Comm* self) { return self->detach(); },
+           py::return_value_policy::reference_internal,
+           py::call_guard<py::gil_scoped_release>(),
+           "Start the comm, and ignore its result. It can be completely forgotten after that.")
+      .def_static("sendto", &Comm::sendto, py::call_guard<py::gil_scoped_release>(),
+                  py::arg("from"), py::arg("to"), py::arg("simulated_size_in_bytes"),
+                  "Do a blocking communication between two arbitrary hosts.")
+      .def_static("sendto_init", py::overload_cast<Host*, Host*>(&Comm::sendto_init),
+                  py::call_guard<py::gil_scoped_release>(),
+                  py::arg("from"), py::arg("to"),
+                  "Creates a communication between the two given hosts, bypassing the mailbox mechanism.")
+      .def_static("sendto_async", &Comm::sendto_async, py::call_guard<py::gil_scoped_release>(),
+                  py::arg("from"), py::arg("to"), py::arg("simulated_size_in_bytes"),
+                  "Do a blocking communication between two arbitrary hosts.\n\nThis initializes a communication that "
+                  "completely bypass the mailbox and actors mechanism. There is really no limit on the hosts involved. "
+                  "In particular, the actor does not have to be on one of the involved hosts.")
+      .def_static("test_any", &Comm::test_any,
+                  py::call_guard<py::gil_scoped_release>(),
+                  py::arg("comms"),
+                  "take a vector s4u::CommPtr and return the rank of the first finished one (or -1 if none is done)")
+      .def_static("wait_all", &Comm::wait_all, py::call_guard<py::gil_scoped_release>(),
+                  py::arg("comms"),
+                  "Block until the completion of all communications in the list.")
+      .def_static("wait_all_for", &Comm::wait_all_for, py::call_guard<py::gil_scoped_release>(),
+                  py::arg("comms"), py::arg("timeout"),
+                  "Block until the completion of all communications in the list, or raises TimeoutException after "
+                  "the specified timeout.")
+      .def_static("wait_any", &Comm::wait_any,
+                  py::call_guard<py::gil_scoped_release>(),
+                  py::arg("comms"),
+                  "Block until the completion of any communication in the list and return the index of the "
+                  "terminated one.")
+      .def_static("wait_any_for", &Comm::wait_any_for,
+                  py::call_guard<py::gil_scoped_release>(),
+                  py::arg("comms"), py::arg("timeout"),
+                  "Block until the completion of any communication in the list and return the index of the terminated "
+                  "one, or -1 if a timeout occurred.");
 
   /* Class Io */
   py::class_<simgrid::s4u::Io, simgrid::s4u::IoPtr>(m, "Io", "I/O activities. See the C++ documentation for details.")
@@ -726,8 +850,57 @@ PYBIND11_MODULE(simgrid, m)
            "Test whether the execution is terminated.")
       .def("cancel", &simgrid::s4u::Exec::cancel, py::call_guard<py::gil_scoped_release>(), "Cancel that execution.")
       .def("start", &simgrid::s4u::Exec::start, py::call_guard<py::gil_scoped_release>(), "Start that execution.")
+      .def("suspend", &simgrid::s4u::Exec::suspend, py::call_guard<py::gil_scoped_release>(), "Suspend that execution.")
       .def("wait", &simgrid::s4u::Exec::wait, py::call_guard<py::gil_scoped_release>(),
-           "Block until the completion of that execution.");
+           "Block until the completion of that execution.")
+      .def("wait_for", &simgrid::s4u::Exec::wait_for, py::call_guard<py::gil_scoped_release>(),
+           py::arg("timeout"),
+           "Block until the completion of that activity, or raises TimeoutException after the specified timeout.");
+
+  /* Class Semaphore */
+  py::class_<Semaphore, SemaphorePtr>(m, "Semaphore",
+                                      "A classical semaphore, but blocking in the simulation world. See the C++ "
+                                      "documentation for details.")
+      .def(py::init<>(&Semaphore::create), py::call_guard<py::gil_scoped_release>(), py::arg("capacity"),
+           "Semaphore constructor.")
+      .def("acquire", &Semaphore::acquire, py::call_guard<py::gil_scoped_release>(),
+           "Acquire on the semaphore object with no timeout. Blocks until the semaphore is acquired.")
+      .def("acquire_timeout", &Semaphore::acquire_timeout, py::call_guard<py::gil_scoped_release>(), py::arg("timeout"),
+           "Acquire on the semaphore object with no timeout. Blocks until the semaphore is acquired or return "
+           "true if it has not been acquired after the specified timeout.")
+      .def("release", &Semaphore::release, py::call_guard<py::gil_scoped_release>(),
+           "Release the semaphore.")
+      .def_property_readonly("capacity", &Semaphore::get_capacity, py::call_guard<py::gil_scoped_release>(),
+                             "Get the semaphore capacity.")
+      .def_property_readonly("would_block", &Semaphore::would_block, py::call_guard<py::gil_scoped_release>(),
+                             "Check whether trying to acquire the semaphore would block (in other word, checks whether "
+                             "this semaphore has capacity).")
+      // Allow semaphores to be automatically acquired/released with a context manager: `with semaphore: ...`
+      .def("__enter__", [](Semaphore* self){ self->acquire(); }, py::call_guard<py::gil_scoped_release>())
+      .def("__exit__", [](Semaphore* self){ self->release(); }, py::call_guard<py::gil_scoped_release>());
+
+  /* Class Mutex */
+  py::class_<Mutex, MutexPtr>(m, "Mutex",
+                              "A classical mutex, but blocking in the simulation world."
+                              "See the C++ documentation for details.")
+      .def(py::init<>(&Mutex::create), py::call_guard<py::gil_scoped_release>(), "Mutex constructor.")
+      .def("lock", &Mutex::lock, py::call_guard<py::gil_scoped_release>(), "Block until the mutex is acquired.")
+      .def("try_lock", &Mutex::try_lock, py::call_guard<py::gil_scoped_release>(),
+           "Try to acquire the mutex. Return true if the mutex was acquired, false otherwise.")
+      .def("unlock", &Mutex::unlock, py::call_guard<py::gil_scoped_release>(), "Release the mutex.")
+      // Allow mutexes to be automatically acquired/released with a context manager: `with mutex: ...`
+      .def("__enter__", [](Mutex* self){ self->lock(); }, py::call_guard<py::gil_scoped_release>())
+      .def("__exit__", [](Mutex* self, const py::object&, const py::object&, const py::object&) { self->unlock(); },
+          py::call_guard<py::gil_scoped_release>());
+
+  /* Class Barrier */
+  py::class_<Barrier, BarrierPtr>(m, "Barrier",
+                                  "A classical barrier, but blocking in the simulation world.")
+      .def(py::init<>(&Barrier::create), py::call_guard<py::gil_scoped_release>(), py::arg("expected_actors"),
+           "Barrier constructor.")
+      .def("wait", &Barrier::wait, py::call_guard<py::gil_scoped_release>(),
+           "Blocks into the barrier. Every waiting actors will be unlocked once the expected amount of actors reaches "
+           "the barrier.");
 
   /* Class Actor */
   py::class_<simgrid::s4u::Actor, ActorPtr>(m, "Actor",
@@ -739,8 +912,8 @@ PYBIND11_MODULE(simgrid, m)
             fun.inc_ref();  // FIXME: why is this needed for tests like exec-async, exec-dvfs and exec-remote?
             args.inc_ref(); // FIXME: why is this needed for tests like actor-migrate?
             return simgrid::s4u::Actor::create(name, h, [fun, args]() {
+              py::gil_scoped_acquire py_context;
               try {
-                py::gil_scoped_acquire py_context;
                 fun(*args);
               } catch (const py::error_already_set& ex) {
                 if (ex.matches(pyForcefulKillEx)) {
@@ -769,7 +942,7 @@ PYBIND11_MODULE(simgrid, m)
       .def_property_readonly("pid", &Actor::get_pid, "The PID (unique identifier) of this actor (read-only property).")
       .def_property_readonly("ppid", &Actor::get_ppid,
                              "The PID (unique identifier) of the actor that created this one (read-only property).")
-      .def("by_pid", &Actor::by_pid, "Retrieve an actor by its PID")
+      .def_static("by_pid", &Actor::by_pid, py::arg("pid"), "Retrieve an actor by its PID")
       .def("set_auto_restart", &Actor::set_auto_restart, py::call_guard<py::gil_scoped_release>(),
            "Specify whether the actor shall restart when its host reboots.")
       .def("daemonize", &Actor::daemonize, py::call_guard<py::gil_scoped_release>(),
@@ -779,13 +952,13 @@ PYBIND11_MODULE(simgrid, m)
            "Returns True if that actor is a daemon and will be terminated automatically when the last non-daemon actor "
            "terminates.")
       .def("join", py::overload_cast<double>(&Actor::join, py::const_), py::call_guard<py::gil_scoped_release>(),
-           "Wait for the actor to finish (more info in the C++ documentation).", py::arg("timeout"))
+           "Wait for the actor to finish (more info in the C++ documentation).", py::arg("timeout") = -1)
       .def("kill", &Actor::kill, py::call_guard<py::gil_scoped_release>(), "Kill that actor")
-      .def("kill_all", &Actor::kill_all, py::call_guard<py::gil_scoped_release>(), "Kill all actors but the caller.")
       .def("self", &Actor::self, "Retrieves the current actor.")
       .def("is_suspended", &Actor::is_suspended, "Returns True if that actor is currently suspended.")
       .def("suspend", &Actor::suspend, py::call_guard<py::gil_scoped_release>(),
            "Suspend that actor, that is blocked until resume()ed by another actor.")
       .def("resume", &Actor::resume, py::call_guard<py::gil_scoped_release>(),
-           "Resume that actor, that was previously suspend()ed.");
+           "Resume that actor, that was previously suspend()ed.")
+      .def_static("kill_all", &Actor::kill_all, py::call_guard<py::gil_scoped_release>(), "Kill all actors but the caller.");
 }
