@@ -7,11 +7,11 @@
 #include "src/instr/instr_smpi.hpp"
 #include "src/smpi/include/private.hpp"
 #include "src/surf/surf_interface.hpp"
+#include "xbt/ex.h"
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(instr_paje_events, instr, "Paje tracing event system (events)");
 
-namespace simgrid {
-namespace instr {
+namespace simgrid::instr {
 
 PajeEvent::PajeEvent(Container* container, Type* type, double timestamp, PajeEventType eventType)
     : container_(container), type_(type), timestamp_(timestamp), eventType_(eventType)
@@ -76,12 +76,11 @@ void StateEvent::print()
     }
 #if HAVE_SMPI
     if (smpi_cfg_trace_call_location())
-      stream_ << container_name << " location " << filename << " " << linenumber << std::endl ;
+      stream_ << container_name << " location " << filename << " " << linenumber << '\n';
 #endif
     stream_ << container_name << " " << extra_->print();
   } else {
     THROW_IMPOSSIBLE;
   }
 }
-} // namespace instr
-} // namespace simgrid
+} // namespace simgrid::instr
