@@ -24,8 +24,7 @@
 #include <sstream>
 #include <string>
 
-namespace simgrid {
-namespace instr {
+namespace simgrid::instr {
 namespace paje {
 
 void dump_generator_version();
@@ -205,7 +204,7 @@ class WaitTIData : public TIData {
   int tag_;
 
 public:
-  WaitTIData(int src, int dest, int tag) : TIData("wait"), src_(src), dest_(dest), tag_(tag){};
+  WaitTIData(const std::string& name, int src, int dest, int tag) : TIData(name), src_(src), dest_(dest), tag_(tag){};
 
   std::string print() override
   {
@@ -230,8 +229,7 @@ public:
   }
   std::string display_size() override { return "NA"; }
 };
-} // namespace instr
-} // namespace simgrid
+} // namespace simgrid::instr
 
 XBT_PRIVATE std::string instr_pid(simgrid::s4u::Actor const& proc);
 
