@@ -18,6 +18,7 @@
 #include "src/mc/mc_replay.hpp"
 #include "src/smpi/include/smpi_actor.hpp"
 #include "src/surf/xml/platf.hpp"
+#include "xbt/module.h"
 #include "xbt/xbt_modinter.h" /* whether initialization was already done */
 
 #include <boost/algorithm/string/predicate.hpp>
@@ -29,37 +30,17 @@
 #include "src/mc/remote/AppSide.hpp"
 #endif
 
-double NOW = 0;
-
 XBT_LOG_NEW_DEFAULT_CATEGORY(ker_engine, "Logging specific to Engine (kernel)");
 
-namespace simgrid {
-namespace kernel {
+namespace simgrid::kernel {
+double EngineImpl::now_           = 0.0;
 EngineImpl* EngineImpl::instance_ = nullptr; /* That singleton is awful too. */
 
 config::Flag<double> cfg_breakpoint{"debug/breakpoint",
                                     "When non-negative, raise a SIGTRAP after given (simulated) time", -1.0};
 config::Flag<bool> cfg_verbose_exit{"debug/verbose-exit", "Display the actor status at exit", true};
 
-xbt_dynar_t get_actors_addr()
-{
-#if SIMGRID_HAVE_MC
-  return EngineImpl::get_instance()->get_actors_vector();
-#else
-  xbt_die("This function is intended to be used when compiling with MC");
-#endif
-}
-
-xbt_dynar_t get_dead_actors_addr()
-{
-#if SIMGRID_HAVE_MC
-  return EngineImpl::get_instance()->get_dead_actors_vector();
-#else
-  xbt_die("This function is intended to be used when compiling with MC");
-#endif
-}
-
-constexpr std::initializer_list<std::pair<const char*, context::ContextFactoryInitializer>> context_factories = {
+constexpr std::initializer_list<std::pair<const char*, context::ContextFactory* (*)()>> context_factories = {
 #if HAVE_RAW_CONTEXTS
     {"raw", &context::raw_factory},
 #endif
@@ -79,8 +60,8 @@ static inline std::string contexts_list()
 {
   std::string res;
   std::string sep = "";
-  for (auto const& factory : context_factories) {
-    res += sep + factory.first;
+  for (auto const& [factory_name, _] : context_factories) {
+    res += sep + factory_name;
     sep = ", ";
   }
   return res;
@@ -90,8 +71,7 @@ static config::Flag<std::string> context_factory_name("contexts/factory",
                                                       (std::string("Possible values: ") + contexts_list()).c_str(),
                                                       context_factories.begin()->first);
 
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel
 
 XBT_ATTRIB_NORETURN static void inthandler(int)
 {
@@ -126,7 +106,7 @@ static void segvhandler(int signum, siginfo_t* siginfo, void* /*context*/)
   } else if (siginfo->si_signo == SIGSEGV) {
     fprintf(stderr, "Segmentation fault.\n");
 #if HAVE_SMPI
-    if (smpi_enabled() && smpi_cfg_privatization() == SmpiPrivStrategies::NONE) {
+    if (SMPI_is_inited() && smpi_cfg_privatization() == SmpiPrivStrategies::NONE) {
 #if HAVE_PRIVATIZATION
       fprintf(stderr, "Try to enable SMPI variable privatization with --cfg=smpi/privatization:yes.\n");
 #else
@@ -178,33 +158,26 @@ static void install_segvhandler()
 
 #endif /* _WIN32 */
 
-namespace simgrid {
-namespace kernel {
+namespace simgrid::kernel {
 
 EngineImpl::~EngineImpl()
 {
-  /* Since hosts_ is a std::map, the hosts are destroyed in the lexicographic order, which ensures that the output is
-   * reproducible.
-   */
-  while (not hosts_.empty())
-    hosts_.begin()->second->destroy();
-
   /* Also delete the other data */
   delete netzone_root_;
-  for (auto const& kv : netpoints_)
-    delete kv.second;
+  for (auto const& [_, netpoint] : netpoints_)
+    delete netpoint;
 
-  while (not links_.empty())
-    links_.begin()->second->destroy();
+  for (auto const& [_, mailbox] : mailboxes_)
+    delete mailbox;
 
-  for (auto const& kv : mailboxes_)
-    delete kv.second;
+  /* Kill all actors (but maestro) */
+  maestro_->kill_all();
+  run_all_actors();
+  empty_trash();
+
+  delete maestro_;
+  delete context_factory_;
 
-    /* Free the remaining data structures */
-#if SIMGRID_HAVE_MC
-  xbt_dynar_free(&actors_vector_);
-  xbt_dynar_free(&dead_actors_vector_);
-#endif
   /* clear models before freeing handle, network models can use external callback defined in the handle */
   models_prio_.clear();
 }
@@ -216,7 +189,7 @@ void EngineImpl::initialize(int* argc, char** argv)
   EngineImpl::instance_ = this;
 #if SIMGRID_HAVE_MC
   // The communication initialization is done ASAP, as we need to get some init parameters from the MC for different
-  // layers. But simix_global needs to be created, as we send the address of some of its fields to the MC that wants to
+  // layers. But instance_ needs to be created, as we send the address of some of its fields to the MC that wants to
   // read them directly.
   simgrid::mc::AppSide::initialize();
 #endif
@@ -266,14 +239,14 @@ void EngineImpl::context_mod_init() const
 #endif
 
   /* select the context factory to use to create the contexts */
-  if (context::factory_initializer != nullptr) { // Give Java a chance to hijack the factory mechanism
-    instance_->set_context_factory(context::factory_initializer());
+  if (context::ContextFactory::initializer) { // Give Java a chance to hijack the factory mechanism
+    instance_->set_context_factory(context::ContextFactory::initializer());
     return;
   }
   /* use the factory specified by --cfg=contexts/factory:value */
-  for (auto const& factory : context_factories)
-    if (context_factory_name == factory.first) {
-      instance_->set_context_factory(factory.second());
+  for (auto const& [factory_name, factory] : context_factories)
+    if (context_factory_name == factory_name) {
+      instance_->set_context_factory(factory());
       break;
     }
 
@@ -307,7 +280,7 @@ void EngineImpl::shutdown()
   XBT_DEBUG("EngineImpl::shutdown() called. Simulation's over.");
 #if HAVE_SMPI
   if (not instance_->actor_list_.empty()) {
-    if (smpi_process()->initialized()) {
+    if (smpi_process() && smpi_process()->initialized()) {
       xbt_die("Process exited without calling MPI_Finalize - Killing simulation");
     } else {
       XBT_WARN("Process called exit when leaving - Skipping cleanups");
@@ -323,18 +296,6 @@ void EngineImpl::shutdown()
     xbt_die("Bailing out to avoid that stop-before-start madness. Please fix your code.");
   }
 
-  /* Kill all actors (but maestro) */
-  instance_->maestro_->kill_all();
-  instance_->run_all_actors();
-  instance_->empty_trash();
-
-  /* Let's free maestro now */
-  delete instance_->maestro_;
-  instance_->maestro_ = nullptr;
-
-  /* Finish context module and SURF */
-  instance_->destroy_context_factory();
-
   while (not timer::kernel_timers().empty()) {
     delete timer::kernel_timers().top().second;
     timer::kernel_timers().pop();
@@ -349,9 +310,12 @@ void EngineImpl::shutdown()
 
 void EngineImpl::seal_platform() const
 {
-  /* sealing resources before run: links */
-  for (auto const& kv : links_)
-    kv.second->get_iface()->seal();
+  /* Seal only once */
+  static bool sealed = false;
+  if (sealed)
+    return;
+  sealed = true;
+
   /* seal netzone root, recursively seal children netzones, hosts and disks */
   netzone_root_->seal();
 }
@@ -359,7 +323,7 @@ void EngineImpl::seal_platform() const
 void EngineImpl::load_platform(const std::string& platf)
 {
   double start = xbt_os_time();
-  if (boost::algorithm::ends_with(platf, ".so") or boost::algorithm::ends_with(platf, ".dylib")) {
+  if (boost::algorithm::ends_with(platf, ".so") || boost::algorithm::ends_with(platf, ".dylib")) {
 #ifdef _WIN32
     xbt_die("loading platform through shared library isn't supported on windows");
 #else
@@ -405,7 +369,7 @@ void EngineImpl::add_model(std::shared_ptr<resource::Model> model, const std::ve
   xbt_assert(models_prio_.find(model_name) == models_prio_.end(),
              "Model %s already exists, use model.set_name() to change its name", model_name.c_str());
 
-  for (const auto dep : dependencies) {
+  for (const auto* dep : dependencies) {
     xbt_assert(models_prio_.find(dep->get_name()) != models_prio_.end(),
                "Model %s doesn't exists. Impossible to use it as dependency.", dep->get_name().c_str());
   }
@@ -413,21 +377,15 @@ void EngineImpl::add_model(std::shared_ptr<resource::Model> model, const std::ve
   models_prio_[model_name] = std::move(model);
 }
 
-void EngineImpl::add_split_duplex_link(const std::string& name, std::unique_ptr<resource::SplitDuplexLinkImpl> link)
-{
-  split_duplex_links_[name] = std::move(link);
-}
-
 /** Wake up all actors waiting for a Surf action to finish */
-void EngineImpl::wake_all_waiting_actors() const
+void EngineImpl::handle_ended_actions() const
 {
   for (auto const& model : models_) {
     XBT_DEBUG("Handling the failed actions (if any)");
     while (auto* action = model->extract_failed_action()) {
       XBT_DEBUG("   Handling Action %p", action);
-      if (action->get_activity() != nullptr) {
-        // If nobody told the interface that the activity has failed, that's because no actor waits on it (maestro
-        // started it). SimDAG I see you!
+      if (action->get_activity() != nullptr) { // Skip vcpu actions
+        // Action failures are not automatically reported when the action is started by maestro (as in SimDAG)
         if (action->get_activity()->get_actor() == maestro_)
           action->get_activity()->get_iface()->complete(s4u::Activity::State::FAILED);
 
@@ -437,11 +395,8 @@ void EngineImpl::wake_all_waiting_actors() const
     XBT_DEBUG("Handling the terminated actions (if any)");
     while (auto* action = model->extract_done_action()) {
       XBT_DEBUG("   Handling Action %p", action);
-      if (action->get_activity() == nullptr)
-        XBT_DEBUG("probably vcpu's action %p, skip", action);
-      else {
-        // If nobody told the interface that the activity is finished, that's because no actor waits on it (maestro
-        // started it). SimDAG I see you!
+      if (action->get_activity() != nullptr) {
+        // Action termination are not automatically reported when the action is started by maestro (as in SimDAG)
         action->get_activity()->set_finish_time(action->get_finish_time());
 
         if (action->get_activity()->get_actor() == maestro_)
@@ -461,7 +416,11 @@ void EngineImpl::wake_all_waiting_actors() const
  */
 void EngineImpl::run_all_actors()
 {
-  instance_->get_context_factory()->run_all();
+  instance_->get_context_factory()->run_all(actors_to_run_);
+
+  for (auto const& actor : actors_to_run_)
+    if (actor->to_be_freed())
+      actor->cleanup_from_kernel();
 
   actors_to_run_.swap(actors_that_ran_);
   actors_to_run_.clear();
@@ -470,35 +429,7 @@ void EngineImpl::run_all_actors()
 actor::ActorImpl* EngineImpl::get_actor_by_pid(aid_t pid)
 {
   auto item = actor_list_.find(pid);
-  if (item != actor_list_.end())
-    return item->second;
-
-  // Search the trash
-  for (auto& a : actors_to_destroy_)
-    if (a.get_pid() == pid)
-      return &a;
-  return nullptr; // Not found, even in the trash
-}
-
-/** Execute all the tasks that are queued, e.g. `.then()` callbacks of futures. */
-bool EngineImpl::execute_tasks()
-{
-  if (tasks.empty())
-    return false;
-
-  std::vector<xbt::Task<void()>> tasksTemp;
-  do {
-    // We don't want the callbacks to modify the vector we are iterating over:
-    tasks.swap(tasksTemp);
-
-    // Execute all the queued tasks:
-    for (auto& task : tasksTemp)
-      task();
-
-    tasksTemp.clear();
-  } while (not tasks.empty());
-
-  return true;
+  return item == actor_list_.end() ? nullptr : item->second;
 }
 
 void EngineImpl::remove_daemon(actor::ActorImpl* actor)
@@ -531,9 +462,6 @@ void EngineImpl::empty_trash()
     XBT_DEBUG("Getting rid of %s (refcount: %d)", actor->get_cname(), actor->get_refcount());
     intrusive_ptr_release(actor);
   }
-#if SIMGRID_HAVE_MC
-  xbt_dynar_reset(dead_actors_vector_);
-#endif
 }
 
 void EngineImpl::display_all_actor_status() const
@@ -541,9 +469,7 @@ void EngineImpl::display_all_actor_status() const
   XBT_INFO("%zu actors are still running, waiting for something.", actor_list_.size());
   /*  List the actors and their state */
   XBT_INFO("Legend of the following listing: \"Actor <pid> (<name>@<host>): <status>\"");
-  for (auto const& kv : actor_list_) {
-    actor::ActorImpl* actor = kv.second;
-
+  for (auto const& [_, actor] : actor_list_) {
     if (actor->waiting_synchro_) {
       const char* synchro_description = "unknown";
 
@@ -556,7 +482,7 @@ void EngineImpl::display_all_actor_status() const
       if (boost::dynamic_pointer_cast<kernel::activity::SleepImpl>(actor->waiting_synchro_) != nullptr)
         synchro_description = "sleeping";
 
-      if (boost::dynamic_pointer_cast<kernel::activity::RawImpl>(actor->waiting_synchro_) != nullptr)
+      if (boost::dynamic_pointer_cast<kernel::activity::SynchroImpl>(actor->waiting_synchro_) != nullptr)
         synchro_description = "synchronization";
 
       if (boost::dynamic_pointer_cast<kernel::activity::IoImpl>(actor->waiting_synchro_) != nullptr)
@@ -568,7 +494,7 @@ void EngineImpl::display_all_actor_status() const
                actor->waiting_synchro_->get_cname(), actor->waiting_synchro_->get_state_str());
     } else {
       XBT_INFO("Actor %ld (%s@%s) simcall %s", actor->get_pid(), actor->get_cname(), actor->get_host()->get_cname(),
-               SIMIX_simcall_name(actor->simcall_));
+               actor->simcall_.get_cname());
     }
   }
 }
@@ -578,7 +504,7 @@ void EngineImpl::presolve() const
   XBT_DEBUG("Consume all trace events occurring before the starting time.");
   double next_event_date;
   while ((next_event_date = profile::future_evt_set.next_date()) != -1.0) {
-    if (next_event_date > NOW)
+    if (next_event_date > now_)
       break;
 
     double value                 = -1.0;
@@ -591,7 +517,7 @@ void EngineImpl::presolve() const
 
   XBT_DEBUG("Set every models in the right state by updating them to 0.");
   for (auto const& model : models_)
-    model->update_actions_state(NOW, 0.0);
+    model->update_actions_state(now_, 0.0);
 }
 
 double EngineImpl::solve(double max_date) const
@@ -601,9 +527,9 @@ double EngineImpl::solve(double max_date) const
   resource::Resource* resource = nullptr;
 
   if (max_date != -1.0) {
-    xbt_assert(max_date >= NOW, "You asked to simulate up to %f, but that's in the past already", max_date);
+    xbt_assert(max_date >= now_, "You asked to simulate up to %f, but that's in the past already", max_date);
 
-    time_delta = max_date - NOW;
+    time_delta = max_date - now_;
   }
 
   XBT_DEBUG("Looking for next event in all models");
@@ -611,7 +537,7 @@ double EngineImpl::solve(double max_date) const
     if (not model->next_occurring_event_is_idempotent()) {
       continue;
     }
-    double next_event = model->next_occurring_event(NOW);
+    double next_event = model->next_occurring_event(now_);
     if ((time_delta < 0.0 || next_event < time_delta) && next_event >= 0.0) {
       time_delta = next_event;
     }
@@ -632,9 +558,9 @@ double EngineImpl::solve(double max_date) const
         continue;
 
       if (next_event_date != -1.0) {
-        time_delta = std::min(next_event_date - NOW, time_delta);
+        time_delta = std::min(next_event_date - now_, time_delta);
       } else {
-        time_delta = std::max(next_event_date - NOW, time_delta); // Get the positive component
+        time_delta = std::max(next_event_date - now_, time_delta); // Get the positive component
       }
 
       XBT_DEBUG("Run the NS3 network at most %fs", time_delta);
@@ -646,29 +572,31 @@ double EngineImpl::solve(double max_date) const
         time_delta = model_next_action_end;
     }
 
-    if (next_event_date < 0.0 || (next_event_date > NOW + time_delta)) {
+    if (next_event_date < 0.0 || (next_event_date > now_ + time_delta)) {
       // next event may have already occurred or will after the next resource change, then bail out
       XBT_DEBUG("no next usable TRACE event. Stop searching for it");
       break;
     }
 
-    XBT_DEBUG("Updating models (min = %g, NOW = %g, next_event_date = %g)", time_delta, NOW, next_event_date);
+    XBT_DEBUG("Updating models (min = %g, NOW = %g, next_event_date = %g)", time_delta, now_, next_event_date);
 
     while (auto* event = profile::future_evt_set.pop_leq(next_event_date, &value, &resource)) {
+      if(value<0)
+	      continue;
       if (resource->is_used() || (watched_hosts().find(resource->get_cname()) != watched_hosts().end())) {
-        time_delta = next_event_date - NOW;
+        time_delta = next_event_date - now_;
         XBT_DEBUG("This event invalidates the next_occurring_event() computation of models. Next event set to %f",
                   time_delta);
       }
-      // FIXME: I'm too lame to update NOW live, so I change it and restore it so that the real update with surf_min
+      // FIXME: I'm too lame to update now_ live, so I change it and restore it so that the real update with surf_min
       // will work
-      double round_start = NOW;
-      NOW                = next_event_date;
+      double round_start = now_;
+      now_               = next_event_date;
       /* update state of the corresponding resource to the new value. Does not touch lmm.
          It will be modified if needed when updating actions */
       XBT_DEBUG("Calling update_resource_state for resource %s", resource->get_cname());
       resource->apply_event(event, value);
-      NOW = round_start;
+      now_ = round_start;
     }
   }
 
@@ -685,11 +613,11 @@ double EngineImpl::solve(double max_date) const
   XBT_DEBUG("Duration set to %f", time_delta);
 
   // Bump the time: jump into the future
-  NOW = NOW + time_delta;
+  now_ += time_delta;
 
   // Inform the models of the date change
   for (auto const& model : models_)
-    model->update_actions_state(NOW, time_delta);
+    model->update_actions_state(now_, time_delta);
 
   s4u::Engine::on_time_advance(time_delta);
 
@@ -700,8 +628,17 @@ void EngineImpl::run(double max_date)
 {
   seal_platform();
 
+  if (MC_is_active()) {
+#if SIMGRID_HAVE_MC
+    mc::AppSide::get()->main_loop();
+#else
+    xbt_die("MC_is_active() is not supposed to return true in non-MC settings");
+#endif
+    THROW_IMPOSSIBLE; // main_loop never returns
+  }
+
   if (MC_record_replay_is_active()) {
-    mc::replay(MC_record_path());
+    mc::RecordTrace::replay(MC_record_path());
     empty_trash();
     return;
   }
@@ -714,7 +651,7 @@ void EngineImpl::run(double max_date)
 
     if (cfg_breakpoint >= 0.0 && simgrid_get_clock() >= cfg_breakpoint) {
       XBT_DEBUG("Breakpoint reached (%g)", cfg_breakpoint.get());
-      cfg_breakpoint = -1.0;
+      cfg_breakpoint = -1.0; // Let the simulation continue without hiting the breakpoint again and again
 #ifdef SIGTRAP
       std::raise(SIGTRAP);
 #else
@@ -722,86 +659,22 @@ void EngineImpl::run(double max_date)
 #endif
     }
 
-    execute_tasks();
-
     while (not actors_to_run_.empty()) {
       XBT_DEBUG("New Sub-Schedule Round; size(queue)=%zu", actors_to_run_.size());
 
       /* Run all actors that are ready to run, possibly in parallel */
       run_all_actors();
 
-      /* answer sequentially and in a fixed arbitrary order all the simcalls that were issued during that sub-round */
-
-      /* WARNING, the order *must* be fixed or you'll jeopardize the simulation reproducibility (see RR-7653) */
-
-      /* Here, the order is ok because:
-       *
-       *   Short proof: only maestro adds stuff to the actors_to_run array, so the execution order of user contexts do
-       *   not impact its order.
-       *
-       *   Long proof: actors remain sorted through an arbitrary (implicit, complex but fixed) order in all cases.
-       *
-       *   - if there is no kill during the simulation, actors remain sorted according by their PID.
-       *     Rationale: This can be proved inductively.
-       *        Assume that actors_to_run is sorted at a beginning of one round (it is at round 0: the deployment file
-       *        is parsed linearly).
-       *        Let's show that it is still so at the end of this round.
-       *        - if an actor is added when being created, that's from maestro. It can be either at startup
-       *          time (and then in PID order), or in response to a process_create simcall. Since simcalls are handled
-       *          in arbitrary order (inductive hypothesis), we are fine.
-       *        - If an actor is added because it's getting killed, its subsequent actions shouldn't matter
-       *        - If an actor gets added to actors_to_run because one of their blocking action constituting the meat
-       *          of a simcall terminates, we're still good. Proof:
-       *          - You are added from ActorImpl::simcall_answer() only. When this function is called depends on the
-       *            resource kind (network, cpu, disk, whatever), but the same arguments hold. Let's take communications
-       *            as an example.
-       *          - For communications, this function is called from CommImpl::finish().
-       *            This function itself don't mess with the order since simcalls are handled in FIFO order.
-       *            The function is called:
-       *            - before the comm starts (invalid parameters, or resource already dead or whatever).
-       *              The order then trivial holds since maestro didn't interrupt its handling of the simcall yet
-       *            - because the communication failed or were canceled after startup. In this case, it's called from
-       *              the function we are in, by the chunk:
-       *                       set = model->states.failed_action_set;
-       *                       while ((synchro = extract(set)))
-       *                          SIMIX_simcall_post((smx_synchro_t) synchro->data);
-       *              This order is also fixed because it depends of the order in which the surf actions were
-       *              added to the system, and only maestro can add stuff this way, through simcalls.
-       *              We thus use the inductive hypothesis once again to conclude that the order in which synchros are
-       *              popped out of the set does not depend on the user code's execution order.
-       *            - because the communication terminated. In this case, synchros are served in the order given by
-       *                       set = model->states.done_action_set;
-       *                       while ((synchro = extract(set)))
-       *                          SIMIX_simcall_post((smx_synchro_t) synchro->data);
-       *              and the argument is very similar to the previous one.
-       *            So, in any case, the orders of calls to CommImpl::finish() do not depend on the order in which user
-       *            actors are executed.
-       *          So, in any cases, the orders of actors within actors_to_run do not depend on the order in which
-       *          user actors were executed previously.
-       *     So, if there is no killing in the simulation, the simulation reproducibility is not jeopardized.
-       *   - If there is some actor killings, the order is changed by this decision that comes from user-land
-       *     But this decision may not have been motivated by a situation that were different because the simulation is
-       *     not reproducible.
-       *     So, even the order change induced by the actor killing is perfectly reproducible.
-       *
-       *   So science works, bitches [http://xkcd.com/54/].
-       *
-       *   We could sort the actors_that_ran array completely so that we can describe the order in which simcalls are
-       *   handled (like "according to the PID of issuer"), but it's not mandatory (order is fixed already even if
-       *   unfriendly).
-       *   That would thus be a pure waste of time.
+      /* answer sequentially and in a fixed arbitrary order all the simcalls that were issued during that sub-round.
+       * The order must be fixed for the simulation to be reproducible (see RR-7653). It's OK here because only maestro
+       * changes the list. Killer actors are moved to the end to let victims finish their simcall before dying, but
+       * the order remains reproducible (even if arbitrarily). No need to sort the vector for sake of reproducibility.
        */
-
-      for (auto const& actor : actors_that_ran_) {
-        if (actor->simcall_.call_ != simix::Simcall::NONE) {
+      for (auto const& actor : actors_that_ran_)
+        if (actor->simcall_.call_ != actor::Simcall::Type::NONE)
           actor->simcall_handle(0);
-        }
-      }
 
-      execute_tasks();
-      do {
-        wake_all_waiting_actors();
-      } while (execute_tasks());
+      handle_ended_actions();
 
       /* If only daemon actors remain, cancel their actions, mark them to die and reschedule them */
       if (actor_list_.size() == daemons_.size())
@@ -820,21 +693,15 @@ void EngineImpl::run(double max_date)
       next_time = std::min(next_time, max_date);
     }
 
-    XBT_DEBUG("Calling solve(%g) %g", next_time, NOW);
+    XBT_DEBUG("Calling solve(%g) %g", next_time, now_);
     elapsed_time = solve(next_time);
-    XBT_DEBUG("Moving time ahead. NOW=%g; elapsed: %g", NOW, elapsed_time);
+    XBT_DEBUG("Moving time ahead. NOW=%g; elapsed: %g", now_, elapsed_time);
 
-    /* Notify all the hosts that have failed */
-    /* FIXME: iterate through the list of failed host and mark each of them */
-    /* as failed. On each host, signal all the running actors with host_fail */
-
-    // Execute timers and tasks until there isn't anything to be done:
+    // Execute timers until there isn't anything to be done:
     bool again = false;
     do {
       again = timer::Timer::execute_all();
-      if (execute_tasks())
-        again = true;
-      wake_all_waiting_actors();
+      handle_ended_actions();
     } while (again);
 
     /* Clean actors to destroy */
@@ -848,17 +715,18 @@ void EngineImpl::run(double max_date)
         XBT_CRITICAL("Oops! Daemon actors cannot do any blocking activity (communications, synchronization, etc) "
                      "once the simulation is over. Please fix your on_exit() functions.");
       } else {
-        XBT_CRITICAL("Oops! Deadlock or code not perfectly clean.");
+        XBT_CRITICAL("Oops! Deadlock detected, some activities are still around but will never complete. "
+                     "This usually happens when the user code is not perfectly clean.");
       }
       display_all_actor_status();
       simgrid::s4u::Engine::on_deadlock();
-      for (auto const& kv : actor_list_) {
-        XBT_DEBUG("Kill %s", kv.second->get_cname());
-        maestro_->kill(kv.second);
+      for (auto const& [_, actor] : actor_list_) {
+        XBT_DEBUG("Kill %s", actor->get_cname());
+        maestro_->kill(actor);
       }
     }
   } while ((vetoed_activities == nullptr || vetoed_activities->empty()) &&
-           ((elapsed_time > -1.0 && not double_equals(max_date, NOW, 0.00001)) || has_actors_to_run()));
+           ((elapsed_time > -1.0 && not double_equals(max_date, now_, 0.00001)) || has_actors_to_run()));
 
   if (not actor_list_.empty() && max_date < 0 && not(vetoed_activities == nullptr || vetoed_activities->empty()))
     THROW_IMPOSSIBLE;
@@ -868,12 +736,6 @@ void EngineImpl::run(double max_date)
 
 double EngineImpl::get_clock()
 {
-  return NOW;
-}
-} // namespace kernel
-} // namespace simgrid
-
-void SIMIX_run() // XBT_ATTRIB_DEPRECATED_v332
-{
-  simgrid::kernel::EngineImpl::get_instance()->run(-1);
+  return now_;
 }
+} // namespace simgrid::kernel
