@@ -6,8 +6,9 @@
 #ifndef SIMGRID_KERNEL_ACTIVITY_ACTIVITYIMPL_HPP
 #define SIMGRID_KERNEL_ACTIVITY_ACTIVITYIMPL_HPP
 
-#include <string>
 #include <list>
+#include <string>
+#include <string_view>
 
 #include "simgrid/forward.h"
 #include <xbt/utility.hpp>
@@ -16,36 +17,38 @@
 #include <simgrid/kernel/resource/Action.hpp>
 #include <simgrid/simix.hpp>
 
-namespace simgrid {
-namespace kernel {
-namespace activity {
+namespace simgrid::kernel::activity {
 
 XBT_DECLARE_ENUM_CLASS(State, WAITING, READY, RUNNING, DONE, CANCELED, FAILED, SRC_HOST_FAILURE, DST_HOST_FAILURE,
                        TIMEOUT, SRC_TIMEOUT, DST_TIMEOUT, LINK_FAILURE);
 
 class XBT_PUBLIC ActivityImpl {
   std::atomic_int_fast32_t refcount_{0};
-  std::string name_ = "";
+  std::string name_        = "";
   actor::ActorImpl* actor_ = nullptr;
   State state_             = State::WAITING; /* State of the activity */
   double start_time_       = -1.0;
   double finish_time_      = -1.0;
+  std::vector<s4u::Host*> hosts_;
 
 public:
   virtual ~ActivityImpl();
   ActivityImpl() = default;
-  std::list<smx_simcall_t> simcalls_;   /* List of simcalls waiting for this activity */
+  std::list<actor::Simcall*> simcalls_; /* List of simcalls waiting for this activity */
   s4u::Activity* piface_         = nullptr;
   resource::Action* surf_action_ = nullptr;
 
 protected:
-  void inline set_name(const std::string& name)
+  void inline set_name(std::string_view name)
   {
     // This is to keep name_ private while allowing ActivityImpl_T<??> to set it and then return a Ptr to qualified
     // child type
     name_ = name;
   }
   void set_start_time(double start_time) { start_time_ = start_time; }
+  void clear_hosts() { hosts_.clear(); }
+  void add_host(s4u::Host* host) { hosts_.push_back(host); }
+  void set_hosts(const std::vector<s4u::Host*>& hosts) { hosts_ = hosts; }
 
 public:
   const std::string& get_name() const { return name_; }
@@ -65,8 +68,11 @@ public:
   void set_finish_time(double finish_time) { finish_time_ = finish_time; }
   double get_finish_time() const { return finish_time_; }
 
-  virtual bool test();
+  virtual bool test(actor::ActorImpl* issuer);
+  static ssize_t test_any(actor::ActorImpl* issuer, const std::vector<ActivityImpl*>& activities);
+
   virtual void wait_for(actor::ActorImpl* issuer, double timeout);
+  static void wait_any_for(actor::ActorImpl* issuer, const std::vector<ActivityImpl*>& activities, double timeout);
   virtual ActivityImpl& set_timeout(double) { THROW_UNIMPLEMENTED; }
 
   virtual void suspend();
@@ -79,16 +85,18 @@ public:
   virtual void finish() = 0; // Unlock all simcalls blocked on that activity, either because it was marked as done by
                              // the model or because it terminated without waiting for the model
 
-  void register_simcall(smx_simcall_t simcall);
-  void unregister_simcall(smx_simcall_t simcall);
+  s4u::Host* get_host() const { return hosts_.front(); }
+  const std::vector<s4u::Host*>& get_hosts() const { return hosts_; };
+
+  void register_simcall(actor::Simcall* simcall);
+  void unregister_simcall(actor::Simcall* simcall);
+  void handle_activity_waitany(actor::Simcall* simcall);
   void clean_action();
   virtual double get_remaining() const;
   // Support for the boost::intrusive_ptr<ActivityImpl> datatype
   friend XBT_PUBLIC void intrusive_ptr_add_ref(ActivityImpl* activity);
   friend XBT_PUBLIC void intrusive_ptr_release(ActivityImpl* activity);
-
-  static xbt::signal<void(ActivityImpl const&)> on_suspended;
-  static xbt::signal<void(ActivityImpl const&)> on_resumed;
+  int get_refcount() const { return static_cast<int>(refcount_); } // For debugging purpose
 };
 
 /* This class exists to allow chained setters as in exec->set_name()->set_priority()->set_blah()
@@ -98,13 +106,13 @@ template <class AnyActivityImpl> class ActivityImpl_T : public ActivityImpl {
   std::string tracing_category_ = "";
 
 public:
-  AnyActivityImpl& set_name(const std::string& name) /* Hides the function in the ancestor class */
+  AnyActivityImpl& set_name(std::string_view name) /* Hides the function in the ancestor class */
   {
     ActivityImpl::set_name(name);
     return static_cast<AnyActivityImpl&>(*this);
   }
 
-  AnyActivityImpl& set_tracing_category(const std::string& category)
+  AnyActivityImpl& set_tracing_category(std::string_view category)
   {
     tracing_category_ = category;
     return static_cast<AnyActivityImpl&>(*this);
@@ -112,8 +120,6 @@ public:
   const std::string& get_tracing_category() const { return tracing_category_; }
 };
 
-} // namespace activity
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::activity
 
 #endif /* SIMGRID_KERNEL_ACTIVITY_ACTIVITYIMPL_HPP */
