@@ -8,201 +8,20 @@
 #include <simgrid/modelchecker.h>
 #include <simgrid/s4u/Host.hpp>
 
+#define SIMIX_H_NO_DEPRECATED_WARNING // avoid deprecation warning on include (remove with XBT_ATTRIB_DEPRECATED_v333)
+#include <simgrid/simix.h>
+
+#include "src/kernel/EngineImpl.hpp"
 #include "src/kernel/activity/CommImpl.hpp"
 #include "src/kernel/activity/MailboxImpl.hpp"
-#include "src/kernel/context/Context.hpp"
+#include "src/kernel/actor/SimcallObserver.hpp"
 #include "src/kernel/resource/CpuImpl.hpp"
-#include "src/kernel/resource/LinkImpl.hpp"
+#include "src/kernel/resource/NetworkModel.hpp"
 #include "src/kernel/resource/StandardLinkImpl.hpp"
 #include "src/mc/mc_replay.hpp"
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(ker_network, kernel, "Kernel network-related synchronization");
 
-XBT_PRIVATE void simcall_HANDLER_comm_send(smx_simcall_t simcall, smx_actor_t src, smx_mailbox_t mbox, double task_size,
-                                           double rate, unsigned char* src_buff, size_t src_buff_size,
-                                           bool (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*),
-                                           void (*copy_data_fun)(simgrid::kernel::activity::CommImpl*, void*, size_t),
-                                           void* data, double timeout)
-{
-  simgrid::kernel::activity::ActivityImplPtr comm = simcall_HANDLER_comm_isend(
-      simcall, src, mbox, task_size, rate, src_buff, src_buff_size, match_fun, nullptr, copy_data_fun, data, false);
-  simcall->mc_value_ = 0;
-  comm->wait_for(simcall->issuer_, timeout);
-}
-
-XBT_PRIVATE simgrid::kernel::activity::ActivityImplPtr simcall_HANDLER_comm_isend(
-    smx_simcall_t /*simcall*/, smx_actor_t src_proc, smx_mailbox_t mbox, double task_size, double rate,
-    unsigned char* src_buff, size_t src_buff_size,
-    bool (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*),
-    void (*clean_fun)(void*), // used to free the synchro in case of problem after a detached send
-    void (*copy_data_fun)(simgrid::kernel::activity::CommImpl*, void*, size_t), // used to copy data if not default one
-    void* data, bool detached)
-{
-  XBT_DEBUG("send from mailbox %p", mbox);
-
-  /* Prepare a synchro describing us, so that it gets passed to the user-provided filter of other side */
-  simgrid::kernel::activity::CommImplPtr this_comm(
-      new simgrid::kernel::activity::CommImpl(simgrid::kernel::activity::CommImpl::Type::SEND));
-
-  /* Look for communication synchro matching our needs. We also provide a description of
-   * ourself so that the other side also gets a chance of choosing if it wants to match with us.
-   *
-   * If it is not found then push our communication into the rendez-vous point */
-  simgrid::kernel::activity::CommImplPtr other_comm =
-      mbox->find_matching_comm(simgrid::kernel::activity::CommImpl::Type::RECEIVE, match_fun, data, this_comm,
-                               /*done*/ false, /*remove_matching*/ true);
-
-  if (not other_comm) {
-    other_comm = std::move(this_comm);
-
-    if (mbox->is_permanent()) {
-      // this mailbox is for small messages, which have to be sent right now
-      other_comm->set_state(simgrid::kernel::activity::State::READY);
-      other_comm->dst_actor_ = mbox->get_permanent_receiver().get();
-      mbox->push_done(other_comm);
-      XBT_DEBUG("pushing a message into the permanent receive list %p, comm %p", mbox, other_comm.get());
-
-    } else {
-      mbox->push(other_comm);
-    }
-  } else {
-    XBT_DEBUG("Receive already pushed");
-
-    other_comm->set_state(simgrid::kernel::activity::State::READY);
-  }
-
-  if (detached) {
-    other_comm->detach();
-    other_comm->clean_fun = clean_fun;
-  } else {
-    other_comm->clean_fun = nullptr;
-    src_proc->activities_.emplace_back(other_comm);
-  }
-
-  /* Setup the communication synchro */
-  other_comm->src_actor_ = src_proc;
-  other_comm->src_data_  = data;
-  (*other_comm).set_src_buff(src_buff, src_buff_size).set_size(task_size).set_rate(rate);
-
-  other_comm->match_fun     = match_fun;
-  other_comm->copy_data_fun = copy_data_fun;
-
-  if (MC_is_active() || MC_record_replay_is_active())
-    other_comm->set_state(simgrid::kernel::activity::State::RUNNING);
-  else
-    other_comm->start();
-
-  return (detached ? nullptr : other_comm);
-}
-
-XBT_PRIVATE void simcall_HANDLER_comm_recv(smx_simcall_t simcall, smx_actor_t receiver, smx_mailbox_t mbox,
-                                           unsigned char* dst_buff, size_t* dst_buff_size,
-                                           bool (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*),
-                                           void (*copy_data_fun)(simgrid::kernel::activity::CommImpl*, void*, size_t),
-                                           void* data, double timeout, double rate)
-{
-  simgrid::kernel::activity::ActivityImplPtr comm = simcall_HANDLER_comm_irecv(
-      simcall, receiver, mbox, dst_buff, dst_buff_size, match_fun, copy_data_fun, data, rate);
-  simcall->mc_value_ = 0;
-  comm->wait_for(simcall->issuer_, timeout);
-}
-
-XBT_PRIVATE simgrid::kernel::activity::ActivityImplPtr
-simcall_HANDLER_comm_irecv(smx_simcall_t /*simcall*/, smx_actor_t receiver, smx_mailbox_t mbox, unsigned char* dst_buff,
-                           size_t* dst_buff_size, bool (*match_fun)(void*, void*, simgrid::kernel::activity::CommImpl*),
-                           void (*copy_data_fun)(simgrid::kernel::activity::CommImpl*, void*, size_t), void* data,
-                           double rate)
-{
-  simgrid::kernel::activity::CommImplPtr this_synchro(
-      new simgrid::kernel::activity::CommImpl(simgrid::kernel::activity::CommImpl::Type::RECEIVE));
-  XBT_DEBUG("recv from mbox %p. this_synchro=%p", mbox, this_synchro.get());
-
-  simgrid::kernel::activity::CommImplPtr other_comm;
-  // communication already done, get it inside the list of completed comms
-  if (mbox->is_permanent() && mbox->has_some_done_comm()) {
-    XBT_DEBUG("We have a comm that has probably already been received, trying to match it, to skip the communication");
-    // find a match in the list of already received comms
-    other_comm = mbox->find_matching_comm(simgrid::kernel::activity::CommImpl::Type::SEND, match_fun, data,
-                                          this_synchro, /*done*/ true,
-                                          /*remove_matching*/ true);
-    // if not found, assume the receiver came first, register it to the mailbox in the classical way
-    if (not other_comm) {
-      XBT_DEBUG("We have messages in the permanent receive list, but not the one we are looking for, pushing request "
-                "into list");
-      other_comm = std::move(this_synchro);
-      mbox->push(other_comm);
-    } else {
-      if (other_comm->surf_action_ && other_comm->get_remaining() < 1e-12) {
-        XBT_DEBUG("comm %p has been already sent, and is finished, destroy it", other_comm.get());
-        other_comm->set_state(simgrid::kernel::activity::State::DONE);
-        other_comm->set_mailbox(nullptr);
-      }
-    }
-  } else {
-    /* Prepare a comm describing us, so that it gets passed to the user-provided filter of other side */
-
-    /* Look for communication activity matching our needs. We also provide a description of
-     * ourself so that the other side also gets a chance of choosing if it wants to match with us.
-     *
-     * If it is not found then push our communication into the rendez-vous point */
-    other_comm = mbox->find_matching_comm(simgrid::kernel::activity::CommImpl::Type::SEND, match_fun, data,
-                                          this_synchro, /*done*/ false,
-                                          /*remove_matching*/ true);
-
-    if (other_comm == nullptr) {
-      XBT_DEBUG("Receive pushed first (%zu comm enqueued so far)", mbox->size());
-      other_comm = std::move(this_synchro);
-      mbox->push(other_comm);
-    } else {
-      XBT_DEBUG("Match my %p with the existing %p", this_synchro.get(), other_comm.get());
-
-      other_comm->set_state(simgrid::kernel::activity::State::READY);
-    }
-    receiver->activities_.emplace_back(other_comm);
-  }
-
-  /* Setup communication synchro */
-  other_comm->dst_actor_ = receiver;
-  other_comm->dst_data_  = data;
-  other_comm->set_dst_buff(dst_buff, dst_buff_size);
-
-  if (rate > -1.0 && (other_comm->get_rate() < 0.0 || rate < other_comm->get_rate()))
-    other_comm->set_rate(rate);
-
-  other_comm->match_fun     = match_fun;
-  other_comm->copy_data_fun = copy_data_fun;
-
-  if (MC_is_active() || MC_record_replay_is_active()) {
-    other_comm->set_state(simgrid::kernel::activity::State::RUNNING);
-    return other_comm;
-  }
-  other_comm->start();
-  return other_comm;
-}
-
-void simcall_HANDLER_comm_wait(smx_simcall_t simcall, simgrid::kernel::activity::CommImpl* comm, double timeout)
-{
-  comm->wait_for(simcall->issuer_, timeout);
-}
-
-bool simcall_HANDLER_comm_test(smx_simcall_t, simgrid::kernel::activity::CommImpl* comm)
-{
-  return comm->test();
-}
-
-ssize_t simcall_HANDLER_comm_testany(smx_simcall_t simcall, simgrid::kernel::activity::CommImpl* comms[], size_t count)
-{
-  std::vector<simgrid::kernel::activity::CommImpl*> comms_vec(comms, comms + count);
-  return simgrid::kernel::activity::CommImpl::test_any(simcall->issuer_, comms_vec);
-}
-
-void simcall_HANDLER_comm_waitany(smx_simcall_t simcall, simgrid::kernel::activity::CommImpl* comms[], size_t count,
-                                  double timeout)
-{
-  std::vector<simgrid::kernel::activity::CommImpl*> comms_vec(comms, comms + count);
-  simgrid::kernel::activity::CommImpl::wait_any_for(simcall->issuer_, comms_vec, timeout);
-}
-
 /******************************************************************************/
 /*                    SIMIX_comm_copy_data callbacks                       */
 /******************************************************************************/
@@ -224,19 +43,39 @@ void SIMIX_comm_copy_pointer_callback(simgrid::kernel::activity::CommImpl* comm,
   simgrid::s4u::Comm::copy_pointer_callback(comm, buff, buff_size);
 }
 
-namespace simgrid {
-namespace kernel {
-namespace activity {
+namespace simgrid::kernel::activity {
 xbt::signal<void(CommImpl const&)> CommImpl::on_start;
 xbt::signal<void(CommImpl const&)> CommImpl::on_completion;
 
-void (*CommImpl::copy_data_callback_)(CommImpl*, void*, size_t) = &s4u::Comm::copy_pointer_callback;
+std::function<void(CommImpl*, void*, size_t)> CommImpl::copy_data_callback_ = &s4u::Comm::copy_pointer_callback;
 
-void CommImpl::set_copy_data_callback(void (*callback)(CommImpl*, void*, size_t))
+void CommImpl::set_copy_data_callback(const std::function<void(CommImpl*, void*, size_t)>& callback)
 {
   copy_data_callback_ = callback;
 }
 
+CommImpl& CommImpl::set_type(CommImplType type)
+{
+  type_ = type;
+  return *this;
+}
+
+CommImpl& CommImpl::set_source(s4u::Host* from)
+{
+  xbt_assert( from_ == nullptr );
+  from_ = from;
+  add_host(from);
+  return *this;
+}
+
+CommImpl& CommImpl::set_destination(s4u::Host* to)
+{
+  xbt_assert( to_ == nullptr );
+  to_ = to;
+  add_host(to_);
+  return *this;
+}
+
 CommImpl& CommImpl::set_size(double size)
 {
   size_ = size;
@@ -250,6 +89,8 @@ CommImpl& CommImpl::set_rate(double rate)
 }
 CommImpl& CommImpl::set_mailbox(MailboxImpl* mbox)
 {
+  if (mbox != nullptr)
+    mbox_id_ = mbox->get_id();
   mbox_ = mbox;
   return *this;
 }
@@ -271,14 +112,10 @@ CommImpl& CommImpl::set_dst_buff(unsigned char* buff, size_t* size)
 CommImpl& CommImpl::detach()
 {
   detached_ = true;
+  EngineImpl::get_instance()->get_maestro()->activities_.emplace_back(this);
   return *this;
 }
 
-CommImpl::CommImpl(s4u::Host* from, s4u::Host* to, double bytes) : size_(bytes), detached_(true), from_(from), to_(to)
-{
-  set_state(State::READY);
-}
-
 CommImpl::~CommImpl()
 {
   XBT_DEBUG("Really free communication %p in state %s (detached = %d)", this, get_state_str(), detached_);
@@ -302,7 +139,10 @@ CommImpl* CommImpl::start()
   /* If both the sender and the receiver are already there, start the communication */
   if (get_state() == State::READY) {
     from_ = from_ != nullptr ? from_ : src_actor_->get_host();
+    xbt_assert(from_->is_on());
     to_   = to_ != nullptr ? to_ : dst_actor_->get_host();
+    xbt_assert(to_->is_on());
+
     /* Getting the network_model from the origin host
      * Valid while we have a single network model, otherwise we would need to change this function to first get the
      * routes and later create the respective surf actions */
@@ -387,11 +227,147 @@ void CommImpl::copy_data()
   copied_ = true;
 }
 
-bool CommImpl::test()
+ActivityImplPtr CommImpl::isend(actor::CommIsendSimcall* observer)
+{
+  auto* mbox = observer->get_mailbox();
+  XBT_DEBUG("send from mailbox %p", mbox);
+
+  /* Prepare a synchro describing us, so that it gets passed to the user-provided filter of other side */
+  CommImplPtr this_comm(new CommImpl());
+  this_comm->set_type(CommImplType::SEND);
+
+  /* Look for communication synchro matching our needs. We also provide a description of
+   * ourself so that the other side also gets a chance of choosing if it wants to match with us.
+   *
+   * If it is not found then push our communication into the rendez-vous point */
+  CommImplPtr other_comm =
+      mbox->find_matching_comm(CommImplType::RECEIVE, observer->get_match_fun(), observer->get_payload(), this_comm,
+                               /*done*/ false, /*remove_matching*/ true);
+
+  if (not other_comm) {
+    other_comm = std::move(this_comm);
+
+    if (mbox->is_permanent()) {
+      // this mailbox is for small messages, which have to be sent right now
+      other_comm->set_state(State::READY);
+      other_comm->dst_actor_ = mbox->get_permanent_receiver().get();
+      mbox->push_done(other_comm);
+      XBT_DEBUG("pushing a message into the permanent receive list %p, comm %p", mbox, other_comm.get());
+
+    } else {
+      mbox->push(other_comm);
+    }
+  } else {
+    XBT_DEBUG("Receive already pushed");
+
+    other_comm->set_state(State::READY);
+  }
+  observer->set_comm(other_comm.get());
+
+  if (observer->is_detached()) {
+    other_comm->detach();
+    other_comm->clean_fun = observer->get_clean_fun();
+  } else {
+    other_comm->clean_fun = nullptr;
+    observer->get_issuer()->activities_.emplace_back(other_comm);
+  }
+
+  /* Setup the communication synchro */
+  other_comm->src_actor_ = observer->get_issuer();
+  other_comm->src_data_  = observer->get_payload();
+  (*other_comm)
+      .set_src_buff(observer->get_src_buff(), observer->get_src_buff_size())
+      .set_size(observer->get_payload_size())
+      .set_rate(observer->get_rate());
+
+  other_comm->match_fun     = observer->get_match_fun();
+  other_comm->copy_data_fun = observer->get_copy_data_fun();
+
+  if (MC_is_active() || MC_record_replay_is_active())
+    other_comm->set_state(simgrid::kernel::activity::State::RUNNING);
+  else
+    other_comm->start();
+
+  return (observer->is_detached() ? nullptr : other_comm);
+}
+
+ActivityImplPtr CommImpl::irecv(actor::CommIrecvSimcall* observer)
+{
+  CommImplPtr this_synchro(new CommImpl());
+  this_synchro->set_type(CommImplType::RECEIVE);
+
+  auto* mbox = observer->get_mailbox();
+  XBT_DEBUG("recv from mbox %p. this_synchro=%p", mbox, this_synchro.get());
+
+  CommImplPtr other_comm;
+  // communication already done, get it inside the list of completed comms
+  if (mbox->is_permanent() && mbox->has_some_done_comm()) {
+    XBT_DEBUG("We have a comm that has probably already been received, trying to match it, to skip the communication");
+    // find a match in the list of already received comms
+    other_comm = mbox->find_matching_comm(CommImplType::SEND, observer->get_match_fun(), observer->get_payload(),
+                                          this_synchro, /*done*/ true, /*remove_matching*/ true);
+    if (other_comm  && other_comm->surf_action_ && other_comm->get_remaining() < 1e-12) {
+      XBT_DEBUG("comm %p has been already sent, and is finished, destroy it", other_comm.get());
+      other_comm->set_state(State::DONE);
+      other_comm->set_mailbox(nullptr);
+    } else {
+      // if not found, assume the receiver came first, register it to the mailbox in the classical way
+      if (not other_comm) {
+        XBT_DEBUG("We have messages in the permanent receive list, but not the one we are looking for, pushing request "
+                  "into list");
+        other_comm = std::move(this_synchro);
+        mbox->push(other_comm);
+      }
+      observer->get_issuer()->activities_.emplace_back(other_comm);
+    }
+  } else {
+    /* Prepare a comm describing us, so that it gets passed to the user-provided filter of other side */
+
+    /* Look for communication activity matching our needs. We also provide a description of
+     * ourself so that the other side also gets a chance of choosing if it wants to match with us.
+     *
+     * If it is not found then push our communication into the rendez-vous point */
+    other_comm = mbox->find_matching_comm(CommImplType::SEND, observer->get_match_fun(), observer->get_payload(),
+                                          this_synchro, /*done*/ false, /*remove_matching*/ true);
+
+    if (other_comm == nullptr) {
+      XBT_DEBUG("Receive pushed first (%zu comm enqueued so far)", mbox->size());
+      other_comm = std::move(this_synchro);
+      mbox->push(other_comm);
+    } else {
+      XBT_DEBUG("Match my %p with the existing %p", this_synchro.get(), other_comm.get());
+
+      other_comm->set_state(simgrid::kernel::activity::State::READY);
+    }
+    observer->get_issuer()->activities_.emplace_back(other_comm);
+  }
+  observer->set_comm(other_comm.get());
+
+  /* Setup communication synchro */
+  other_comm->dst_actor_ = observer->get_issuer();
+  other_comm->dst_data_  = observer->get_payload();
+  other_comm->set_dst_buff(observer->get_dst_buff(), observer->get_dst_buff_size());
+
+  if (observer->get_rate() > -1.0 && (other_comm->get_rate() < 0.0 || observer->get_rate() < other_comm->get_rate()))
+    other_comm->set_rate(observer->get_rate());
+
+  other_comm->match_fun     = observer->get_match_fun();
+  other_comm->copy_data_fun = observer->get_copy_data_fun();
+
+  if (MC_is_active() || MC_record_replay_is_active()) {
+    other_comm->set_state(State::RUNNING);
+    return other_comm;
+  }
+  other_comm->start();
+
+  return other_comm;
+}
+
+bool CommImpl::test(actor::ActorImpl* issuer)
 {
   if ((MC_is_active() || MC_record_replay_is_active()) && src_actor_ && dst_actor_)
     set_state(State::DONE);
-  return ActivityImpl::test();
+  return ActivityImpl::test(issuer);
 }
 
 void CommImpl::wait_for(actor::ActorImpl* issuer, double timeout)
@@ -400,89 +376,19 @@ void CommImpl::wait_for(actor::ActorImpl* issuer, double timeout)
 
   /* Associate this simcall to the wait synchro */
   register_simcall(&issuer->simcall_);
-
   if (MC_is_active() || MC_record_replay_is_active()) {
-    int idx = issuer->simcall_.mc_value_;
-    if (idx == 0) {
-      set_state(State::DONE);
-    } else {
-      /* If we reached this point, the wait simcall must have a timeout */
-      /* Otherwise it shouldn't be enabled and executed by the MC */
-      if (timeout < 0.0)
-        THROW_IMPOSSIBLE;
-      set_state(issuer == src_actor_ ? State::SRC_TIMEOUT : State::DST_TIMEOUT);
-    }
+    // FIXME: what about timeouts?
+    set_state(State::DONE);
     finish();
     return;
   }
-
-  /* If the synchro has already finish perform the error handling, */
-  /* otherwise set up a waiting timeout on the right side          */
-  if (get_state() != State::WAITING && get_state() != State::RUNNING) {
-    finish();
-  } else { /* we need a sleep action (even when there is no timeout) to be notified of host failures */
-    resource::Action* sleep = issuer->get_host()->get_cpu()->sleep(timeout);
-    sleep->set_activity(this);
-
-    if (issuer == src_actor_)
-      src_timeout_ = sleep;
-    else
-      dst_timeout_ = sleep;
-  }
-}
-
-ssize_t CommImpl::test_any(const actor::ActorImpl* issuer, const std::vector<CommImpl*>& comms)
-{
-  if (MC_is_active() || MC_record_replay_is_active()) {
-    int idx = issuer->simcall_.mc_value_;
-    xbt_assert(idx == -1 || comms[idx]->test());
-    return idx;
-  }
-
-  for (std::size_t i = 0; i < comms.size(); ++i) {
-    if (comms[i]->test())
-      return i;
-  }
-  return -1;
+  ActivityImpl::wait_for(issuer, timeout);
 }
 
 void CommImpl::wait_any_for(actor::ActorImpl* issuer, const std::vector<CommImpl*>& comms, double timeout)
 {
-  if (MC_is_active() || MC_record_replay_is_active()) {
-    xbt_assert(timeout <= 0.0, "Timeout not implemented for waitany in the model-checker");
-    int idx    = issuer->simcall_.mc_value_;
-    auto* comm = comms[idx];
-    comm->simcalls_.push_back(&issuer->simcall_);
-    simcall_comm_waitany__set__result(&issuer->simcall_, idx);
-    comm->set_state(State::DONE);
-    comm->finish();
-    return;
-  }
-
-  if (timeout < 0.0) {
-    issuer->simcall_.timeout_cb_ = nullptr;
-  } else {
-    issuer->simcall_.timeout_cb_ = timer::Timer::set(s4u::Engine::get_clock() + timeout, [issuer, comms]() {
-      // FIXME: Vector `comms' is copied here. Use a reference once its lifetime is extended (i.e. when the simcall is
-      // modernized).
-      issuer->simcall_.timeout_cb_ = nullptr;
-      for (auto* comm : comms)
-        comm->unregister_simcall(&issuer->simcall_);
-      simcall_comm_waitany__set__result(&issuer->simcall_, -1);
-      issuer->simcall_answer();
-    });
-  }
-
-  for (auto* comm : comms) {
-    /* associate this simcall to the the synchro */
-    comm->simcalls_.push_back(&issuer->simcall_);
-
-    /* see if the synchro is already finished */
-    if (comm->get_state() != State::WAITING && comm->get_state() != State::RUNNING) {
-      comm->finish();
-      break;
-    }
-  }
+  std::vector<ActivityImpl*> activities(comms.begin(), comms.end());
+  ActivityImpl::wait_any_for(issuer, activities, timeout);
 }
 
 void CommImpl::suspend()
@@ -540,14 +446,17 @@ void CommImpl::post()
     set_state(State::SRC_TIMEOUT);
   else if (dst_timeout_ && dst_timeout_->get_state() == resource::Action::State::FINISHED)
     set_state(State::DST_TIMEOUT);
-  else if (src_timeout_ && src_timeout_->get_state() == resource::Action::State::FAILED)
+  else if ((from_ && not from_->is_on()) || (src_timeout_ && src_timeout_->get_state() == resource::Action::State::FAILED))
     set_state(State::SRC_HOST_FAILURE);
-  else if (dst_timeout_ && dst_timeout_->get_state() == resource::Action::State::FAILED)
+  else if ((to_ && not to_->is_on()) || (dst_timeout_ && dst_timeout_->get_state() == resource::Action::State::FAILED))
     set_state(State::DST_HOST_FAILURE);
   else if (surf_action_ && surf_action_->get_state() == resource::Action::State::FAILED) {
     set_state(State::LINK_FAILURE);
-  } else
+  } else if (get_state() == State::RUNNING) {
+    xbt_assert(from_ && from_->is_on());
+    xbt_assert(to_ && to_->is_on());
     set_state(State::DONE);
+  }
 
   XBT_DEBUG("CommImpl::post(): comm %p, state %s, src_proc %p, dst_proc %p, detached: %d", this, get_state_str(),
             src_actor_.get(), dst_actor_.get(), detached_);
@@ -576,7 +485,7 @@ void CommImpl::set_exception(actor::ActorImpl* issuer)
 
     case State::SRC_HOST_FAILURE:
       if (issuer == src_actor_)
-        issuer->context_->set_wannadie();
+        issuer->set_wannadie();
       else {
         set_state(State::FAILED);
         issuer->exception_ = std::make_exception_ptr(NetworkFailureException(XBT_THROW_POINT, "Remote peer failed"));
@@ -585,7 +494,7 @@ void CommImpl::set_exception(actor::ActorImpl* issuer)
 
     case State::DST_HOST_FAILURE:
       if (issuer == dst_actor_)
-        issuer->context_->set_wannadie();
+        issuer->set_wannadie();
       else {
         set_state(State::FAILED);
         issuer->exception_ = std::make_exception_ptr(NetworkFailureException(XBT_THROW_POINT, "Remote peer failed"));
@@ -633,61 +542,31 @@ void CommImpl::finish()
   if (get_state() == State::DONE)
     copy_data();
 
+  if (detached_)
+    EngineImpl::get_instance()->get_maestro()->activities_.remove(this);
+
   while (not simcalls_.empty()) {
-    smx_simcall_t simcall = simcalls_.front();
+    actor::Simcall* simcall = simcalls_.front();
     simcalls_.pop_front();
 
     /* If a waitany simcall is waiting for this synchro to finish, then remove it from the other synchros in the waitany
      * list. Afterwards, get the position of the actual synchro in the waitany list and return it as the result of the
      * simcall */
 
-    if (simcall->call_ == simix::Simcall::NONE) // FIXME: maybe a better way to handle this case
-      continue;                                 // if actor handling comm is killed
-    if (simcall->call_ == simix::Simcall::COMM_WAITANY) {
-      CommImpl** comms = simcall_comm_waitany__get__comms(simcall);
-      size_t count     = simcall_comm_waitany__get__count(simcall);
-      for (size_t i = 0; i < count; i++)
-        comms[i]->unregister_simcall(simcall);
-      if (simcall->timeout_cb_) {
-        simcall->timeout_cb_->remove();
-        simcall->timeout_cb_ = nullptr;
-      }
-      if (not MC_is_active() && not MC_record_replay_is_active()) {
-        auto element = std::find(comms, comms + count, this);
-        ssize_t rank = (element != comms + count) ? element - comms : -1;
-        simcall_comm_waitany__set__result(simcall, rank);
-      }
-    }
+    if (simcall->call_ == actor::Simcall::Type::NONE) // FIXME: maybe a better way to handle this case
+      continue;                                       // if actor handling comm is killed
+
+    handle_activity_waitany(simcall);
 
     /* Check out for errors */
 
     if (not simcall->issuer_->get_host()->is_on()) {
-      simcall->issuer_->context_->set_wannadie();
+      simcall->issuer_->set_wannadie();
     } else {
-      set_exception(simcall->issuer_);
-      simcall->issuer_->simcall_answer();
-    }
-    /* if there is an exception during a waitany or a testany, indicate the position of the failed communication */
-    if (simcall->issuer_->exception_ &&
-        (simcall->call_ == simix::Simcall::COMM_WAITANY || simcall->call_ == simix::Simcall::COMM_TESTANY)) {
-      // First retrieve the rank of our failing synchro
-      CommImpl** comms;
-      size_t count;
-      if (simcall->call_ == simix::Simcall::COMM_WAITANY) {
-        comms = simcall_comm_waitany__get__comms(simcall);
-        count = simcall_comm_waitany__get__count(simcall);
-      } else {
-        /* simcall->call_ == simix::Simcall::COMM_TESTANY */
-        comms = simcall_comm_testany__get__comms(simcall);
-        count = simcall_comm_testany__get__count(simcall);
-      }
-      auto element = std::find(comms, comms + count, this);
-      ssize_t rank = (element != comms + count) ? element - comms : -1;
-      // In order to modify the exception we have to rethrow it:
-      try {
-        std::rethrow_exception(simcall->issuer_->exception_);
-      } catch (Exception& e) {
-        e.set_value(rank);
+      // Do not answer to dying actors
+      if (not simcall->issuer_->wannadie()) {
+        set_exception(simcall->issuer_);
+        simcall->issuer_->simcall_answer();
       }
     }
 
@@ -702,6 +581,4 @@ void CommImpl::finish()
   }
 }
 
-} // namespace activity
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::activity
