@@ -12,16 +12,13 @@
 #include "src/kernel/activity/IoImpl.hpp"
 #include "src/kernel/actor/ActorImpl.hpp"
 #include "src/kernel/actor/SimcallObserver.hpp"
-#include "src/kernel/context/Context.hpp"
 #include "src/kernel/resource/CpuImpl.hpp"
 #include "src/kernel/resource/DiskImpl.hpp"
 #include "src/mc/mc_replay.hpp"
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(ker_io, kernel, "Kernel io-related synchronization");
 
-namespace simgrid {
-namespace kernel {
-namespace activity {
+namespace simgrid::kernel::activity {
 
 IoImpl::IoImpl()
 {
@@ -118,7 +115,7 @@ void IoImpl::set_exception(actor::ActorImpl* issuer)
 {
   switch (get_state()) {
     case State::FAILED:
-      issuer->context_->set_wannadie();
+      issuer->set_wannadie();
       static_cast<s4u::Io*>(get_iface())->complete(s4u::Activity::State::FAILED);
       issuer->exception_ = std::make_exception_ptr(StorageFailureException(XBT_THROW_POINT, "Storage failed"));
       break;
@@ -138,33 +135,17 @@ void IoImpl::finish()
 {
   XBT_DEBUG("IoImpl::finish() in state %s", get_state_str());
   while (not simcalls_.empty()) {
-    smx_simcall_t simcall = simcalls_.front();
+    actor::Simcall* simcall = simcalls_.front();
     simcalls_.pop_front();
 
     /* If a waitany simcall is waiting for this synchro to finish, then remove it from the other synchros in the waitany
      * list. Afterwards, get the position of the actual synchro in the waitany list and return it as the result of the
      * simcall */
 
-    if (simcall->call_ == simix::Simcall::NONE) // FIXME: maybe a better way to handle this case
-      continue;                                 // if process handling comm is killed
-    if (auto* observer = dynamic_cast<kernel::actor::IoWaitanySimcall*>(simcall->observer_)) { // simcall is a wait_any?
-      const auto& ios = observer->get_ios();
+    if (simcall->call_ == actor::Simcall::Type::NONE) // FIXME: maybe a better way to handle this case
+      continue;                                       // if process handling comm is killed
 
-      for (auto* io : ios) {
-        io->unregister_simcall(simcall);
-
-        if (simcall->timeout_cb_) {
-          simcall->timeout_cb_->remove();
-          simcall->timeout_cb_ = nullptr;
-        }
-      }
-
-      if (not MC_is_active() && not MC_record_replay_is_active()) {
-        auto element = std::find(ios.begin(), ios.end(), this);
-        int rank     = element != ios.end() ? static_cast<int>(std::distance(ios.begin(), element)) : -1;
-        observer->set_result(rank);
-      }
-    }
+    handle_activity_waitany(simcall);
 
     set_exception(simcall->issuer_);
 
@@ -173,32 +154,4 @@ void IoImpl::finish()
   }
 }
 
-void IoImpl::wait_any_for(actor::ActorImpl* issuer, const std::vector<IoImpl*>& ios, double timeout)
-{
-  if (timeout < 0.0) {
-    issuer->simcall_.timeout_cb_ = nullptr;
-  } else {
-    issuer->simcall_.timeout_cb_ = timer::Timer::set(s4u::Engine::get_clock() + timeout, [issuer, &ios]() {
-      issuer->simcall_.timeout_cb_ = nullptr;
-      for (auto* io : ios)
-        io->unregister_simcall(&issuer->simcall_);
-      // default result (-1) is set in actor::IoWaitanySimcall
-      issuer->simcall_answer();
-    });
-  }
-
-  for (auto* io : ios) {
-    /* associate this simcall to the the synchro */
-    io->simcalls_.push_back(&issuer->simcall_);
-
-    /* see if the synchro is already finished */
-    if (io->get_state() != State::WAITING && io->get_state() != State::RUNNING) {
-      io->finish();
-      break;
-    }
-  }
-}
-
-} // namespace activity
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::activity
