@@ -9,9 +9,7 @@
 #include "src/kernel/activity/ActivityImpl.hpp"
 #include <simgrid/s4u/Io.hpp>
 
-namespace simgrid {
-namespace kernel {
-namespace activity {
+namespace simgrid::kernel::activity {
 
 class XBT_PUBLIC IoImpl : public ActivityImpl_T<IoImpl> {
   resource::DiskImpl* disk_           = nullptr;
@@ -39,10 +37,7 @@ public:
   void post() override;
   void set_exception(actor::ActorImpl* issuer) override;
   void finish() override;
-  static void wait_any_for(actor::ActorImpl* issuer, const std::vector<IoImpl*>& ios, double timeout);
 };
-} // namespace activity
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::activity
 
 #endif
