@@ -4,6 +4,7 @@
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "src/kernel/activity/MailboxImpl.hpp"
+#include "simgrid/msg.h"
 #include "src/kernel/activity/CommImpl.hpp"
 
 #include <unordered_map>
@@ -14,15 +15,30 @@ XBT_LOG_NEW_DEFAULT_SUBCATEGORY(ker_mailbox, kernel, "Mailbox implementation");
 /*                           Rendez-Vous Points                               */
 /******************************************************************************/
 
-namespace simgrid {
-namespace kernel {
-namespace activity {
+namespace simgrid::kernel::activity {
+
+unsigned MailboxImpl::next_id_ = 0;
+
+MailboxImpl::~MailboxImpl()
+{
+  try {
+    clear(false);
+  } catch (const std::bad_alloc& ba) {
+    XBT_ERROR("MailboxImpl::clear() failure: %s", ba.what());
+  }
+  set_receiver(nullptr);
+}
 
 /** @brief set the receiver of the mailbox to allow eager sends
  *  @param actor The receiving dude
  */
 void MailboxImpl::set_receiver(s4u::ActorPtr actor)
 {
+  if (this->permanent_receiver_) {
+    std::vector<MailboxImpl*>& mboxes = this->permanent_receiver_->mailboxes_;
+    mboxes.erase(std::remove(mboxes.begin(), mboxes.end(), this), mboxes.end());
+  }
+
   if (actor != nullptr)
     this->permanent_receiver_ = actor->get_impl();
   else
@@ -54,27 +70,53 @@ void MailboxImpl::remove(const CommImplPtr& comm)
   xbt_die("Comm %p not found in mailbox %s", comm.get(), this->get_cname());
 }
 
-CommImplPtr MailboxImpl::iprobe(int type, bool (*match_fun)(void*, void*, CommImpl*), void* data)
+/** @brief Removes all communication activities from a mailbox
+ */
+void MailboxImpl::clear( bool do_post )
+{
+  // CommImpl::cancel() will remove the comm from the mailbox..
+  for (auto comm : done_comm_queue_) {
+    comm->cancel();
+    comm->set_state(State::FAILED);
+    if(do_post)
+      comm->post();
+  }
+  done_comm_queue_.clear();
+
+  while (not comm_queue_.empty()) {
+    auto comm = comm_queue_.back();
+    if (comm->get_state() == State::WAITING && not comm->is_detached()) {
+      comm->cancel();
+      comm->set_state(State::FAILED);
+      if(do_post)
+        comm->post();
+    } else
+      comm_queue_.pop_back();
+  }
+  xbt_assert(comm_queue_.empty() && done_comm_queue_.empty());
+}
+
+CommImplPtr MailboxImpl::iprobe(int type, const std::function<bool(void*, void*, CommImpl*)>& match_fun, void* data)
 {
   XBT_DEBUG("iprobe from %p %p", this, &comm_queue_);
 
-  CommImplPtr this_comm;
-  CommImpl::Type smx_type;
+  CommImplPtr this_comm(new CommImpl);
+  CommImplType other_type;
   if (type == 1) {
-    this_comm = CommImplPtr(new CommImpl(CommImpl::Type::SEND));
-    smx_type  = CommImpl::Type::RECEIVE;
+    this_comm->set_type(CommImplType::SEND);
+    other_type = CommImplType::RECEIVE;
   } else {
-    this_comm = CommImplPtr(new CommImpl(CommImpl::Type::RECEIVE));
-    smx_type  = CommImpl::Type::SEND;
+    this_comm->set_type(CommImplType::RECEIVE);
+    other_type = CommImplType::SEND;
   }
   CommImplPtr other_comm = nullptr;
   if (permanent_receiver_ != nullptr && not done_comm_queue_.empty()) {
     XBT_DEBUG("first check in the permanent recv mailbox, to see if we already got something");
-    other_comm = find_matching_comm(smx_type, match_fun, data, this_comm, /*done*/ true, /*remove_matching*/ false);
+    other_comm = find_matching_comm(other_type, match_fun, data, this_comm, /*done*/ true, /*remove_matching*/ false);
   }
   if (not other_comm) {
     XBT_DEBUG("check if we have more luck in the normal mailbox");
-    other_comm = find_matching_comm(smx_type, match_fun, data, this_comm, /*done*/ false, /*remove_matching*/ false);
+    other_comm = find_matching_comm(other_type, match_fun, data, this_comm, /*done*/ false, /*remove_matching*/ false);
   }
 
   return other_comm;
@@ -89,7 +131,8 @@ CommImplPtr MailboxImpl::iprobe(int type, bool (*match_fun)(void*, void*, CommIm
  *  @param remove_matching whether or not to clean the found object from the queue
  *  @return The communication activity if found, nullptr otherwise
  */
-CommImplPtr MailboxImpl::find_matching_comm(CommImpl::Type type, bool (*match_fun)(void*, void*, CommImpl*),
+CommImplPtr MailboxImpl::find_matching_comm(CommImplType type,
+                                            const std::function<bool(void*, void*, CommImpl*)>& match_fun,
                                             void* this_user_data, const CommImplPtr& my_synchro, bool done,
                                             bool remove_matching)
 {
@@ -97,8 +140,8 @@ CommImplPtr MailboxImpl::find_matching_comm(CommImpl::Type type, bool (*match_fu
 
   auto iter = std::find_if(
       comm_queue.begin(), comm_queue.end(), [&type, &match_fun, &this_user_data, &my_synchro](const CommImplPtr& comm) {
-        void* other_user_data = (comm->type_ == CommImpl::Type::SEND ? comm->src_data_ : comm->dst_data_);
-        return (comm->type_ == type && (not match_fun || match_fun(this_user_data, other_user_data, comm.get())) &&
+        void* other_user_data = (comm->get_type() == CommImplType::SEND ? comm->src_data_ : comm->dst_data_);
+        return (comm->get_type() == type && (not match_fun || match_fun(this_user_data, other_user_data, comm.get())) &&
                 (not comm->match_fun || comm->match_fun(other_user_data, this_user_data, my_synchro.get())));
       });
   if (iter == comm_queue.end()) {
@@ -108,15 +151,10 @@ CommImplPtr MailboxImpl::find_matching_comm(CommImpl::Type type, bool (*match_fu
 
   const CommImplPtr& comm = *iter;
   XBT_DEBUG("Found a matching communication synchro %p", comm.get());
-#if SIMGRID_HAVE_MC
-  comm->mbox_cpy = comm->get_mailbox();
-#endif
   comm->set_mailbox(nullptr);
   CommImplPtr comm_cpy = comm;
   if (remove_matching)
     comm_queue.erase(iter);
   return comm_cpy;
 }
-} // namespace activity
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::activity
