@@ -7,6 +7,9 @@
 #include <simgrid/s4u/Actor.hpp>
 #include <simgrid/s4u/Host.hpp>
 
+#define SIMIX_H_NO_DEPRECATED_WARNING // avoid deprecation warning on include (remove with XBT_ATTRIB_DEPRECATED_v333)
+#include <simgrid/simix.h>
+
 #include "src/kernel/EngineImpl.hpp"
 #if HAVE_SMPI
 #include "src/smpi/include/private.hpp"
@@ -26,28 +29,17 @@ XBT_LOG_NEW_DEFAULT_SUBCATEGORY(ker_actor, kernel, "Logging specific to Actor's
  *
  * @return The SIMIX process
  */
-smx_actor_t SIMIX_process_self() // XBT_ATTRIB_DEPRECATED_v333
+simgrid::kernel::actor::ActorImpl* SIMIX_process_self() // XBT_ATTRIB_DEPRECATED_v333
 {
   return simgrid::kernel::actor::ActorImpl::self();
 }
 
-namespace simgrid {
-namespace kernel {
-namespace actor {
+namespace simgrid::kernel::actor {
 
-static unsigned long maxpid = 0;
-unsigned long get_maxpid()
-{
-  return maxpid;
-}
-unsigned long* get_maxpid_addr()
-{
-  return &maxpid;
-}
-ActorImpl* ActorImpl::by_pid(aid_t pid)
-{
-  return EngineImpl::get_instance()->get_actor_by_pid(pid);
-}
+/*------------------------- [ ActorIDTrait ] -------------------------*/
+unsigned long ActorIDTrait::maxpid_ = 0;
+
+ActorIDTrait::ActorIDTrait(const std::string& name, aid_t ppid) : name_(name), pid_(maxpid_++), ppid_(ppid) {}
 
 ActorImpl* ActorImpl::self()
 {
@@ -56,9 +48,9 @@ ActorImpl* ActorImpl::self()
   return (self_context != nullptr) ? self_context->get_actor() : nullptr;
 }
 
-ActorImpl::ActorImpl(xbt::string name, s4u::Host* host) : host_(host), name_(std::move(name)), piface_(this)
+ActorImpl::ActorImpl(xbt::string name, s4u::Host* host, aid_t ppid)
+    : ActorIDTrait(std::move(name), ppid), host_(host), piface_(this)
 {
-  pid_            = maxpid++;
   simcall_.issuer_ = this;
   stacksize_       = context::stack_size;
 }
@@ -88,7 +80,7 @@ ActorImplPtr ActorImpl::attach(const std::string& name, void* data, s4u::Host* h
     throw HostFailureException(XBT_THROW_POINT, "Cannot attach actor on failed host.");
   }
 
-  auto* actor = new ActorImpl(xbt::string(name), host);
+  auto* actor = new ActorImpl(xbt::string(name), host, /*ppid*/ -1);
   /* Actor data */
   actor->piface_.set_data(data);
   actor->code_ = nullptr;
@@ -124,7 +116,7 @@ void ActorImpl::detach()
   auto* context = dynamic_cast<context::AttachContext*>(context::Context::self());
   xbt_assert(context != nullptr, "Not a suitable context");
 
-  context->get_actor()->cleanup();
+  context->get_actor()->cleanup_from_self();
   context->attach_stop();
 }
 
@@ -134,24 +126,19 @@ bool ActorImpl::is_maestro() const
   return context_->is_maestro();
 }
 
-void ActorImpl::cleanup_from_simix()
+void ActorImpl::cleanup_from_kernel()
 {
+  xbt_assert(s4u::Actor::is_maestro(), "Cleanup_from_kernel must be called in maestro context");
+
   auto* engine = EngineImpl::get_instance();
-  const std::lock_guard<std::mutex> lock(engine->get_mutex());
-  engine->remove_actor(pid_);
+  if (engine->get_actor_by_pid(get_pid()) == nullptr)
+    return; // Already cleaned
+
+  engine->remove_actor(get_pid());
   if (host_ && host_actor_list_hook.is_linked())
     host_->get_impl()->remove_actor(this);
-  if (not kernel_destroy_list_hook.is_linked()) {
-#if SIMGRID_HAVE_MC
-    engine->add_dead_actor_to_dynar(this);
-#endif
+  if (not kernel_destroy_list_hook.is_linked())
     engine->add_actor_to_destroy_list(*this);
-  }
-}
-
-void ActorImpl::cleanup()
-{
-  finished_ = true;
 
   if (has_to_auto_restart() && not get_host()->is_on()) {
     XBT_DEBUG("Insert host %s to watched_hosts because it's off and %s needs to restart", get_host()->get_cname(),
@@ -159,14 +146,27 @@ void ActorImpl::cleanup()
     watched_hosts().insert(get_host()->get_name());
   }
 
+  undaemonize();
+  s4u::Actor::on_termination(*get_ciface());
+
+  while (not mailboxes_.empty())
+    mailboxes_.back()->set_receiver(nullptr);
+}
+
+/* Do all the cleanups from the actor context. Warning, the simcall mechanism was not reignited so doing simcalls in
+ * this context is dangerous */
+void ActorImpl::cleanup_from_self()
+{
+  xbt_assert(not ActorImpl::is_maestro(), "Cleanup_from_self called from maestro on '%s'", get_cname());
+  set_to_be_freed();
+
   if (on_exit) {
     // Execute the termination callbacks
-    bool failed = context_->wannadie();
+    bool failed = wannadie();
     for (auto exit_fun = on_exit->crbegin(); exit_fun != on_exit->crend(); ++exit_fun)
       (*exit_fun)(failed);
     on_exit.reset();
   }
-  undaemonize();
 
   /* cancel non-blocking activities */
   for (auto activity : activities_)
@@ -175,11 +175,6 @@ void ActorImpl::cleanup()
 
   XBT_DEBUG("%s@%s(%ld) should not run anymore", get_cname(), get_host()->get_cname(), get_pid());
 
-  if (EngineImpl::get_instance()->is_maestro(this)) /* Do not cleanup maestro */
-    return;
-
-  XBT_DEBUG("Cleanup actor %s (%p), waiting synchro %p", get_cname(), this, waiting_synchro_.get());
-
   /* Unregister associated timers if any */
   if (kill_timer_ != nullptr) {
     kill_timer_->remove();
@@ -190,34 +185,24 @@ void ActorImpl::cleanup()
     simcall_.timeout_cb_ = nullptr;
   }
 
-  cleanup_from_simix();
+  /* maybe the actor was killed during a simcall, reset its observer */
+  simcall_.observer_ = nullptr;
 
-  context_->set_wannadie(false); // don't let the simcall's yield() do a Context::stop(), to avoid infinite loops
-  actor::simcall([this] { s4u::Actor::on_termination(*get_ciface()); });
-  context_->set_wannadie();
+  set_wannadie();
 }
 
 void ActorImpl::exit()
 {
-  context_->set_wannadie();
-  suspended_          = false;
-  exception_          = nullptr;
+  set_wannadie();
+  suspended_ = false;
+  exception_ = nullptr;
 
-  /* destroy the blocking synchro if any */
   if (waiting_synchro_ != nullptr) {
-    waiting_synchro_->cancel();
-    waiting_synchro_->set_state(activity::State::FAILED);
-
-    activity::ExecImplPtr exec = boost::dynamic_pointer_cast<activity::ExecImpl>(waiting_synchro_);
-    activity::CommImplPtr comm = boost::dynamic_pointer_cast<activity::CommImpl>(waiting_synchro_);
-
-    if (exec != nullptr) {
-      exec->clean_action();
-    } else if (comm != nullptr) {
-      comm->unregister_simcall(&simcall_);
-    } else {
-      activity::ActivityImplPtr(waiting_synchro_)->finish();
-    }
+    /* Take an extra reference on the activity object that may be unref by Comm::finish() or friends */
+    activity::ActivityImplPtr activity = waiting_synchro_;
+    activity->cancel();
+    activity->set_state(activity::State::FAILED);
+    activity->post();
 
     activities_.remove(waiting_synchro_);
     waiting_synchro_ = nullptr;
@@ -233,7 +218,7 @@ void ActorImpl::exit()
 void ActorImpl::kill(ActorImpl* actor) const
 {
   xbt_assert(not actor->is_maestro(), "Killing maestro is a rather bad idea.");
-  if (actor->finished_) {
+  if (actor->wannadie()) {
     XBT_DEBUG("Ignoring request to kill actor %s@%s that is already dead", actor->get_cname(),
               actor->host_->get_cname());
     return;
@@ -252,9 +237,9 @@ void ActorImpl::kill(ActorImpl* actor) const
 
 void ActorImpl::kill_all() const
 {
-  for (auto const& kv : EngineImpl::get_instance()->get_actor_list())
-    if (kv.second != this)
-      this->kill(kv.second);
+  for (auto const& [_, actor] : EngineImpl::get_instance()->get_actor_list())
+    if (actor != this)
+      this->kill(actor);
 }
 
 void ActorImpl::set_kill_time(double kill_time)
@@ -265,6 +250,7 @@ void ActorImpl::set_kill_time(double kill_time)
   kill_timer_ = timer::Timer::set(kill_time, [this] {
     this->exit();
     kill_timer_ = nullptr;
+    EngineImpl::get_instance()->add_actor_to_run_list(this);
   });
 }
 
@@ -279,11 +265,10 @@ void ActorImpl::yield()
 
   /* Go into sleep and return control to maestro */
   context_->suspend();
-
   /* Ok, maestro returned control to us */
   XBT_DEBUG("Control returned to me: '%s'", get_cname());
 
-  if (context_->wannadie()) {
+  if (wannadie()) {
     XBT_DEBUG("Actor %s@%s is dead", get_cname(), host_->get_cname());
     context_->stop();
     THROW_IMPOSSIBLE;
@@ -305,9 +290,8 @@ void ActorImpl::yield()
       e.rethrow_nested(XBT_THROW_POINT, boost::core::demangle(typeid(e).name()) + " raised in kernel mode.");
     }
   }
-
 #if HAVE_SMPI
-  if (not finished_)
+  if (not wannadie())
     smpi_switch_data_segment(get_iface());
 #endif
 }
@@ -336,19 +320,13 @@ s4u::Actor* ActorImpl::restart()
   XBT_DEBUG("Restarting actor %s on %s", get_cname(), host_->get_cname());
 
   // retrieve the arguments of the old actor
-  ProcessArg arg(host_, this);
+  ProcessArg args(host_, this);
 
   // kill the old actor
   context::Context::self()->get_actor()->kill(this);
 
   // start the new actor
-  ActorImplPtr actor = ActorImpl::create(arg.name, arg.code, arg.data, arg.host, nullptr);
-  actor->set_properties(arg.properties);
-  *actor->on_exit = std::move(*arg.on_exit);
-  actor->set_kill_time(arg.kill_time);
-  actor->set_auto_restart(arg.auto_restart);
-
-  return actor->get_ciface();
+  return create(&args)->get_ciface();
 }
 
 void ActorImpl::suspend()
@@ -369,8 +347,8 @@ void ActorImpl::resume()
 {
   XBT_IN("actor = %p", this);
 
-  if (context_->wannadie()) {
-    XBT_VERB("Ignoring request to suspend an actor that is currently dying.");
+  if (wannadie()) {
+    XBT_VERB("Ignoring request to resume an actor that is currently dying.");
     return;
   }
 
@@ -389,12 +367,17 @@ void ActorImpl::resume()
 
 activity::ActivityImplPtr ActorImpl::join(const ActorImpl* actor, double timeout)
 {
-  activity::ActivityImplPtr sleep = this->sleep(timeout);
-  actor->on_exit->emplace_back([sleep](bool) {
-    if (sleep->surf_action_)
-      sleep->surf_action_->finish(resource::Action::State::FINISHED);
-  });
-  return sleep;
+  activity::ActivityImplPtr sleep_activity = this->sleep(timeout);
+  if (actor->wannadie() || actor->to_be_freed()) {
+    if (sleep_activity->surf_action_)
+      sleep_activity->surf_action_->finish(resource::Action::State::FINISHED);
+  } else {
+    actor->on_exit->emplace_back([sleep_activity](bool) {
+      if (sleep_activity->surf_action_)
+        sleep_activity->surf_action_->finish(resource::Action::State::FINISHED);
+    });
+  }
+  return sleep_activity;
 }
 
 activity::ActivityImplPtr ActorImpl::sleep(double duration)
@@ -403,9 +386,9 @@ activity::ActivityImplPtr ActorImpl::sleep(double duration)
     throw_exception(std::make_exception_ptr(HostFailureException(
         XBT_THROW_POINT, std::string("Host ") + host_->get_cname() + " failed, you cannot sleep there.")));
 
-  auto sleep = new activity::SleepImpl();
-  sleep->set_name("sleep").set_host(host_).set_duration(duration).start();
-  return activity::SleepImplPtr(sleep);
+  auto sleep_activity = new activity::SleepImpl();
+  sleep_activity->set_name("sleep").set_host(host_).set_duration(duration).start();
+  return activity::SleepImplPtr(sleep_activity);
 }
 
 void ActorImpl::throw_exception(std::exception_ptr e)
@@ -427,9 +410,9 @@ void ActorImpl::simcall_answer()
 {
   auto* engine = EngineImpl::get_instance();
   if (not this->is_maestro()) {
-    XBT_DEBUG("Answer simcall %s issued by %s (%p)", SIMIX_simcall_name(simcall_), get_cname(), this);
-    xbt_assert(simcall_.call_ != simix::Simcall::NONE);
-    simcall_.call_ = simix::Simcall::NONE;
+    XBT_DEBUG("Answer simcall %s issued by %s (%p)", simcall_.get_cname(), get_cname(), this);
+    xbt_assert(simcall_.call_ != Simcall::Type::NONE);
+    simcall_.call_            = Simcall::Type::NONE;
     const auto& actors_to_run = engine->get_actors_to_run();
     xbt_assert(not XBT_LOG_ISENABLED(ker_actor, xbt_log_priority_debug) ||
                    std::find(begin(actors_to_run), end(actors_to_run), this) == end(actors_to_run),
@@ -447,8 +430,7 @@ void ActorImpl::set_host(s4u::Host* dest)
 
 ActorImplPtr ActorImpl::init(const std::string& name, s4u::Host* host) const
 {
-  auto* actor = new ActorImpl(xbt::string(name), host);
-  actor->set_ppid(this->pid_);
+  auto* actor = new ActorImpl(xbt::string(name), host, get_pid());
 
   intrusive_ptr_add_ref(actor);
   /* The on_creation() signal must be delayed until there, where the pid and everything is set */
@@ -463,7 +445,7 @@ ActorImpl* ActorImpl::start(const ActorCode& code)
   auto* engine = EngineImpl::get_instance();
 
   if (not host_->is_on()) {
-    XBT_WARN("Cannot launch actor '%s' on failed host '%s'", name_.c_str(), host_->get_cname());
+    XBT_WARN("Cannot launch actor '%s' on failed host '%s'", get_cname(), host_->get_cname());
     intrusive_ptr_release(this);
     throw HostFailureException(XBT_THROW_POINT, "Cannot start actor on failed host.");
   }
@@ -476,7 +458,7 @@ ActorImpl* ActorImpl::start(const ActorCode& code)
 
   /* Add the actor to its host's actor list */
   host_->get_impl()->add_actor(this);
-  engine->add_actor(pid_, this);
+  engine->add_actor(get_pid(), this);
 
   /* Now insert it in the global actor list and in the actor to run list */
   engine->add_actor_to_run_list_no_check(this);
@@ -501,12 +483,32 @@ ActorImplPtr ActorImpl::create(const std::string& name, const ActorCode& code, v
 
   return actor;
 }
+ActorImplPtr ActorImpl::create(ProcessArg* args)
+{
+  ActorImplPtr actor    = ActorImpl::create(args->name, args->code, nullptr, args->host, nullptr);
+  actor->restart_count_ = args->restart_count_;
+  actor->set_properties(args->properties);
+  if (args->on_exit)
+    *actor->on_exit = *args->on_exit;
+  if (args->kill_time >= 0)
+    actor->set_kill_time(args->kill_time);
+  if (args->auto_restart)
+    actor->set_auto_restart(args->auto_restart);
+  if (args->daemon_)
+    actor->daemonize();
+  return actor;
+}
+void ActorImpl::set_wannadie(bool value)
+{
+  XBT_DEBUG("Actor %s gonna die.", get_cname());
+  iwannadie_ = value;
+}
 
 void create_maestro(const std::function<void()>& code)
 {
   auto* engine = EngineImpl::get_instance();
   /* Create maestro actor and initialize it */
-  auto* maestro = new ActorImpl(xbt::string(""), /*host*/ nullptr);
+  auto* maestro = new ActorImpl(xbt::string(""), /*host*/ nullptr, /*ppid*/ -1);
 
   if (not code) {
     maestro->context_.reset(engine->get_context_factory()->create_context(ActorCode(), maestro));
@@ -518,9 +520,7 @@ void create_maestro(const std::function<void()>& code)
   engine->set_maestro(maestro);
 }
 
-} // namespace actor
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::actor
 
 /* needs to be public and without simcall because it is called by exceptions and logging events */
 const char* SIMIX_process_self_get_name() // XBT_ATTRIB_DEPRECATED_v333
@@ -528,12 +528,6 @@ const char* SIMIX_process_self_get_name() // XBT_ATTRIB_DEPRECATED_v333
   return simgrid::s4u::Actor::is_maestro() ? "maestro" : simgrid::kernel::actor::ActorImpl::self()->get_cname();
 }
 
-/** @brief Returns the process from PID. */
-smx_actor_t SIMIX_process_from_PID(aid_t pid) // XBT_ATTRIB_DEPRECATED_v331
-{
-  return simgrid::kernel::actor::ActorImpl::by_pid(pid);
-}
-
 int SIMIX_is_maestro() // XBT_ATTRIB_DEPRECATED_v333
 {
   const auto* self = simgrid::kernel::actor::ActorImpl::self();
