@@ -14,9 +14,7 @@
 #include <csignal>
 #include <functional>
 
-namespace simgrid {
-namespace kernel {
-namespace context {
+namespace simgrid::kernel::context {
 extern unsigned stack_size;
 extern unsigned guard_size;
 
@@ -33,7 +31,10 @@ public:
   /** Turn the current thread into maestro (the old maestro becomes a regular actor) */
   virtual Context* create_maestro(std::function<void()>&& code, actor::ActorImpl* actor);
 
-  virtual void run_all() = 0;
+  virtual void run_all(std::vector<actor::ActorImpl*> const& actors_list) = 0;
+
+  /* This allows Java to hijack the context factory (Java induces factories of factory :) */
+  static std::function<ContextFactory*(void)> initializer;
 
 protected:
   template <class T, class... Args> T* new_context(Args&&... args)
@@ -51,7 +52,6 @@ class XBT_PUBLIC Context {
 
   std::function<void()> code_;
   actor::ActorImpl* actor_ = nullptr;
-  bool iwannadie_          = false;
   bool is_maestro_;
   void declare_context(std::size_t size);
 
@@ -65,8 +65,6 @@ public:
   Context& operator=(const Context&) = delete;
   virtual ~Context();
 
-  bool wannadie() const { return iwannadie_; }
-  void set_wannadie(bool value = true) { iwannadie_ = value; }
   bool is_maestro() const { return is_maestro_; }
   void operator()() const { code_(); }
   bool has_code() const { return static_cast<bool>(code_); }
@@ -100,23 +98,16 @@ public:
   virtual void attach_stop() = 0;
 };
 
-
-/* This allows Java to hijack the context factory (Java induces factories of factory :) */
-using ContextFactoryInitializer = ContextFactory* (*)();
-XBT_PUBLIC_DATA ContextFactoryInitializer factory_initializer;
-
 XBT_PRIVATE ContextFactory* thread_factory();
 XBT_PRIVATE ContextFactory* sysv_factory();
 XBT_PRIVATE ContextFactory* raw_factory();
 XBT_PRIVATE ContextFactory* boost_factory();
 
-XBT_PUBLIC int is_parallel();
+XBT_PUBLIC bool is_parallel();
 XBT_PUBLIC int get_nthreads();
 XBT_PUBLIC void set_nthreads(int nb_threads);
 XBT_PUBLIC void set_parallel_mode(e_xbt_parmap_mode_t mode);
 XBT_PUBLIC e_xbt_parmap_mode_t get_parallel_mode();
-} // namespace context
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::context
 
 #endif
