@@ -8,6 +8,7 @@
 #include "src/internal_config.h"
 #include "src/kernel/EngineImpl.hpp"
 #include "src/kernel/actor/ActorImpl.hpp"
+#include "src/sthread/sthread.h"
 #include "xbt/parmap.hpp"
 
 #include "src/kernel/context/ContextSwapped.hpp"
@@ -48,11 +49,15 @@ void smx_ctx_wrapper(simgrid::kernel::context::SwappedContext* context)
   __sanitizer_finish_switch_fiber(nullptr, &context->asan_ctx_->asan_stack_, &context->asan_ctx_->asan_stack_size_);
 #endif
   try {
+    sthread_enable();
     (*context)();
-    context->Context::stop();
+    sthread_disable();
+    context->stop();
   } catch (simgrid::ForcefulKillException const&) {
+    sthread_disable();
     XBT_DEBUG("Caught a ForcefulKillException");
   } catch (simgrid::Exception const& e) {
+    sthread_disable();
     XBT_INFO("Actor killed by an uncaught exception %s", boost::core::demangle(typeid(e).name()).c_str());
     throw;
   }
@@ -63,14 +68,12 @@ void smx_ctx_wrapper(simgrid::kernel::context::SwappedContext* context)
   THROW_IMPOSSIBLE;
 }
 
-namespace simgrid {
-namespace kernel {
-namespace context {
+namespace simgrid::kernel::context {
 
 /* thread-specific storage for the worker's context */
 thread_local SwappedContext* SwappedContext::worker_context_ = nullptr;
 
-SwappedContext::SwappedContext(std::function<void()>&& code, smx_actor_t actor, SwappedContextFactory* factory)
+SwappedContext::SwappedContext(std::function<void()>&& code, actor::ActorImpl* actor, SwappedContextFactory* factory)
     : Context(std::move(code), actor, not code /* maestro if no code */), factory_(*factory)
 {
   // Save maestro (=first created context) in preparation for run_all
@@ -178,13 +181,6 @@ unsigned char* SwappedContext::get_stack_bottom() const
 #endif
 }
 
-void SwappedContext::stop()
-{
-  Context::stop();
-  /* We must cut the actor execution using an exception to properly free the C++ RAII variables */
-  throw ForcefulKillException();
-}
-
 void SwappedContext::swap_into(SwappedContext* to)
 {
 #if HAVE_SANITIZER_ADDRESS_FIBER_SUPPORT
@@ -204,7 +200,7 @@ void SwappedContext::swap_into(SwappedContext* to)
 }
 
 /** Maestro wants to run all ready actors */
-void SwappedContextFactory::run_all()
+void SwappedContextFactory::run_all(std::vector<actor::ActorImpl*> const& actors_list)
 {
   const auto* engine = EngineImpl::get_instance();
   /* This function is called by maestro at the beginning of a scheduling round to get all working threads executing some
@@ -214,7 +210,7 @@ void SwappedContextFactory::run_all()
   if (is_parallel()) {
     // We lazily create the parmap so that all options are actually processed when doing so.
     if (parmap_ == nullptr)
-      parmap_ = std::make_unique<simgrid::xbt::Parmap<smx_actor_t>>(get_nthreads(), get_parallel_mode());
+      parmap_ = std::make_unique<simgrid::xbt::Parmap<actor::ActorImpl*>>(get_nthreads(), get_parallel_mode());
 
     // Usually, Parmap::apply() executes the provided function on all elements of the array.
     // Here, the executed function does not return the control to the parmap before all the array is processed:
@@ -227,9 +223,9 @@ void SwappedContextFactory::run_all()
           auto* context = static_cast<SwappedContext*>(actor->context_.get());
           context->resume();
         },
-        engine->get_actors_to_run());
+        actors_list);
   } else { // sequential execution
-    if (not engine->has_actors_to_run())
+    if (actors_list.empty())
       return;
 
     /* maestro is already saved in the first slot of workers_context_ */
@@ -253,6 +249,7 @@ void SwappedContext::resume()
     // Save my current soul (either maestro, or one of the minions) in a thread-specific area
     worker_context_ = old;
   }
+  sthread_enable();
   // Switch my soul and the actor's one
   Context::set_current(this);
   old->swap_into(this);
@@ -273,7 +270,7 @@ void SwappedContext::suspend()
   SwappedContext* next_context;
   if (is_parallel()) {
     // Get some more work to directly swap into the next executable actor instead of yielding back to the parmap
-    boost::optional<smx_actor_t> next_work = factory_.parmap_->next();
+    boost::optional<actor::ActorImpl*> next_work = factory_.parmap_->next();
     if (next_work) {
       // There is a next soul to embody (ie, another executable actor)
       XBT_DEBUG("Run next process");
@@ -294,10 +291,12 @@ void SwappedContext::suspend()
     if (i < engine->get_actor_to_run_count()) {
       /* Actually swap into the next actor directly without transiting to maestro */
       XBT_DEBUG("Run next actor");
+      sthread_enable();
       next_context = static_cast<SwappedContext*>(engine->get_actor_to_run_at(i)->context_.get());
     } else {
       /* all processes were run, actually return to maestro */
       XBT_DEBUG("No more actors to run");
+      sthread_disable();
       next_context = factory_.maestro_context_;
     }
   }
@@ -305,6 +304,4 @@ void SwappedContext::suspend()
   this->swap_into(next_context);
 }
 
-} // namespace context
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::context
