@@ -19,16 +19,14 @@
 #include "src/internal_config.h"
 #include "src/kernel/context/ContextSwapped.hpp"
 
-namespace simgrid {
-namespace kernel {
-namespace context {
+namespace simgrid::kernel::context {
 
 class UContext : public SwappedContext {
 public:
   UContext(std::function<void()>&& code, actor::ActorImpl* actor, SwappedContextFactory* factory);
 
 private:
-  ucontext_t uc_;         /* the ucontext that executes the code */
+  ucontext_t uc_{}; /* the ucontext that executes the code */
 
   void swap_into_for_real(SwappedContext* to) override;
 };
@@ -37,8 +35,6 @@ class UContextFactory : public SwappedContextFactory {
 public:
   UContext* create_context(std::function<void()>&& code, actor::ActorImpl* actor) override;
 };
-} // namespace context
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::context
 
 #endif
