@@ -1,21 +1,18 @@
-/* Copyright (c) 2009-2021. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2009-2022. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "simgrid/kernel/routing/ClusterZone.hpp"
 #include "simgrid/kernel/routing/NetPoint.hpp"
-#include "simgrid/kernel/routing/RoutedZone.hpp"
-#include "src/surf/network_interface.hpp"
+#include "src/kernel/resource/StandardLinkImpl.hpp"
 
-XBT_LOG_NEW_DEFAULT_SUBCATEGORY(surf_route_cluster, surf, "Routing part of surf");
+XBT_LOG_NEW_DEFAULT_SUBCATEGORY(ker_routing_cluster, ker_routing, "Kernel Cluster Routing");
 
 /* This routing is specifically setup to represent clusters, aka homogeneous sets of machines
  * Note that a router is created, easing the interconnection with the rest of the world. */
 
-namespace simgrid {
-namespace kernel {
-namespace routing {
+namespace simgrid::kernel::routing {
 
 void ClusterBase::set_loopback()
 {
@@ -40,9 +37,10 @@ void ClusterBase::set_link_characteristics(double bw, double lat, s4u::Link::Sha
   link_lat_            = lat;
 }
 
-void ClusterBase::add_private_link_at(unsigned long position, std::pair<resource::LinkImpl*, resource::LinkImpl*> link)
+void ClusterBase::add_private_link_at(unsigned long position,
+                                      std::pair<resource::StandardLinkImpl*, resource::StandardLinkImpl*> link)
 {
-  private_links_.insert({position, link});
+  private_links_.try_emplace(position, link);
 }
 
 void ClusterBase::set_gateway(unsigned long position, NetPoint* gateway)
@@ -54,12 +52,8 @@ void ClusterBase::set_gateway(unsigned long position, NetPoint* gateway)
 
 NetPoint* ClusterBase::get_gateway(unsigned long position)
 {
-  NetPoint* res = nullptr;
-  auto it       = gateways_.find(position);
-  if (it != gateways_.end()) {
-    res = it->second;
-  }
-  return res;
+  auto it = gateways_.find(position);
+  return it == gateways_.end() ? nullptr : it->second;
 }
 
 void ClusterBase::fill_leaf_from_cb(unsigned long position, const std::vector<unsigned long>& dimensions,
@@ -119,6 +113,4 @@ void ClusterBase::fill_leaf_from_cb(unsigned long position, const std::vector<un
   *node_netpoint = netpoint;
 }
 
-} // namespace routing
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::routing
