@@ -6,7 +6,7 @@
 #include <simgrid/kernel/routing/FatTreeZone.hpp>
 #include <simgrid/kernel/routing/NetPoint.hpp>
 
-#include "src/kernel/resource/StandardLinkImpl.hpp"
+#include "src/kernel/resource/NetworkModel.hpp"
 #include "src/surf/xml/platf.hpp" // surf_parse_error() and surf_parse_assert()
 
 #include <fstream>
@@ -20,8 +20,7 @@
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(ker_routing_fat_tree, ker_routing, "Kernel Fat-Tree Routing");
 
 namespace simgrid {
-namespace kernel {
-namespace routing {
+namespace kernel::routing {
 
 bool FatTreeZone::is_in_sub_tree(const FatTreeNode* root, const FatTreeNode* node) const
 {
@@ -78,8 +77,8 @@ void FatTreeZone::get_local_route(const NetPoint* src, const NetPoint* dst, Rout
     for (unsigned int i = 0; i < currentNode->level; i++)
       d /= this->num_parents_per_node_[i];
 
-    int k = this->num_parents_per_node_[currentNode->level];
-    d     = d % k;
+    int k = this->num_parents_per_node_[currentNode->level] * this->num_port_lower_level_[currentNode->level];
+    d = d % k;
 
     if (currentNode->limiter_link_)
       into->link_list_.push_back(currentNode->limiter_link_);
@@ -94,7 +93,9 @@ void FatTreeZone::get_local_route(const NetPoint* src, const NetPoint* dst, Rout
 
   // Down part
   while (currentNode != destination) {
-    for (unsigned int i = 0; i < currentNode->children.size(); i++) {
+    //pick cable when multiple parallels
+    int d = source->position % this->num_port_lower_level_[currentNode->level - 1];
+    for (unsigned int i = d * this->num_children_per_node_[currentNode->level - 1]; i < currentNode->children.size(); i++) {
       if (i % this->num_children_per_node_[currentNode->level - 1] == destination->label[currentNode->level - 1]) {
         add_link_latency(into->link_list_, currentNode->children[i]->down_link_, latency);
 
@@ -341,7 +342,7 @@ void FatTreeZone::add_processing_node(int id, resource::StandardLinkImpl* limite
   position++;
   newNode->parents.resize(static_cast<size_t>(this->num_parents_per_node_[0]) * this->num_port_lower_level_[0]);
   newNode->label.resize(this->levels_);
-  this->compute_nodes_.insert(make_pair(id, newNode));
+  this->compute_nodes_.try_emplace(id, newNode);
   this->nodes_.emplace_back(newNode);
 }
 
@@ -488,8 +489,7 @@ void FatTreeZone::generate_dot_file(const std::string& filename) const
   file << "}";
   file.close();
 }
-} // namespace routing
-} // namespace kernel
+} // namespace kernel::routing
 
 namespace s4u {
 FatTreeParams::FatTreeParams(unsigned int n_levels, const std::vector<unsigned int>& down_links,
