@@ -7,15 +7,14 @@
 #include <simgrid/kernel/routing/NetPoint.hpp>
 #include <xbt/string.hpp>
 
-#include "src/kernel/resource/StandardLinkImpl.hpp"
+#include "src/kernel/resource/NetworkModel.hpp"
 
 #include <climits>
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(ker_routing_floyd, ker_routing, "Kernel Floyd Routing");
 
 namespace simgrid {
-namespace kernel {
-namespace routing {
+namespace kernel::routing {
 
 void FloydZone::init_tables(unsigned int table_size)
 {
@@ -135,7 +134,7 @@ void FloydZone::do_seal()
       auto& route = link_table_[i][i];
       if (not route) {
         route.reset(new Route());
-        route->link_list_.push_back(get_network_model()->loopback_);
+        route->link_list_.push_back(get_network_model()->loopback_.get());
         predecessor_table_[i][i] = i;
         cost_table_[i][i]        = 1;
       }
@@ -154,8 +153,7 @@ void FloydZone::do_seal()
     }
   }
 }
-} // namespace routing
-} // namespace kernel
+} // namespace kernel::routing
 
 namespace s4u {
 NetZone* create_floyd_zone(const std::string& name)
