@@ -7,21 +7,22 @@
 #include <simgrid/kernel/routing/NetZoneImpl.hpp>
 #include <simgrid/s4u/Engine.hpp>
 #include <simgrid/s4u/Host.hpp>
+#include <simgrid/s4u/VirtualMachine.hpp>
 
+#include "xbt/asserts.hpp"
 #include "src/include/simgrid/sg_config.hpp"
 #include "src/kernel/EngineImpl.hpp"
 #include "src/kernel/resource/CpuImpl.hpp"
 #include "src/kernel/resource/DiskImpl.hpp"
+#include "src/kernel/resource/NetworkModel.hpp"
 #include "src/kernel/resource/SplitDuplexLinkImpl.hpp"
-#include "src/surf/HostImpl.hpp"
-
 #include "src/kernel/resource/StandardLinkImpl.hpp"
+#include "src/kernel/resource/VirtualMachineImpl.hpp"
+#include "src/surf/HostImpl.hpp"
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(ker_routing, kernel, "Kernel routing-related information");
 
-namespace simgrid {
-namespace kernel {
-namespace routing {
+namespace simgrid::kernel::routing {
 
 /* Pick the right models for CPU, net and host, and call their model_init_preparse */
 static void surf_config_models_setup()
@@ -40,8 +41,8 @@ static void surf_config_models_setup()
 
   XBT_DEBUG("host model: %s", host_model_name.c_str());
   if (host_model_name == "compound") {
-    xbt_assert(not cpu_model_name.empty(), "Set a cpu model to use with the 'compound' host model");
-    xbt_assert(not network_model_name.empty(), "Set a network model to use with the 'compound' host model");
+    xbt_enforce(not cpu_model_name.empty(), "Set a cpu model to use with the 'compound' host model");
+    xbt_enforce(not network_model_name.empty(), "Set a network model to use with the 'compound' host model");
 
     const auto* cpu_model = find_model_description(surf_cpu_model_description, cpu_model_name);
     cpu_model->model_init_preparse();
@@ -93,7 +94,7 @@ NetZoneImpl::NetZoneImpl(const std::string& name) : piface_(this), name_(name)
     surf_config_models_setup();
   }
 
-  xbt_assert(nullptr == engine->netpoint_by_name_or_null(get_name()),
+  xbt_enforce(nullptr == engine->netpoint_by_name_or_null(get_name()),
              "Refusing to create a second NetZone called '%s'.", get_cname());
   netpoint_ = new NetPoint(name_, NetPoint::Type::NetZone);
   XBT_DEBUG("NetZone '%s' created with the id '%lu'", get_cname(), netpoint_->id());
@@ -107,15 +108,53 @@ NetZoneImpl::~NetZoneImpl()
   for (auto const& nz : children_)
     delete nz;
 
-  for (auto const& kv : bypass_routes_)
-    delete kv.second;
+  /* Since hosts_ and links_ are a std::map, the hosts are destroyed in the lexicographic order, which ensures that the
+   * output is reproducible.
+   */
+  for (auto const& [_, host] : hosts_) {
+    host->destroy();
+  }
+  hosts_.clear();
+  for (auto const& [_, link] : links_) {
+    link->destroy();
+  }
+  links_.clear();
+
+  for (auto const& [_, route] : bypass_routes_)
+    delete route;
 
   s4u::Engine::get_instance()->netpoint_unregister(netpoint_);
 }
 
+xbt_node_t NetZoneImpl::new_xbt_graph_node(const s_xbt_graph_t* graph, const char* name,
+                                           std::map<std::string, xbt_node_t, std::less<>>* nodes)
+{
+  auto [elm, inserted] = nodes->try_emplace(name);
+  if (inserted)
+    elm->second = xbt_graph_new_node(graph, xbt_strdup(name));
+  return elm->second;
+}
+
+xbt_edge_t NetZoneImpl::new_xbt_graph_edge(const s_xbt_graph_t* graph, xbt_node_t src, xbt_node_t dst,
+                                           std::map<std::string, xbt_edge_t, std::less<>>* edges)
+{
+  const auto* src_name = static_cast<const char*>(xbt_graph_node_get_data(src));
+  const auto* dst_name = static_cast<const char*>(xbt_graph_node_get_data(dst));
+
+  auto elm = edges->find(std::string(src_name) + dst_name);
+  if (elm == edges->end()) {
+    bool inserted;
+    std::tie(elm, inserted) = edges->try_emplace(std::string(dst_name) + src_name);
+    if (inserted)
+      elm->second = xbt_graph_new_edge(graph, src, dst, nullptr);
+  }
+
+  return elm->second;
+}
+
 void NetZoneImpl::add_child(NetZoneImpl* new_zone)
 {
-  xbt_assert(not sealed_, "Cannot add a new child to the sealed zone %s", get_cname());
+  xbt_enforce(not sealed_, "Cannot add a new child to the sealed zone %s", get_cname());
   /* set the parent behavior */
   hierarchy_ = RoutingMode::recursive;
   children_.push_back(new_zone);
@@ -128,72 +167,97 @@ void NetZoneImpl::add_child(NetZoneImpl* new_zone)
  */
 std::vector<s4u::Host*> NetZoneImpl::get_all_hosts() const
 {
-  std::vector<s4u::Host*> res;
-  for (auto const& card : get_vertices()) {
-    s4u::Host* host = s4u::Host::by_name_or_null(card->get_name());
-    if (host != nullptr)
-      res.push_back(host);
-  }
-  return res;
+  return s4u::Engine::get_instance()->get_filtered_hosts(
+      [this](const s4u::Host* host) { return host->get_impl()->get_englobing_zone() == this; });
 }
-int NetZoneImpl::get_host_count() const
+size_t NetZoneImpl::get_host_count() const
 {
-  int count = 0;
-  for (auto const& card : get_vertices()) {
-    const s4u::Host* host = s4u::Host::by_name_or_null(card->get_name());
-    if (host != nullptr)
-      count++;
+  return get_all_hosts().size();
+}
+
+std::vector<s4u::Link*> NetZoneImpl::get_filtered_links(const std::function<bool(s4u::Link*)>& filter) const
+{
+  std::vector<s4u::Link*> filtered_list;
+  for (auto const& [_, link] : links_) {
+    s4u::Link* l = link->get_iface();
+    if (filter(l))
+      filtered_list.push_back(l);
   }
-  return count;
+
+  for (const auto* child : children_) {
+    auto child_links = child->get_filtered_links(filter);
+    filtered_list.insert(filtered_list.end(), std::make_move_iterator(child_links.begin()),
+                         std::make_move_iterator(child_links.end()));
+  }
+  return filtered_list;
+}
+
+std::vector<s4u::Link*> NetZoneImpl::get_all_links() const
+{
+  return get_filtered_links([](const s4u::Link*) { return true; });
+}
+
+size_t NetZoneImpl::get_link_count() const
+{
+  size_t total = links_.size();
+  for (const auto* child : children_) {
+    total += child->get_link_count();
+  }
+  return total;
 }
 
 s4u::Host* NetZoneImpl::create_host(const std::string& name, const std::vector<double>& speed_per_pstate)
 {
-  xbt_assert(cpu_model_pm_,
+  xbt_enforce(cpu_model_pm_,
              "Impossible to create host: %s. Invalid CPU model: nullptr. Have you set the parent of this NetZone: %s?",
              name.c_str(), get_cname());
-  xbt_assert(not sealed_, "Impossible to create host: %s. NetZone %s already sealed", name.c_str(), get_cname());
-  auto* res = (new resource::HostImpl(name))->get_iface();
-  res->set_netpoint((new NetPoint(name, NetPoint::Type::Host))->set_englobing_zone(this));
+  xbt_enforce(not sealed_, "Impossible to create host: %s. NetZone %s already sealed", name.c_str(), get_cname());
+  auto* host   = (new resource::HostImpl(name))->set_englobing_zone(this);
+  hosts_[name] = host;
+  host->get_iface()->set_netpoint((new NetPoint(name, NetPoint::Type::Host))->set_englobing_zone(this));
 
-  cpu_model_pm_->create_cpu(res, speed_per_pstate);
+  cpu_model_pm_->create_cpu(host->get_iface(), speed_per_pstate);
 
-  return res;
+  return host->get_iface();
+}
+
+resource::StandardLinkImpl* NetZoneImpl::do_create_link(const std::string& name, const std::vector<double>& bandwidths)
+{
+  return network_model_->create_link(name, bandwidths);
 }
 
 s4u::Link* NetZoneImpl::create_link(const std::string& name, const std::vector<double>& bandwidths)
 {
-  xbt_assert(
+  xbt_enforce(
       network_model_,
       "Impossible to create link: %s. Invalid network model: nullptr. Have you set the parent of this NetZone: %s?",
       name.c_str(), get_cname());
-  xbt_assert(not sealed_, "Impossible to create link: %s. NetZone %s already sealed", name.c_str(), get_cname());
-  return network_model_->create_link(name, bandwidths)->get_iface();
+  xbt_enforce(not sealed_, "Impossible to create link: %s. NetZone %s already sealed", name.c_str(), get_cname());
+  links_[name] = do_create_link(name, bandwidths)->set_englobing_zone(this);
+  return links_[name]->get_iface();
 }
 
 s4u::SplitDuplexLink* NetZoneImpl::create_split_duplex_link(const std::string& name,
                                                             const std::vector<double>& bandwidths)
 {
-  xbt_assert(
+  xbt_enforce(
       network_model_,
       "Impossible to create link: %s. Invalid network model: nullptr. Have you set the parent of this NetZone: %s?",
       name.c_str(), get_cname());
-  xbt_assert(not sealed_, "Impossible to create link: %s. NetZone %s already sealed", name.c_str(), get_cname());
+  xbt_enforce(not sealed_, "Impossible to create link: %s. NetZone %s already sealed", name.c_str(), get_cname());
 
-  auto* link_up                  = network_model_->create_link(name + "_UP", bandwidths);
-  auto* link_down                = network_model_->create_link(name + "_DOWN", bandwidths);
-  auto link                      = std::make_unique<resource::SplitDuplexLinkImpl>(name, link_up, link_down);
-  auto* link_iface               = link->get_iface();
-  EngineImpl::get_instance()->add_split_duplex_link(name, std::move(link));
-  return link_iface;
+  auto* link_up             = create_link(name + "_UP", bandwidths)->get_impl()->set_englobing_zone(this);
+  auto* link_down           = create_link(name + "_DOWN", bandwidths)->get_impl()->set_englobing_zone(this);
+  split_duplex_links_[name] = std::make_unique<resource::SplitDuplexLinkImpl>(name, link_up, link_down);
+  return split_duplex_links_[name]->get_iface();
 }
 
 s4u::Disk* NetZoneImpl::create_disk(const std::string& name, double read_bandwidth, double write_bandwidth)
 {
-  xbt_assert(disk_model_,
+  xbt_enforce(disk_model_,
              "Impossible to create disk: %s. Invalid disk model: nullptr. Have you set the parent of this NetZone: %s?",
              name.c_str(), get_cname());
-  xbt_assert(not sealed_, "Impossible to create disk: %s. NetZone %s already sealed", name.c_str(), get_cname());
+  xbt_enforce(not sealed_, "Impossible to create disk: %s. NetZone %s already sealed", name.c_str(), get_cname());
   auto* l = disk_model_->create_disk(name, read_bandwidth, write_bandwidth);
 
   return l->get_iface();
@@ -201,9 +265,9 @@ s4u::Disk* NetZoneImpl::create_disk(const std::string& name, double read_bandwid
 
 NetPoint* NetZoneImpl::create_router(const std::string& name)
 {
-  xbt_assert(nullptr == s4u::Engine::get_instance()->netpoint_by_name_or_null(name),
+  xbt_enforce(nullptr == s4u::Engine::get_instance()->netpoint_by_name_or_null(name),
              "Refusing to create a router named '%s': this name already describes a node.", name.c_str());
-  xbt_assert(not sealed_, "Impossible to create router: %s. NetZone %s already sealed", name.c_str(), get_cname());
+  xbt_enforce(not sealed_, "Impossible to create router: %s. NetZone %s already sealed", name.c_str(), get_cname());
 
   return (new NetPoint(name, NetPoint::Type::Router))->set_englobing_zone(this);
 }
@@ -226,7 +290,7 @@ std::vector<resource::StandardLinkImpl*> NetZoneImpl::get_link_list_impl(const s
     }
     // split-duplex links
     const auto* sd_link = dynamic_cast<const s4u::SplitDuplexLink*>(link.get_link());
-    xbt_assert(sd_link,
+    xbt_enforce(sd_link,
                "Add_route: cast to SpliDuplexLink impossible. This should not happen, please contact SimGrid team");
     resource::StandardLinkImpl* link_impl;
     switch (link.get_direction()) {
@@ -251,6 +315,67 @@ std::vector<resource::StandardLinkImpl*> NetZoneImpl::get_link_list_impl(const s
   return links;
 }
 
+resource::StandardLinkImpl* NetZoneImpl::get_link_by_name_or_null(const std::string& name) const
+{
+  if (auto link_it = links_.find(name); link_it != links_.end())
+    return link_it->second;
+
+  for (const auto* child : children_) {
+    if (auto* link = child->get_link_by_name_or_null(name))
+      return link;
+  }
+
+  return nullptr;
+}
+
+resource::SplitDuplexLinkImpl* NetZoneImpl::get_split_duplex_link_by_name_or_null(const std::string& name) const
+{
+  if (auto link_it = split_duplex_links_.find(name); link_it != split_duplex_links_.end())
+    return link_it->second.get();
+
+  for (const auto* child : children_) {
+    if (auto* link = child->get_split_duplex_link_by_name_or_null(name))
+      return link;
+  }
+
+  return nullptr;
+}
+
+resource::HostImpl* NetZoneImpl::get_host_by_name_or_null(const std::string& name) const
+{
+  if (auto host_it = hosts_.find(name); host_it != hosts_.end())
+    return host_it->second;
+
+  for (const auto* child : children_) {
+    if (auto* host = child->get_host_by_name_or_null(name))
+      return host;
+  }
+
+  return nullptr;
+}
+
+std::vector<s4u::Host*> NetZoneImpl::get_filtered_hosts(const std::function<bool(s4u::Host*)>& filter) const
+{
+  std::vector<s4u::Host*> filtered_list;
+  for (auto const& [_, host] : hosts_) {
+    s4u::Host* h = host->get_iface();
+    if (filter(h))
+      filtered_list.push_back(h);
+    /* Engine::get_hosts returns the VMs too */
+    for (auto* vm : h->get_impl()->get_vms()) {
+      if (filter(vm))
+        filtered_list.push_back(vm);
+    }
+  }
+
+  for (const auto* child : children_) {
+    auto child_links = child->get_filtered_hosts(filter);
+    filtered_list.insert(filtered_list.end(), std::make_move_iterator(child_links.begin()),
+                         std::make_move_iterator(child_links.end()));
+  }
+  return filtered_list;
+}
+
 void NetZoneImpl::add_route(NetPoint* /*src*/, NetPoint* /*dst*/, NetPoint* /*gw_src*/, NetPoint* /*gw_dst*/,
                             const std::vector<s4u::LinkInRoute>& /*link_list_*/, bool /*symmetrical*/)
 {
@@ -264,16 +389,16 @@ void NetZoneImpl::add_bypass_route(NetPoint* src, NetPoint* dst, NetPoint* gw_sr
   if (gw_dst) {
     XBT_DEBUG("Load bypassNetzoneRoute from %s@%s to %s@%s", src->get_cname(), gw_src->get_cname(), dst->get_cname(),
               gw_dst->get_cname());
-    xbt_assert(not link_list.empty(), "Bypass route between %s@%s and %s@%s cannot be empty.", src->get_cname(),
+    xbt_enforce(not link_list.empty(), "Bypass route between %s@%s and %s@%s cannot be empty.", src->get_cname(),
                gw_src->get_cname(), dst->get_cname(), gw_dst->get_cname());
-    xbt_assert(bypass_routes_.find({src, dst}) == bypass_routes_.end(),
+    xbt_enforce(bypass_routes_.find({src, dst}) == bypass_routes_.end(),
                "The bypass route between %s@%s and %s@%s already exists.", src->get_cname(), gw_src->get_cname(),
                dst->get_cname(), gw_dst->get_cname());
   } else {
     XBT_DEBUG("Load bypassRoute from %s to %s", src->get_cname(), dst->get_cname());
-    xbt_assert(not link_list.empty(), "Bypass route between %s and %s cannot be empty.", src->get_cname(),
+    xbt_enforce(not link_list.empty(), "Bypass route between %s and %s cannot be empty.", src->get_cname(),
                dst->get_cname());
-    xbt_assert(bypass_routes_.find({src, dst}) == bypass_routes_.end(),
+    xbt_enforce(bypass_routes_.find({src, dst}) == bypass_routes_.end(),
                "The bypass route between %s and %s already exists.", src->get_cname(), dst->get_cname());
   }
 
@@ -283,7 +408,7 @@ void NetZoneImpl::add_bypass_route(NetPoint* src, NetPoint* dst, NetPoint* gw_sr
   newRoute->links.insert(newRoute->links.end(), begin(converted_list), end(converted_list));
 
   /* Store it */
-  bypass_routes_.insert({{src, dst}, newRoute});
+  bypass_routes_.try_emplace({src, dst}, newRoute);
 }
 
 /** @brief Get the common ancestor and its first children in each line leading to src and dst
@@ -354,8 +479,8 @@ static void find_common_ancestors(const NetPoint* src, const NetPoint* dst,
   const NetZoneImpl* src_as = src->get_englobing_zone();
   const NetZoneImpl* dst_as = dst->get_englobing_zone();
 
-  xbt_assert(src_as, "Host %s must be in a netzone", src->get_cname());
-  xbt_assert(dst_as, "Host %s must be in a netzone", dst->get_cname());
+  xbt_enforce(src_as, "Host %s must be in a netzone", src->get_cname());
+  xbt_enforce(dst_as, "Host %s must be in a netzone", dst->get_cname());
 
   /* (2) find the path to the root routing component */
   std::vector<NetZoneImpl*> path_src;
@@ -390,7 +515,7 @@ static void find_common_ancestors(const NetPoint* src, const NetPoint* dst,
   if (*src_ancestor == *dst_ancestor) {             // src is the ancestor of dst, or the contrary
     *common_ancestor = *src_ancestor;
   } else {
-    xbt_assert(parent != nullptr);
+    xbt_enforce(parent != nullptr);
     *common_ancestor = parent;
   }
 }
@@ -520,7 +645,7 @@ void NetZoneImpl::get_global_route_with_netzones(const NetPoint* src, const NetP
 
   /* Not in the same netzone, no bypass. We'll have to find our path between the netzones recursively */
   common_ancestor->get_local_route(src_ancestor->netpoint_, dst_ancestor->netpoint_, &route, latency);
-  xbt_assert((route.gw_src_ != nullptr) && (route.gw_dst_ != nullptr), "Bad gateways for route from '%s' to '%s'.",
+  xbt_enforce((route.gw_src_ != nullptr) && (route.gw_dst_ != nullptr), "Bad gateways for route from '%s' to '%s'.",
              src->get_cname(), dst->get_cname());
 
   /* If source gateway is not our source, we have to recursively find our way up to this point */
@@ -533,6 +658,58 @@ void NetZoneImpl::get_global_route_with_netzones(const NetPoint* src, const NetP
     get_global_route_with_netzones(route.gw_dst_, dst, links, latency, netzones);
 }
 
+void NetZoneImpl::get_graph(const s_xbt_graph_t* graph, std::map<std::string, xbt_node_t, std::less<>>* nodes,
+                            std::map<std::string, xbt_edge_t, std::less<>>* edges)
+{
+  std::vector<NetPoint*> vertices = get_vertices();
+
+  for (auto const& my_src : vertices) {
+    for (auto const& my_dst : vertices) {
+      if (my_src == my_dst)
+        continue;
+
+      Route route;
+
+      get_local_route(my_src, my_dst, &route, nullptr);
+
+      XBT_DEBUG("get_route_and_latency %s -> %s", my_src->get_cname(), my_dst->get_cname());
+
+      xbt_node_t current;
+      xbt_node_t previous;
+      const char* previous_name;
+      const char* current_name;
+
+      if (route.gw_src_) {
+        previous      = new_xbt_graph_node(graph, route.gw_src_->get_cname(), nodes);
+        previous_name = route.gw_src_->get_cname();
+      } else {
+        previous      = new_xbt_graph_node(graph, my_src->get_cname(), nodes);
+        previous_name = my_src->get_cname();
+      }
+
+      for (auto const& link : route.link_list_) {
+        const char* link_name = link->get_cname();
+        current               = new_xbt_graph_node(graph, link_name, nodes);
+        current_name          = link_name;
+        new_xbt_graph_edge(graph, previous, current, edges);
+        XBT_DEBUG("  %s -> %s", previous_name, current_name);
+        previous      = current;
+        previous_name = current_name;
+      }
+
+      if (route.gw_dst_) {
+        current      = new_xbt_graph_node(graph, route.gw_dst_->get_cname(), nodes);
+        current_name = route.gw_dst_->get_cname();
+      } else {
+        current      = new_xbt_graph_node(graph, my_dst->get_cname(), nodes);
+        current_name = my_dst->get_cname();
+      }
+      new_xbt_graph_edge(graph, previous, current, edges);
+      XBT_DEBUG("  %s -> %s", previous_name, current_name);
+    }
+  }
+}
+
 void NetZoneImpl::seal()
 {
   /* already sealed netzone */
@@ -544,6 +721,11 @@ void NetZoneImpl::seal()
   for (auto* host : get_all_hosts()) {
     host->seal();
   }
+
+  /* sealing links */
+  for (auto const& [_, link] : links_)
+    link->get_iface()->seal();
+
   for (auto* sub_net : get_children()) {
     sub_net->seal();
   }
@@ -553,7 +735,7 @@ void NetZoneImpl::seal()
 
 void NetZoneImpl::set_parent(NetZoneImpl* parent)
 {
-  xbt_assert(not sealed_, "Impossible to set parent to an already sealed NetZone(%s)", this->get_cname());
+  xbt_enforce(not sealed_, "Impossible to set parent to an already sealed NetZone(%s)", this->get_cname());
   parent_ = parent;
   netpoint_->set_englobing_zone(parent_);
   if (parent) {
@@ -570,37 +752,37 @@ void NetZoneImpl::set_parent(NetZoneImpl* parent)
 
 void NetZoneImpl::set_network_model(std::shared_ptr<resource::NetworkModel> netmodel)
 {
-  xbt_assert(not sealed_, "Impossible to set network model to an already sealed NetZone(%s)", this->get_cname());
+  xbt_enforce(not sealed_, "Impossible to set network model to an already sealed NetZone(%s)", this->get_cname());
   network_model_ = std::move(netmodel);
 }
 
 void NetZoneImpl::set_cpu_vm_model(std::shared_ptr<resource::CpuModel> cpu_model)
 {
-  xbt_assert(not sealed_, "Impossible to set CPU model to an already sealed NetZone(%s)", this->get_cname());
+  xbt_enforce(not sealed_, "Impossible to set CPU model to an already sealed NetZone(%s)", this->get_cname());
   cpu_model_vm_ = std::move(cpu_model);
 }
 
 void NetZoneImpl::set_cpu_pm_model(std::shared_ptr<resource::CpuModel> cpu_model)
 {
-  xbt_assert(not sealed_, "Impossible to set CPU model to an already sealed NetZone(%s)", this->get_cname());
+  xbt_enforce(not sealed_, "Impossible to set CPU model to an already sealed NetZone(%s)", this->get_cname());
   cpu_model_pm_ = std::move(cpu_model);
 }
 
 void NetZoneImpl::set_disk_model(std::shared_ptr<resource::DiskModel> disk_model)
 {
-  xbt_assert(not sealed_, "Impossible to set disk model to an already sealed NetZone(%s)", this->get_cname());
+  xbt_enforce(not sealed_, "Impossible to set disk model to an already sealed NetZone(%s)", this->get_cname());
   disk_model_ = std::move(disk_model);
 }
 
 void NetZoneImpl::set_host_model(std::shared_ptr<resource::HostModel> host_model)
 {
-  xbt_assert(not sealed_, "Impossible to set host model to an already sealed NetZone(%s)", this->get_cname());
+  xbt_enforce(not sealed_, "Impossible to set host model to an already sealed NetZone(%s)", this->get_cname());
   host_model_ = std::move(host_model);
 }
 
 const NetZoneImpl* NetZoneImpl::get_netzone_recursive(const NetPoint* netpoint) const
 {
-  xbt_assert(netpoint && netpoint->is_netzone(), "Netpoint %s must be of the type NetZone",
+  xbt_enforce(netpoint && netpoint->is_netzone(), "Netpoint %s must be of the type NetZone",
              netpoint ? netpoint->get_cname() : "nullptr");
 
   if (netpoint == netpoint_)
@@ -624,6 +806,4 @@ bool NetZoneImpl::is_component_recursive(const NetPoint* netpoint) const
   return std::any_of(begin(children_), end(children_),
                      [netpoint](const auto* child) { return child->is_component_recursive(netpoint); });
 }
-} // namespace routing
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::routing
