@@ -6,24 +6,23 @@
 #ifndef SIMGRID_MC_VISITED_STATE_HPP
 #define SIMGRID_MC_VISITED_STATE_HPP
 
-#include "src/mc/mc_state.hpp"
+#include "src/mc/api/State.hpp"
 #include "src/mc/sosp/Snapshot.hpp"
 
 #include <cstddef>
 #include <memory>
 
-namespace simgrid {
-namespace mc {
+namespace simgrid::mc {
 
 class XBT_PRIVATE VisitedState {
 public:
   std::shared_ptr<simgrid::mc::Snapshot> system_state = nullptr;
   std::size_t heap_bytes_used = 0;
-  int actors_count            = 0;
-  int num          = 0; // unique id of that state in the storage of all stored IDs
-  int original_num = -1; // num field of the VisitedState to which I was declared equal to (used for dot_output)
+  int actor_count_;
+  long num;               // unique id of that state in the storage of all stored IDs
+  long original_num = -1; // num field of the VisitedState to which I was declared equal to (used for dot_output)
 
-  explicit VisitedState(unsigned long state_number);
+  explicit VisitedState(unsigned long state_number, unsigned int actor_count);
 };
 
 class XBT_PRIVATE VisitedStates {
@@ -31,13 +30,12 @@ class XBT_PRIVATE VisitedStates {
 public:
   void clear() { states_.clear(); }
   std::unique_ptr<simgrid::mc::VisitedState> addVisitedState(unsigned long state_number,
-                                                             simgrid::mc::State* graph_state, bool compare_snapshots);
+                                                             simgrid::mc::State* graph_state);
 
 private:
   void prune();
 };
 
-}
-}
+} // namespace simgrid::mc
 
 #endif
