@@ -16,8 +16,7 @@
 #include <cstdint>
 #include <vector>
 
-namespace simgrid {
-namespace dwarf {
+namespace simgrid::dwarf {
 
 /** A DWARF expression with optional validity constraints */
 class LocationListEntry {
@@ -32,9 +31,7 @@ private:
 public:
   LocationListEntry() = default;
   LocationListEntry(DwarfExpression expression, range_type range) : expression_(std::move(expression)), range_(range) {}
-  explicit LocationListEntry(DwarfExpression expression) : expression_(std::move(expression)), range_({0, UINT64_MAX})
-  {
-  }
+  explicit LocationListEntry(DwarfExpression expression) : expression_(std::move(expression)) {}
 
   DwarfExpression& expression() { return expression_; }
   DwarfExpression const& expression() const { return expression_; }
@@ -74,7 +71,6 @@ Location resolve(simgrid::dwarf::LocationList const& locations, simgrid::mc::Obj
 XBT_PRIVATE
 simgrid::dwarf::LocationList location_list(const simgrid::mc::ObjectInformation& info, Dwarf_Attribute& attr);
 
-} // namespace dwarf
-} // namespace simgrid
+} // namespace simgrid::dwarf
 
 #endif
