@@ -14,8 +14,7 @@
 #include "src/mc/mc_private.hpp"
 #include "xbt/file.hpp"
 
-namespace simgrid {
-namespace mc {
+namespace simgrid::mc {
 
 /* For an executable object, addresses are virtual address (there is no offset) i.e.
  *  \f$\text{virtual address} = \{dwarf address}\f$
@@ -124,8 +123,8 @@ static void remove_local_variable(Frame& scope, const char* var_name, const char
 
 void ObjectInformation::remove_local_variable(const char* var_name, const char* subprogram_name)
 {
-  for (auto& entry : this->subprograms)
-    mc::remove_local_variable(entry.second, var_name, subprogram_name, entry.second);
+  for (auto& [_, entry] : this->subprograms)
+    mc::remove_local_variable(entry, var_name, subprogram_name, entry);
 }
 
 /** @brief Fills the position of the segments (executable, read-only, read/write) */
@@ -139,10 +138,7 @@ void find_object_address(std::vector<xbt::VmMap> const& maps, ObjectInformation*
 
   for (size_t i = 0; i < maps.size(); ++i) {
     simgrid::xbt::VmMap const& reg = maps[i];
-    if (maps[i].pathname.empty())
-      continue;
-    std::string map_basename = simgrid::xbt::Path(maps[i].pathname).get_base_name();
-    if (map_basename != name)
+    if (reg.pathname.empty() || name != simgrid::xbt::Path(reg.pathname).get_base_name())
       continue;
 
     // This is the non-GNU_RELRO-part of the data segment:
@@ -198,5 +194,4 @@ void find_object_address(std::vector<xbt::VmMap> const& maps, ObjectInformation*
   xbt_assert(result->start_exec || result->start_rw || result->start_ro);
 }
 
-} // namespace mc
-} // namespace simgrid
+} // namespace simgrid::mc
