@@ -31,16 +31,13 @@
 #include <cstdio>
 #include <libunwind.h>
 
-namespace simgrid {
-namespace unw {
+namespace simgrid::unw {
 
 XBT_PRIVATE unw_addr_space_t create_addr_space();
 XBT_PRIVATE void* create_context(unw_addr_space_t as, pid_t pid);
-} // namespace unw
-} // namespace simgrid
+} // namespace simgrid::unw
 
-namespace simgrid {
-namespace mc {
+namespace simgrid::mc {
 
 class UnwindContext {
   simgrid::mc::AddressSpace* address_space_ = nullptr;
@@ -68,7 +65,6 @@ public:
 };
 
 void dumpStack(FILE* file, unw_cursor_t* cursor);
-} // namespace mc
-} // namespace simgrid
+} // namespace simgrid::mc
 
 #endif
