@@ -9,8 +9,7 @@
 #include "simgrid/forward.h"
 #include <vector>
 
-namespace simgrid {
-namespace mc {
+namespace simgrid::mc {
 
 /** Execute everything which is invisible
  *
@@ -23,7 +22,7 @@ XBT_PRIVATE void execute_actors();
 XBT_PRIVATE extern std::vector<double> processes_time;
 
 /** Execute a given simcall */
-XBT_PRIVATE void handle_simcall(smx_simcall_t req, int req_num);
+XBT_PRIVATE void handle_simcall(kernel::actor::Simcall* req, int req_num);
 
 /** Is the process ready to execute its simcall?
  *
@@ -34,11 +33,10 @@ XBT_PRIVATE void handle_simcall(smx_simcall_t req, int req_num);
  *  have both a source and a destination yet is not enabled
  *  (unless timeout is enabled in the wait and enabled in SimGridMC).
  */
-XBT_PRIVATE bool actor_is_enabled(smx_actor_t process);
+XBT_PRIVATE bool actor_is_enabled(kernel::actor::ActorImpl* process);
 
 /** Check if the given simcall is visible */
-XBT_PRIVATE bool request_is_visible(const s_smx_simcall* req);
-} // namespace mc
-} // namespace simgrid
+XBT_PRIVATE bool request_is_visible(const kernel::actor::Simcall* req);
+} // namespace simgrid::mc
 
 #endif
