@@ -7,13 +7,11 @@
 #include "src/kernel/actor/ActorImpl.hpp"
 
 #if SIMGRID_HAVE_MC
-#include "src/mc/Session.hpp"
-#include "src/mc/checker/Checker.hpp"
+#include "src/mc/api/RemoteApp.hpp"
+#include "src/mc/explo/Exploration.hpp"
 #include "src/mc/inspect/mc_unw.hpp"
-#include "src/mc/mc_comm_pattern.hpp"
 #include "src/mc/mc_config.hpp"
 #include "src/mc/mc_private.hpp"
-#include "src/mc/mc_safety.hpp"
 #include "src/mc/remote/AppSide.hpp"
 #include "src/mc/sosp/Snapshot.hpp"
 
@@ -32,64 +30,18 @@
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_global, mc, "Logging specific to MC (global)");
 
-namespace simgrid {
-namespace mc {
+namespace simgrid::mc {
 
 std::vector<double> processes_time;
 
-}
 }
 
 #if SIMGRID_HAVE_MC
 
-/* Liveness */
-
-namespace simgrid {
-namespace mc {
-
-xbt_automaton_t property_automaton = nullptr;
-
-}
-}
-
-/* Dot output */
-FILE *dot_output = nullptr;
-
-
-/*******************************  Initialization of MC *******************************/
-/*********************************************************************************/
-
-void MC_init_dot_output()
-{
-  dot_output = fopen(_sg_mc_dot_output_file.get().c_str(), "w");
-  xbt_assert(dot_output != nullptr, "Error open dot output file: %s", strerror(errno));
-
-  fprintf(dot_output,
-          "digraph graphname{\n fixedsize=true; rankdir=TB; ranksep=.25; edge [fontsize=12]; node [fontsize=10, shape=circle,width=.5 ]; graph [resolution=20, fontsize=10];\n");
-}
+namespace simgrid::mc {
 
 /*******************************  Core of MC *******************************/
 /**************************************************************************/
-
-void MC_run()
-{
-  simgrid::mc::processes_time.resize(simgrid::kernel::actor::get_maxpid());
-  MC_ignore_heap(simgrid::mc::processes_time.data(),
-    simgrid::mc::processes_time.size() * sizeof(simgrid::mc::processes_time[0]));
-  simgrid::mc::AppSide::get()->main_loop();
-}
-
-void MC_automaton_load(const char *file)
-{
-  if (simgrid::mc::property_automaton == nullptr)
-    simgrid::mc::property_automaton = xbt_automaton_new();
-
-  xbt_automaton_load(simgrid::mc::property_automaton, file);
-}
-
-namespace simgrid {
-namespace mc {
-
 void dumpStack(FILE* file, unw_cursor_t* cursor)
 {
   int nframe = 0;
@@ -116,20 +68,19 @@ void dumpStack(FILE* file, unw_cursor_t* cursor)
   } while (unw_step(cursor));
 }
 
-}
-}
+} // namespace simgrid::mc
 #endif
 
 double MC_process_clock_get(const simgrid::kernel::actor::ActorImpl* process)
 {
   if (simgrid::mc::processes_time.empty())
     return 0;
-  if (process != nullptr)
-    return simgrid::mc::processes_time[process->get_pid()];
-  return -1;
+  if (process == nullptr)
+    return -1;
+  return simgrid::mc::processes_time.at(process->get_pid());
 }
 
 void MC_process_clock_add(const simgrid::kernel::actor::ActorImpl* process, double amount)
 {
-  simgrid::mc::processes_time[process->get_pid()] += amount;
+  simgrid::mc::processes_time.at(process->get_pid()) += amount;
 }
