@@ -12,15 +12,8 @@
 #include "src/mc/mc_forward.hpp"
 #include "src/xbt/memory_map.hpp"
 
-/********************************* MC Global **********************************/
-
-XBT_PRIVATE void MC_init_dot_output();
-
-XBT_PRIVATE extern FILE* dot_output;
-
 /********************************** Miscellaneous **********************************/
-namespace simgrid {
-namespace mc {
+namespace simgrid::mc {
 
 XBT_PRIVATE void find_object_address(std::vector<simgrid::xbt::VmMap> const& maps,
                                      simgrid::mc::ObjectInformation* result);
@@ -28,9 +21,6 @@ XBT_PRIVATE void find_object_address(std::vector<simgrid::xbt::VmMap> const& map
 XBT_PRIVATE
 bool snapshot_equal(const Snapshot* s1, const Snapshot* s2);
 
-// Move is somewhere else (in the LivenessChecker class, in the Session class?):
-extern XBT_PRIVATE xbt_automaton_t property_automaton;
-}
-}
+} // namespace simgrid::mc
 
 #endif
