@@ -12,8 +12,7 @@
 
 #include <memory>
 
-namespace simgrid {
-namespace mc {
+namespace simgrid::mc {
 
 /** Model-checked-side of the communication protocol
  *
@@ -31,8 +30,9 @@ public:
 
 private:
   void handle_deadlock_check(const s_mc_message_t* msg) const;
-  void handle_simcall_execute(const s_mc_message_simcall_handle_t* message) const;
-  void handle_actor_enabled(const s_mc_message_actor_enabled_t* msg) const;
+  void handle_simcall_execute(const s_mc_message_simcall_execute_t* message) const;
+  void handle_finalize(const s_mc_message_int_t* msg) const;
+  void handle_actors_status() const;
 
 public:
   Channel const& get_channel() const { return channel_; }
@@ -52,7 +52,6 @@ public:
   static AppSide* initialize();
   static AppSide* get() { return instance_.get(); }
 };
-} // namespace mc
-} // namespace simgrid
+} // namespace simgrid::mc
 
 #endif
