@@ -10,8 +10,7 @@
 
 #include <type_traits>
 
-namespace simgrid {
-namespace mc {
+namespace simgrid::mc {
 
 /** A channel for exchanging messages between model-checker and model-checked app
  *
@@ -20,10 +19,7 @@ namespace mc {
  */
 class Channel {
   int socket_ = -1;
-  template <class M> static constexpr bool messageType()
-  {
-    return std::is_class<M>::value && std::is_trivial<M>::value;
-  }
+  template <class M> static constexpr bool messageType() { return std::is_class_v<M> && std::is_trivial_v<M>; }
 
 public:
   explicit Channel(int sock) : socket_(sock) {}
@@ -55,7 +51,6 @@ public:
 
   int get_socket() const { return socket_; }
 };
-} // namespace mc
-} // namespace simgrid
+} // namespace simgrid::mc
 
 #endif
