@@ -8,14 +8,10 @@
 
 // ***** Environment variables for passing context to the model-checked process
 
-/** Environment variable name used to pass the communication socket.
- *
- * It is set by `simgrid-mc` to enable MC support in the children processes
- */
-#define MC_ENV_SOCKET_FD "SIMGRID_MC_SOCKET_FD"
-
 #ifdef __cplusplus
 
+#include "src/kernel/actor/SimcallObserver.hpp"
+
 #include "mc/datatypes.h"
 #include "simgrid/forward.h" // aid_t
 #include <array>
@@ -25,18 +21,16 @@
 #include <xbt/utility.hpp>
 
 // ***** Messages
-namespace simgrid {
-namespace mc {
+namespace simgrid::mc {
 
 XBT_DECLARE_ENUM_CLASS(MessageType, NONE, INITIAL_ADDRESSES, CONTINUE, IGNORE_HEAP, UNIGNORE_HEAP, IGNORE_MEMORY,
-                       STACK_REGION, REGISTER_SYMBOL, DEADLOCK_CHECK, DEADLOCK_CHECK_REPLY, WAITING, SIMCALL_HANDLE,
-                       SIMCALL_IS_VISIBLE, SIMCALL_IS_VISIBLE_ANSWER, SIMCALL_TO_STRING, SIMCALL_TO_STRING_ANSWER,
-                       SIMCALL_DOT_LABEL, ASSERTION_FAILED, ACTOR_ENABLED, ACTOR_ENABLED_REPLY, FINALIZE);
-
-} // namespace mc
-} // namespace simgrid
+                       STACK_REGION, REGISTER_SYMBOL, DEADLOCK_CHECK, DEADLOCK_CHECK_REPLY, WAITING, SIMCALL_EXECUTE,
+                       SIMCALL_EXECUTE_ANSWER, ASSERTION_FAILED, ACTORS_STATUS, ACTORS_STATUS_REPLY, FINALIZE,
+                       FINALIZE_REPLY);
+} // namespace simgrid::mc
 
 constexpr unsigned MC_MESSAGE_LENGTH = 512;
+constexpr unsigned SIMCALL_SERIALIZATION_BUFFER_SIZE = 2048;
 
 /** Basic structure for a MC message
  *
@@ -63,8 +57,6 @@ struct s_mc_message_initial_addresses_t {
   simgrid::mc::MessageType type;
   xbt_mheap_t mmalloc_default_mdp;
   unsigned long* maxpid;
-  xbt_dynar_t actors;
-  xbt_dynar_t dead_actors;
 };
 
 struct s_mc_message_ignore_heap_t {
@@ -94,40 +86,30 @@ struct s_mc_message_register_symbol_t {
 };
 
 /* Server -> client */
-struct s_mc_message_simcall_handle_t {
+struct s_mc_message_simcall_execute_t {
   simgrid::mc::MessageType type;
   aid_t aid_;
   int times_considered_;
 };
+struct s_mc_message_simcall_execute_answer_t {
+  simgrid::mc::MessageType type;
+  std::array<char, SIMCALL_SERIALIZATION_BUFFER_SIZE> buffer;
+};
 
 struct s_mc_message_restore_t {
   simgrid::mc::MessageType type;
   int index;
 };
 
-struct s_mc_message_actor_enabled_t {
+struct s_mc_message_actors_status_answer_t {
   simgrid::mc::MessageType type;
-  aid_t aid; // actor ID
+  int count;
 };
-
-/* RPC */
-struct s_mc_message_simcall_is_visible_t { // MessageType::SIMCALL_IS_VISIBLE
-  simgrid::mc::MessageType type;
+struct s_mc_message_actors_status_one_t { // an array of `s_mc_message_actors_status_one_t[count]` is sent right after
+                                          // after a s_mc_message_actors_status_answer_t
   aid_t aid;
-};
-struct s_mc_message_simcall_is_visible_answer_t { // MessageType::SIMCALL_IS_VISIBLE_ANSWER
-  simgrid::mc::MessageType type;
-  bool value;
-};
-
-struct s_mc_message_simcall_to_string_t { // MessageType::SIMCALL_TO_STRING or MessageType::SIMCALL_DOT_LABEL
-  simgrid::mc::MessageType type;
-  aid_t aid;
-  int time_considered;
-};
-struct s_mc_message_simcall_to_string_answer_t { // MessageType::SIMCALL_TO_STRING_ANSWER
-  simgrid::mc::MessageType type;
-  char value[1024];
+  bool enabled;
+  int max_considered;
 };
 
 #endif // __cplusplus
