@@ -1,4 +1,4 @@
-/* Copyright (c) 2010-2021. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2010-2022. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -12,13 +12,15 @@
 #include <xbt/config.hpp>
 
 #include "src/internal_config.h" // HAVE_SMPI
-#include "src/surf/network_interface.hpp"
+#include "src/kernel/activity/CommImpl.hpp"
+#include "src/kernel/resource/NetworkModel.hpp"
 #if HAVE_SMPI
 #include "src/smpi/include/smpi_request.hpp"
 #include "src/smpi/plugins/ampi/ampi.hpp"
 #endif
 
 #include <boost/algorithm/string.hpp>
+#include <string_view>
 
 SIMGRID_REGISTER_PLUGIN(host_dvfs, "Dvfs support", &sg_host_dvfs_plugin_init)
 
@@ -42,7 +44,7 @@ static simgrid::config::Flag<std::string> cfg_governor("plugin/dvfs/governor",
                                                              {"performance", "TODO: Doc"}, {"powersave", "TODO: Doc"},
                                                        }),
 
-                                                       [](const std::string& val) {
+                                                       [](std::string_view val) {
                                                          if (val != "performance")
                                                            sg_host_dvfs_plugin_init();
                                                        });
@@ -51,10 +53,10 @@ static simgrid::config::Flag<int>
     cfg_min_pstate("plugin/dvfs/min-pstate",
                    "Which pstate is the minimum (and hence fastest) pstate for this governor?", 0);
 
-static const int max_pstate_not_limited = -1;
+static constexpr int MAX_PSTATE_NOT_LIMITED = -1;
 static simgrid::config::Flag<int>
     cfg_max_pstate("plugin/dvfs/max-pstate",
-                   "Which pstate is the maximum (and hence slowest) pstate for this governor?", max_pstate_not_limited);
+                   "Which pstate is the maximum (and hence slowest) pstate for this governor?", MAX_PSTATE_NOT_LIMITED);
 
 /** @addtogroup SURF_plugin_load
 
@@ -62,12 +64,9 @@ static simgrid::config::Flag<int>
 
 */
 
-XBT_LOG_NEW_DEFAULT_SUBCATEGORY(surf_plugin_dvfs, surf, "Logging specific to the SURF HostDvfs plugin");
+XBT_LOG_NEW_DEFAULT_SUBCATEGORY(host_dvfs, kernel, "Logging specific to the HostDvfs plugin");
 
-namespace simgrid {
-namespace plugin {
-
-namespace dvfs {
+namespace simgrid::plugin::dvfs {
 
 /**
  *  Add this to your host tag:
@@ -97,7 +96,7 @@ public:
   explicit Governor(simgrid::s4u::Host* ptr)
       : host_(ptr)
   {
-    if (cfg_max_pstate == max_pstate_not_limited)
+    if (cfg_max_pstate == MAX_PSTATE_NOT_LIMITED)
       max_pstate = host_->get_pstate_count() - 1;
     init();
   }
@@ -109,19 +108,16 @@ public:
 
   void init()
   {
-    const char* local_sampling_rate_config = host_->get_property(cfg_sampling_rate.get_name());
-    if (local_sampling_rate_config != nullptr) {
+    if (const char* local_sampling_rate_config = host_->get_property(cfg_sampling_rate.get_name())) {
       sampling_rate_ = std::stod(local_sampling_rate_config);
     } else {
       sampling_rate_ = cfg_sampling_rate;
     }
-    const char* local_min_pstate_config = host_->get_property(cfg_min_pstate.get_name());
-    if (local_min_pstate_config != nullptr) {
+    if (const char* local_min_pstate_config = host_->get_property(cfg_min_pstate.get_name())) {
       min_pstate = std::stoul(local_min_pstate_config);
     }
 
-    const char* local_max_pstate_config = host_->get_property(cfg_max_pstate.get_name());
-    if (local_max_pstate_config != nullptr) {
+    if (const char* local_max_pstate_config = host_->get_property(cfg_max_pstate.get_name())) {
       max_pstate = std::stoul(local_max_pstate_config);
     }
     xbt_assert(max_pstate <= host_->get_pstate_count() - 1, "Value for max_pstate too large!");
@@ -294,21 +290,25 @@ public:
         task_id           = 0;
       }
     });
-    simgrid::s4u::Exec::on_start.connect([this](simgrid::s4u::Exec const& activity) {
+    simgrid::s4u::Exec::on_start_cb([this](simgrid::s4u::Exec const& activity) {
       if (activity.get_host() == get_host())
         pre_task();
     });
-    simgrid::s4u::Exec::on_completion.connect([this](simgrid::s4u::Exec const& activity) {
+    simgrid::s4u::Activity::on_completion_cb([this](simgrid::s4u::Activity const& activity) {
+      const auto* exec = dynamic_cast<simgrid::s4u::Exec const*>(&activity);
+      if (exec == nullptr) // Only Execs are concerned here
+        return;
       // For more than one host (not yet supported), we can access the host via
       // simcalls_.front()->issuer->get_iface()->get_host()
-      if (activity.get_host() == get_host() && iteration_running) {
-        comp_timer += activity.get_finish_time() - activity.get_start_time();
+      if (exec->get_host() == get_host() && iteration_running) {
+        comp_timer += exec->get_finish_time() - exec->get_start_time();
       }
     });
     // FIXME I think that this fires at the same time for all hosts, so when the src sends something,
     // the dst will be notified even though it didn't even arrive at the recv yet
-    simgrid::s4u::Link::on_communicate.connect([this](const kernel::resource::NetworkAction& act) {
-      if ((get_host() == &act.get_src() || get_host() == &act.get_dst()) && iteration_running) {
+    kernel::activity::CommImpl::on_start.connect([this](const kernel::activity::CommImpl& comm) {
+      const auto* act = static_cast<kernel::resource::NetworkAction*>(comm.surf_action_);
+      if ((get_host() == &act->get_src() || get_host() == &act->get_dst()) && iteration_running) {
         post_task();
       }
     });
@@ -358,9 +358,7 @@ public:
   void update() override {}
 };
 #endif
-} // namespace dvfs
-} // namespace plugin
-} // namespace simgrid
+} // namespace simgrid::plugin::dvfs
 
 /* **************************** events  callback *************************** */
 static void on_host_added(simgrid::s4u::Host& host)
@@ -380,8 +378,7 @@ static void on_host_added(simgrid::s4u::Host& host)
     XBT_DEBUG("DVFS process on %s is a daemon: %d", daemon_proc->get_host()->get_cname(), daemon_proc->is_daemon());
 
     std::string dvfs_governor;
-    const char* host_conf = daemon_proc->get_host()->get_property("plugin/dvfs/governor");
-    if (host_conf != nullptr) {
+    if (const char* host_conf = daemon_proc->get_host()->get_property("plugin/dvfs/governor")) {
       dvfs_governor = std::string(host_conf);
       boost::algorithm::to_lower(dvfs_governor);
     } else {
@@ -439,5 +436,5 @@ void sg_host_dvfs_plugin_init()
 
   sg_host_load_plugin_init();
 
-  simgrid::s4u::Host::on_creation.connect(&on_host_added);
+  simgrid::s4u::Host::on_creation_cb(&on_host_added);
 }
