@@ -7,7 +7,7 @@
 #include <simgrid/s4u/Engine.hpp>
 
 #include "src/kernel/activity/CommImpl.hpp"
-#include "src/kernel/resource/StandardLinkImpl.hpp"
+#include "src/kernel/resource/NetworkModel.hpp"
 
 #include <limits>
 
@@ -34,8 +34,7 @@ SIMGRID_REGISTER_PLUGIN(link_load, "Link cumulated load.", &sg_link_load_plugin_
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(link_load, kernel, "Logging specific to the LinkLoad plugin");
 
-namespace simgrid {
-namespace plugin {
+namespace simgrid::plugin {
 
 class LinkLoad {
   s4u::Link* link_{};      /*< The link onto which this data is attached*/
@@ -67,7 +66,7 @@ public:
 
 xbt::Extension<s4u::Link, LinkLoad> LinkLoad::EXTENSION_ID;
 
-LinkLoad::LinkLoad(s4u::Link* ptr) : link_(ptr), is_tracked_(false)
+LinkLoad::LinkLoad(s4u::Link* ptr) : link_(ptr)
 {
   XBT_DEBUG("Instantiating a LinkLoad for link '%s'", link_->get_cname());
 }
@@ -156,8 +155,7 @@ double LinkLoad::get_average_bytes()
     return 0;
 }
 
-} // namespace plugin
-} // namespace simgrid
+} // namespace simgrid::plugin
 
 using simgrid::plugin::LinkLoad;
 
@@ -183,7 +181,8 @@ static void on_communication(const simgrid::kernel::activity::CommImpl& comm)
  */
 void sg_link_load_plugin_init()
 {
-  xbt_assert(simgrid::s4u::Engine::get_instance()->get_host_count() == 0,
+  xbt_assert(simgrid::s4u::Engine::get_instance()->get_host_count() == 0 &&
+                 simgrid::s4u::Engine::get_instance()->get_link_count() == 0,
              "Please call sg_link_load_plugin_init() BEFORE initializing the platform.");
   xbt_assert(not LinkLoad::EXTENSION_ID.valid(), "Double call to sg_link_load_plugin_init. Aborting.");
   LinkLoad::EXTENSION_ID = simgrid::s4u::Link::extension_create<LinkLoad>();
