@@ -5,6 +5,7 @@
 
 #include <simgrid/Exception.hpp>
 #include <simgrid/s4u/Activity.hpp>
+#include <simgrid/s4u/Comm.hpp>
 #include <simgrid/s4u/Engine.hpp>
 #include <simgrid/s4u/Exec.hpp>
 #include <simgrid/s4u/Io.hpp>
@@ -12,7 +13,7 @@
 
 #include "src/kernel/activity/ActivityImpl.hpp"
 #include "src/kernel/actor/ActorImpl.hpp"
-#include "src/kernel/actor/SimcallObserver.hpp"
+#include "src/kernel/actor/CommObserver.hpp"
 
 XBT_LOG_EXTERNAL_CATEGORY(s4u);
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(s4u_activity, s4u, "S4U activities");
@@ -24,7 +25,9 @@ template class xbt::Extendable<s4u::Activity>;
 namespace s4u {
 
 xbt::signal<void(Activity&)> Activity::on_veto;
-xbt::signal<void(Activity&)> Activity::on_completion;
+xbt::signal<void(Activity const&)> Activity::on_completion;
+xbt::signal<void(Activity const&)> Activity::on_suspended;
+xbt::signal<void(Activity const&)> Activity::on_resumed;
 
 std::set<Activity*>* Activity::vetoed_activities_ = nullptr;
 
@@ -52,10 +55,13 @@ Activity* Activity::wait_for(double timeout)
     vetoable_start();
 
   if (state_ == State::FAILED) {
+    if (dynamic_cast<Comm*>(this))
+      throw NetworkFailureException(XBT_THROW_POINT, "Cannot wait for a failed comm");
     if (dynamic_cast<Exec*>(this))
       throw HostFailureException(XBT_THROW_POINT, "Cannot wait for a failed exec");
     if (dynamic_cast<Io*>(this))
       throw StorageFailureException(XBT_THROW_POINT, "Cannot wait for a failed I/O");
+    THROW_IMPOSSIBLE;
   }
 
   kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
@@ -78,17 +84,56 @@ bool Activity::test()
   if (state_ == State::INITED || state_ == State::STARTING)
     this->vetoable_start();
 
-  if (kernel::actor::simcall([this] { return this->get_impl()->test(); })) {
+  kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
+  kernel::actor::ActivityTestSimcall observer{issuer, pimpl_.get()};
+  if (kernel::actor::simcall_answered([&observer] { return observer.get_activity()->test(observer.get_issuer()); },
+                                      &observer)) {
     complete(State::FINISHED);
     return true;
   }
-
   return false;
 }
 
+ssize_t Activity::test_any(const std::vector<ActivityPtr>& activities)
+{
+  std::vector<kernel::activity::ActivityImpl*> ractivities(activities.size());
+  std::transform(begin(activities), end(activities), begin(ractivities),
+                 [](const ActivityPtr& act) { return act->pimpl_.get(); });
+
+  kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
+  kernel::actor::ActivityTestanySimcall observer{issuer, ractivities};
+  ssize_t changed_pos = kernel::actor::simcall_answered(
+      [&observer] {
+        return kernel::activity::ActivityImpl::test_any(observer.get_issuer(), observer.get_activities());
+      },
+      &observer);
+  if (changed_pos != -1)
+    activities.at(changed_pos)->complete(State::FINISHED);
+  return changed_pos;
+}
+
+ssize_t Activity::wait_any_for(const std::vector<ActivityPtr>& activities, double timeout)
+{
+  std::vector<kernel::activity::ActivityImpl*> ractivities(activities.size());
+  std::transform(begin(activities), end(activities), begin(ractivities),
+                 [](const ActivityPtr& activity) { return activity->pimpl_.get(); });
+
+  kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
+  kernel::actor::ActivityWaitanySimcall observer{issuer, ractivities, timeout};
+  ssize_t changed_pos = kernel::actor::simcall_blocking(
+      [&observer] {
+        kernel::activity::ActivityImpl::wait_any_for(observer.get_issuer(), observer.get_activities(),
+                                                     observer.get_timeout());
+      },
+      &observer);
+  if (changed_pos != -1)
+    activities.at(changed_pos)->complete(State::FINISHED);
+  return changed_pos;
+}
+
 Activity* Activity::cancel()
 {
-  kernel::actor::simcall([this] {
+  kernel::actor::simcall_answered([this] {
     XBT_HERE();
     if (pimpl_)
       pimpl_->cancel();
