@@ -12,13 +12,12 @@
 
 #include <mutex>
 
-namespace simgrid {
-namespace s4u {
+namespace simgrid::s4u {
 
 ConditionVariablePtr ConditionVariable::create()
 {
   kernel::activity::ConditionVariableImpl* cond =
-      kernel::actor::simcall([] { return new kernel::activity::ConditionVariableImpl(); });
+      kernel::actor::simcall_answered([] { return new kernel::activity::ConditionVariableImpl(); });
   return ConditionVariablePtr(cond->get_iface(), false);
 }
 
@@ -77,12 +76,12 @@ std::cv_status ConditionVariable::wait_until(const std::unique_lock<Mutex>& lock
  */
 void ConditionVariable::notify_one()
 {
-  simgrid::kernel::actor::simcall([this]() { pimpl_->signal(); });
+  simgrid::kernel::actor::simcall_answered([this]() { pimpl_->signal(); });
 }
 
 void ConditionVariable::notify_all()
 {
-  simgrid::kernel::actor::simcall([this]() { pimpl_->broadcast(); });
+  simgrid::kernel::actor::simcall_answered([this]() { pimpl_->broadcast(); });
 }
 
 void intrusive_ptr_add_ref(const ConditionVariable* cond)
@@ -95,8 +94,7 @@ void intrusive_ptr_release(const ConditionVariable* cond)
   intrusive_ptr_release(cond->pimpl_);
 }
 
-} // namespace s4u
-} // namespace simgrid
+} // namespace simgrid::s4u
 
 /* **************************** Public C interface *************************** */
 sg_cond_t sg_cond_init()
@@ -111,7 +109,7 @@ void sg_cond_wait(sg_cond_t cond, sg_mutex_t mutex)
 
 int sg_cond_wait_for(sg_cond_t cond, sg_mutex_t mutex, double delay)
 {
-  std::unique_lock<simgrid::s4u::Mutex> lock(*mutex);
+  std::unique_lock lock(*mutex);
   return cond->wait_for(lock, delay) == std::cv_status::timeout;
 }
 
