@@ -11,8 +11,7 @@
 #include "src/kernel/actor/ActorImpl.hpp"
 #include "src/kernel/actor/SimcallObserver.hpp"
 
-namespace simgrid {
-namespace s4u {
+namespace simgrid::s4u {
 xbt::signal<void(Io const&)> Io::on_start;
 
 Io::Io(kernel::activity::IoImplPtr pimpl)
@@ -28,7 +27,7 @@ IoPtr Io::init()
 
 Io* Io::start()
 {
-  kernel::actor::simcall(
+  kernel::actor::simcall_answered(
       [this] { (*boost::static_pointer_cast<kernel::activity::IoImpl>(pimpl_)).set_name(get_name()).start(); });
 
   if (suspended_)
@@ -41,27 +40,17 @@ Io* Io::start()
 
 ssize_t Io::wait_any_for(const std::vector<IoPtr>& ios, double timeout)
 {
-  std::vector<kernel::activity::IoImpl*> rios(ios.size());
-  std::transform(begin(ios), end(ios), begin(rios),
-                 [](const IoPtr& io) { return static_cast<kernel::activity::IoImpl*>(io->pimpl_.get()); });
-
-  kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
-  kernel::actor::IoWaitanySimcall observer{issuer, rios, timeout};
-  ssize_t changed_pos = kernel::actor::simcall_blocking(
-      [&observer] {
-        kernel::activity::IoImpl::wait_any_for(observer.get_issuer(), observer.get_ios(), observer.get_timeout());
-      },
-      &observer);
-  if (changed_pos != -1)
-    ios.at(changed_pos)->complete(State::FINISHED);
-  return changed_pos;
+  std::vector<ActivityPtr> activities;
+  for (const auto& io : ios)
+    activities.push_back(boost::dynamic_pointer_cast<Activity>(io));
+  return Activity::wait_any_for(activities, timeout);
 }
 
 IoPtr Io::set_disk(const_sg_disk_t disk)
 {
   xbt_assert(state_ == State::INITED || state_ == State::STARTING, "Cannot set disk once the Io is started");
 
-  kernel::actor::simcall(
+  kernel::actor::simcall_answered(
       [this, disk] { boost::static_pointer_cast<kernel::activity::IoImpl>(pimpl_)->set_disk(disk->get_impl()); });
 
   // Setting the disk may allow to start the activity, let's try
@@ -75,7 +64,7 @@ IoPtr Io::set_priority(double priority)
 {
   xbt_assert(state_ == State::INITED || state_ == State::STARTING,
              "Cannot change the priority of an io after its start");
-  kernel::actor::simcall([this, priority] {
+  kernel::actor::simcall_answered([this, priority] {
     boost::static_pointer_cast<kernel::activity::IoImpl>(pimpl_)->set_sharing_penalty(1. / priority);
   });
   return this;
@@ -84,7 +73,7 @@ IoPtr Io::set_priority(double priority)
 IoPtr Io::set_size(sg_size_t size)
 {
   xbt_assert(state_ == State::INITED || state_ == State::STARTING, "Cannot set size once the Io is started");
-  kernel::actor::simcall(
+  kernel::actor::simcall_answered(
       [this, size] { boost::static_pointer_cast<kernel::activity::IoImpl>(pimpl_)->set_size(size); });
   Activity::set_remaining(size);
   return this;
@@ -93,14 +82,14 @@ IoPtr Io::set_size(sg_size_t size)
 IoPtr Io::set_op_type(OpType type)
 {
   xbt_assert(state_ == State::INITED || state_ == State::STARTING, "Cannot set size once the Io is started");
-  kernel::actor::simcall(
+  kernel::actor::simcall_answered(
       [this, type] { boost::static_pointer_cast<kernel::activity::IoImpl>(pimpl_)->set_type(type); });
   return this;
 }
 
 IoPtr Io::update_priority(double priority)
 {
-  kernel::actor::simcall([this, priority] {
+  kernel::actor::simcall_answered([this, priority] {
     boost::static_pointer_cast<kernel::activity::IoImpl>(pimpl_)->update_sharing_penalty(1. / priority);
   });
   return this;
@@ -109,7 +98,7 @@ IoPtr Io::update_priority(double priority)
 /** @brief Returns the amount of flops that remain to be done */
 double Io::get_remaining() const
 {
-  return kernel::actor::simcall(
+  return kernel::actor::simcall_answered(
       [this]() { return boost::static_pointer_cast<kernel::activity::IoImpl>(pimpl_)->get_remaining(); });
 }
 
@@ -123,5 +112,4 @@ bool Io::is_assigned() const
   return boost::static_pointer_cast<kernel::activity::IoImpl>(pimpl_)->get_disk() != nullptr;
 }
 
-} // namespace s4u
-} // namespace simgrid
+} // namespace simgrid::s4u
