@@ -12,8 +12,7 @@
 XBT_LOG_EXTERNAL_CATEGORY(s4u);
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(s4u_channel, s4u, "S4U Communication Mailboxes");
 
-namespace simgrid {
-namespace s4u {
+namespace simgrid::s4u {
 
 const xbt::string& Mailbox::get_name() const
 {
@@ -73,7 +72,7 @@ kernel::activity::CommImplPtr Mailbox::front() const
 
 void Mailbox::set_receiver(ActorPtr actor)
 {
-  kernel::actor::simcall([this, actor]() { this->pimpl_->set_receiver(actor); });
+  kernel::actor::simcall_answered([this, actor]() { this->pimpl_->set_receiver(actor); });
 }
 
 /** @brief get the receiver (process associated to the mailbox) */
@@ -88,7 +87,7 @@ CommPtr Mailbox::put_init()
 {
   CommPtr res(new Comm());
   res->sender_  = kernel::actor::ActorImpl::self();
-  res->mailbox_ = this;
+  res->set_mailbox(this);
   return res;
 }
 
@@ -123,19 +122,24 @@ void Mailbox::put(void* payload, uint64_t simulated_size_in_bytes, double timeou
 
 CommPtr Mailbox::get_init()
 {
-  CommPtr res(new Comm());
+  auto res       = CommPtr(new Comm())->set_mailbox(this);
   res->receiver_ = kernel::actor::ActorImpl::self();
-  res->mailbox_  = this;
   return res;
 }
 
 kernel::activity::ActivityImplPtr
-Mailbox::iprobe(int type, bool (*match_fun)(void*, void*, kernel::activity::CommImpl*), void* data)
+Mailbox::iprobe(int type, const std::function<bool(void*, void*, kernel::activity::CommImpl*)>& match_fun, void* data)
 {
-  return kernel::actor::simcall([this, type, match_fun, data] { return pimpl_->iprobe(type, match_fun, data); });
+  return kernel::actor::simcall_answered(
+      [this, type, &match_fun, data] { return pimpl_->iprobe(type, match_fun, data); });
 }
-} // namespace s4u
-} // namespace simgrid
+
+void Mailbox::clear()
+{
+  kernel::actor::simcall_answered([this]() { this->pimpl_->clear(true); });
+}
+
+} // namespace simgrid::s4u
 
 /* **************************** Public C interface *************************** */
 sg_mailbox_t sg_mailbox_by_name(const char* alias)
