@@ -12,16 +12,10 @@
 #include <simgrid/zone.h>
 #include <xbt/parse_units.hpp>
 
-#include "src/kernel/resource/LinkImpl.hpp"
-#include "src/kernel/resource/StandardLinkImpl.hpp"
+#include "src/kernel/resource/NetworkModel.hpp"
 
-namespace simgrid {
-namespace s4u {
+namespace simgrid::s4u {
 
-xbt::signal<void(bool symmetrical, kernel::routing::NetPoint* src, kernel::routing::NetPoint* dst,
-                 kernel::routing::NetPoint* gw_src, kernel::routing::NetPoint* gw_dst,
-                 std::vector<kernel::resource::StandardLinkImpl*> const& link_list)>
-    NetZone::on_route_creation;
 xbt::signal<void(NetZone const&)> NetZone::on_creation;
 xbt::signal<void(NetZone const&)> NetZone::on_seal;
 
@@ -38,7 +32,7 @@ const char* NetZone::get_property(const std::string& key) const
 
 void NetZone::set_property(const std::string& key, const std::string& value)
 {
-  kernel::actor::simcall([this, &key, &value] { pimpl_->set_property(key, value); });
+  kernel::actor::simcall_answered([this, &key, &value] { pimpl_->set_property(key, value); });
 }
 
 /** @brief Returns the list of direct children (no grand-children) */
@@ -50,12 +44,6 @@ std::vector<NetZone*> NetZone::get_children() const
   return res;
 }
 
-NetZone* NetZone::add_child(NetZone* new_zone) // XBT_ATTRIB_DEPRECATED_v332
-{
-  new_zone->set_parent(this);
-  return this;
-}
-
 const std::string& NetZone::get_name() const
 {
   return pimpl_->get_name();
@@ -66,11 +54,6 @@ const char* NetZone::get_cname() const
   return pimpl_->get_cname();
 }
 
-NetZone* NetZone::get_father() const // XBT_ATTRIB_DEPRECATED_v331
-{
-  return pimpl_->get_parent()->get_iface();
-}
-
 NetZone* NetZone::get_parent() const
 {
   return pimpl_->get_parent()->get_iface();
@@ -78,7 +61,7 @@ NetZone* NetZone::get_parent() const
 
 NetZone* NetZone::set_parent(const NetZone* parent)
 {
-  kernel::actor::simcall([this, parent] { pimpl_->set_parent(parent->get_impl()); });
+  kernel::actor::simcall_answered([this, parent] { pimpl_->set_parent(parent->get_impl()); });
   return this;
 }
 
@@ -92,7 +75,7 @@ std::vector<Host*> NetZone::get_all_hosts() const
   return pimpl_->get_all_hosts();
 }
 
-int NetZone::get_host_count() const
+size_t NetZone::get_host_count() const
 {
   return pimpl_->get_host_count();
 }
@@ -102,17 +85,6 @@ unsigned long NetZone::add_component(kernel::routing::NetPoint* elm)
   return pimpl_->add_component(elm);
 }
 
-// XBT_ATTRIB_DEPRECATED_v332
-std::vector<LinkInRoute>
-NetZone::convert_to_linkInRoute(const std::vector<kernel::resource::StandardLinkImpl*>& link_list)
-{
-  std::vector<LinkInRoute> links;
-  for (const auto* link : link_list) {
-    links.emplace_back(LinkInRoute(link->get_iface()));
-  }
-  return links;
-}
-
 void NetZone::add_route(kernel::routing::NetPoint* src, kernel::routing::NetPoint* dst,
                         kernel::routing::NetPoint* gw_src, kernel::routing::NetPoint* gw_dst,
                         const std::vector<LinkInRoute>& link_list, bool symmetrical)
@@ -120,22 +92,6 @@ void NetZone::add_route(kernel::routing::NetPoint* src, kernel::routing::NetPoin
   pimpl_->add_route(src, dst, gw_src, gw_dst, link_list, symmetrical);
 }
 
-// XBT_ATTRIB_DEPRECATED_v332
-void NetZone::add_route(kernel::routing::NetPoint* src, kernel::routing::NetPoint* dst,
-                        kernel::routing::NetPoint* gw_src, kernel::routing::NetPoint* gw_dst,
-                        const std::vector<kernel::resource::StandardLinkImpl*>& link_list, bool symmetrical)
-{
-  pimpl_->add_route(src, dst, gw_src, gw_dst, convert_to_linkInRoute(link_list), symmetrical);
-}
-
-// XBT_ATTRIB_DEPRECATED_v332
-void NetZone::add_bypass_route(kernel::routing::NetPoint* src, kernel::routing::NetPoint* dst,
-                               kernel::routing::NetPoint* gw_src, kernel::routing::NetPoint* gw_dst,
-                               const std::vector<kernel::resource::StandardLinkImpl*>& link_list, bool /*symmetrical*/)
-{
-  pimpl_->add_bypass_route(src, dst, gw_src, gw_dst, convert_to_linkInRoute(link_list));
-}
-
 void NetZone::add_bypass_route(kernel::routing::NetPoint* src, kernel::routing::NetPoint* dst,
                                kernel::routing::NetPoint* gw_src, kernel::routing::NetPoint* gw_dst,
                                const std::vector<LinkInRoute>& link_list)
@@ -154,7 +110,7 @@ void NetZone::extract_xbt_graph(const s_xbt_graph_t* graph, std::map<std::string
 
 NetZone* NetZone::seal()
 {
-  kernel::actor::simcall([this] { pimpl_->seal(); });
+  kernel::actor::simcall_answered([this] { pimpl_->seal(); });
   return this;
 }
 
@@ -165,7 +121,7 @@ s4u::Host* NetZone::create_host(const std::string& name, double speed)
 
 s4u::Host* NetZone::create_host(const std::string& name, const std::vector<double>& speed_per_pstate)
 {
-  return kernel::actor::simcall(
+  return kernel::actor::simcall_answered(
       [this, &name, &speed_per_pstate] { return pimpl_->create_host(name, speed_per_pstate); });
 }
 
@@ -186,7 +142,7 @@ s4u::Link* NetZone::create_link(const std::string& name, double bandwidth)
 
 s4u::Link* NetZone::create_link(const std::string& name, const std::vector<double>& bandwidths)
 {
-  return kernel::actor::simcall([this, &name, &bandwidths] { return pimpl_->create_link(name, bandwidths); });
+  return kernel::actor::simcall_answered([this, &name, &bandwidths] { return pimpl_->create_link(name, bandwidths); });
 }
 
 s4u::Link* NetZone::create_link(const std::string& name, const std::string& bandwidth)
@@ -208,7 +164,7 @@ s4u::SplitDuplexLink* NetZone::create_split_duplex_link(const std::string& name,
 
 s4u::SplitDuplexLink* NetZone::create_split_duplex_link(const std::string& name, double bandwidth)
 {
-  return kernel::actor::simcall(
+  return kernel::actor::simcall_answered(
       [this, &name, &bandwidth] { return pimpl_->create_split_duplex_link(name, std::vector<double>{bandwidth}); });
 }
 
@@ -230,7 +186,7 @@ s4u::Link* NetZone::create_link(const std::string& name, const std::vector<std::
 
 kernel::routing::NetPoint* NetZone::create_router(const std::string& name)
 {
-  return kernel::actor::simcall([this, &name] { return pimpl_->create_router(name); });
+  return kernel::actor::simcall_answered([this, &name] { return pimpl_->create_router(name); });
 }
 
 kernel::routing::NetPoint* NetZone::get_netpoint()
@@ -243,8 +199,7 @@ kernel::resource::NetworkModelIntf* NetZone::get_network_model() const
   kernel::resource::NetworkModelIntf* model = pimpl_->get_network_model().get();
   return model;
 }
-} // namespace s4u
-} // namespace simgrid
+} // namespace simgrid::s4u
 
 /* **************************** Public C interface *************************** */
 
