@@ -12,9 +12,8 @@
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(s4u_vm, s4u, "S4U virtual machines");
 
-namespace simgrid {
-namespace s4u {
-xbt::signal<void(VirtualMachine&)> VirtualMachine::on_creation;
+namespace simgrid::s4u {
+xbt::signal<void(VirtualMachine&)> VirtualMachine::on_vm_creation;
 xbt::signal<void(VirtualMachine const&)> VirtualMachine::on_start;
 xbt::signal<void(VirtualMachine const&)> VirtualMachine::on_started;
 xbt::signal<void(VirtualMachine const&)> VirtualMachine::on_shutdown;
@@ -22,7 +21,7 @@ xbt::signal<void(VirtualMachine const&)> VirtualMachine::on_suspend;
 xbt::signal<void(VirtualMachine const&)> VirtualMachine::on_resume;
 xbt::signal<void(VirtualMachine const&)> VirtualMachine::on_migration_start;
 xbt::signal<void(VirtualMachine const&)> VirtualMachine::on_migration_end;
-xbt::signal<void(VirtualMachine const&)> VirtualMachine::on_destruction;
+xbt::signal<void(VirtualMachine const&)> VirtualMachine::on_vm_destruction;
 
 xbt::Extension<Host, VmHostExt> VmHostExt::EXTENSION_ID;
 
@@ -36,81 +35,34 @@ VirtualMachine::VirtualMachine(const std::string& name, s4u::Host* physical_host
     : Host(new kernel::resource::VirtualMachineImpl(name, this, physical_host, core_amount, ramsize))
     , pimpl_vm_(dynamic_cast<kernel::resource::VirtualMachineImpl*>(Host::get_impl()))
 {
-  XBT_DEBUG("Create VM %s", get_cname());
+  physical_host->get_impl()->create_vm(name, this);
+}
 
-  /* Currently, a VM uses the network resource of its physical host */
-  set_netpoint(physical_host->get_netpoint());
-
-  // Create a VCPU for this VM
-  std::vector<double> speeds;
-  for (unsigned long i = 0; i < physical_host->get_pstate_count(); i++)
-    speeds.push_back(physical_host->get_pstate_speed(i));
-
-  physical_host->get_netpoint()
-      ->get_englobing_zone()
-      ->get_cpu_vm_model()
-      ->create_cpu(this, speeds)
-      ->set_core_count(core_amount)
-      ->seal();
-
-  if (physical_host->get_pstate() != 0)
-    set_pstate(physical_host->get_pstate());
-
-  seal(); // seal this host
-  s4u::VirtualMachine::on_creation(*this);
+VirtualMachine::VirtualMachine(kernel::resource::VirtualMachineImpl* impl)
+    : Host(impl), pimpl_vm_(dynamic_cast<kernel::resource::VirtualMachineImpl*>(Host::get_impl()))
+{
 }
 
 void VirtualMachine::start()
 {
-  on_start(*this);
-
-  VmHostExt::ensureVmExtInstalled();
-
-  kernel::actor::simcall([this]() {
-    Host* pm = this->pimpl_vm_->get_physical_host();
-    if (pm->extension<VmHostExt>() == nullptr)
-      pm->extension_set(new VmHostExt());
-
-    size_t pm_ramsize = pm->extension<VmHostExt>()->ramsize;
-    if (pm_ramsize && not pm->extension<VmHostExt>()->overcommit) { /* Need to verify that we don't overcommit */
-      /* Retrieve the memory occupied by the VMs on that host. Yep, we have to traverse all VMs of all hosts for that */
-      size_t total_ramsize_of_vms = 0;
-      for (VirtualMachine* const& ws_vm : kernel::resource::VirtualMachineImpl::allVms_)
-        if (pm == ws_vm->get_pm())
-          total_ramsize_of_vms += ws_vm->get_ramsize();
-
-      if (total_ramsize_of_vms + get_ramsize() > pm_ramsize) {
-        XBT_WARN("cannot start %s@%s due to memory shortage: get_ramsize() %zu, free %zu, pm_ramsize %zu (bytes).",
-                 get_cname(), pm->get_cname(), get_ramsize(), pm_ramsize - total_ramsize_of_vms, pm_ramsize);
-        throw VmFailureException(XBT_THROW_POINT,
-                                 xbt::string_printf("Memory shortage on host '%s', VM '%s' cannot be started",
-                                                    pm->get_cname(), get_cname()));
-      }
-    }
-    this->pimpl_vm_->set_state(State::RUNNING);
-  });
-
-  on_started(*this);
+  kernel::actor::simcall_answered([this]() { pimpl_vm_->start(); });
 }
 
 void VirtualMachine::suspend()
 {
-  on_suspend(*this);
-  kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
-  kernel::actor::simcall([this, issuer]() { pimpl_vm_->suspend(issuer); });
+  const kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
+  kernel::actor::simcall_answered([this, issuer]() { pimpl_vm_->suspend(issuer); });
 }
 
 void VirtualMachine::resume()
 {
   pimpl_vm_->resume();
-  on_resume(*this);
 }
 
 void VirtualMachine::shutdown()
 {
   kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
-  kernel::actor::simcall([this, issuer]() { pimpl_vm_->shutdown(issuer); });
-  on_shutdown(*this);
+  kernel::actor::simcall_answered([this, issuer]() { pimpl_vm_->shutdown(issuer); });
 }
 
 void VirtualMachine::destroy()
@@ -120,16 +72,10 @@ void VirtualMachine::destroy()
     shutdown();
 
     XBT_DEBUG("destroy %s", get_cname());
-    on_destruction(*this);
+    on_vm_destruction(*this);
     /* Then, destroy the VM object */
-    kernel::actor::simcall([this]() {
-      get_vm_impl()->vm_destroy();
-      get_impl()->destroy();
-
-      /* Don't free these things twice: they are the ones of my physical host */
-      set_netpoint(nullptr);
-      delete this;
-    });
+    kernel::actor::simcall_answered(
+        [this]() { get_vm_impl()->get_physical_host()->get_impl()->destroy_vm(get_name()); });
   };
 
   if (not this_actor::is_maestro() && this_actor::get_host() == this) {
@@ -150,13 +96,13 @@ simgrid::s4u::Host* VirtualMachine::get_pm() const
 
 VirtualMachine* VirtualMachine::set_pm(simgrid::s4u::Host* pm)
 {
-  kernel::actor::simcall([this, pm]() { pimpl_vm_->set_physical_host(pm); });
+  kernel::actor::simcall_answered([this, pm]() { pimpl_vm_->set_physical_host(pm); });
   return this;
 }
 
 VirtualMachine::State VirtualMachine::get_state() const
 {
-  return kernel::actor::simcall([this]() { return pimpl_vm_->get_state(); });
+  return kernel::actor::simcall_answered([this]() { return pimpl_vm_->get_state(); });
 }
 
 size_t VirtualMachine::get_ramsize() const
@@ -197,24 +143,21 @@ VirtualMachine* VirtualMachine::set_ramsize(size_t ramsize)
  */
 VirtualMachine* VirtualMachine::set_bound(double bound)
 {
-  kernel::actor::simcall([this, bound]() { pimpl_vm_->set_bound(bound); });
+  kernel::actor::simcall_answered([this, bound]() { pimpl_vm_->set_bound(bound); });
   return this;
 }
 
 void VirtualMachine::start_migration() const
 {
   pimpl_vm_->start_migration();
-  on_migration_start(*this);
 }
 
 void VirtualMachine::end_migration() const
 {
   pimpl_vm_->end_migration();
-  on_migration_end(*this);
 }
 
-} // namespace s4u
-} // namespace simgrid
+} // namespace simgrid::s4u
 
 /* **************************** Public C interface *************************** */
 
