@@ -65,8 +65,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * Author: Ahmad Faraj
  ****************************************************************************/
 
-namespace simgrid{
-namespace smpi{
+namespace simgrid::smpi {
 
 int
 allgatherv__pair(const void *send_buff, int send_count,
@@ -105,5 +104,4 @@ allgatherv__pair(const void *send_buff, int send_count,
   return MPI_SUCCESS;
 }
 
-}
-}
+} // namespace simgrid::smpi
