@@ -18,8 +18,7 @@
 */
 
 //#include <star-reduction.c>
-namespace simgrid {
-namespace smpi {
+namespace simgrid::smpi {
 int allreduce__lr(const void *sbuf, void *rbuf, int rcount,
                   MPI_Datatype dtype, MPI_Op op, MPI_Comm comm)
 {
@@ -38,7 +37,7 @@ int allreduce__lr(const void *sbuf, void *rbuf, int rcount,
 
   if (rcount < size) {
     XBT_INFO("MPI_allreduce_lr: communication size smaller than number of process, use default MPI_allreduce.");
-    allreduce__default(sbuf, rbuf, rcount, dtype, op, comm);
+    allreduce__redbcast(sbuf, rbuf, rcount, dtype, op, comm);
     return MPI_SUCCESS;
   }
 
@@ -101,5 +100,4 @@ int allreduce__lr(const void *sbuf, void *rbuf, int rcount,
 
   return 0;
 }
-}
-}
+} // namespace simgrid::smpi
