@@ -6,8 +6,7 @@
 
 #include "../colls_private.hpp"
 //#include <star-reduction.c>
-namespace simgrid{
-namespace smpi{
+namespace simgrid::smpi {
 int allreduce__rdb(const void *sbuff, void *rbuff, int count,
                    MPI_Datatype dtype, MPI_Op op, MPI_Comm comm)
 {
@@ -128,5 +127,4 @@ int allreduce__rdb(const void *sbuff, void *rbuff, int count,
   smpi_free_tmp_buffer(tmp_buf);
   return MPI_SUCCESS;
 }
-}
-}
+} // namespace simgrid::smpi
