@@ -14,8 +14,7 @@ This function performs all-reduce operation as follow.
 3) allgather - inter between root of each SMP node
 4) binomial_tree bcast inside each SMP node
 */
-namespace simgrid{
-namespace smpi{
+namespace simgrid::smpi {
 int allreduce__smp_rsag_lr(const void *send_buf, void *recv_buf,
                            int count, MPI_Datatype dtype,
                            MPI_Op op, MPI_Comm comm)
@@ -256,5 +255,4 @@ int allreduce__smp_rsag_lr(const void *send_buf, void *recv_buf,
   smpi_free_tmp_buffer(tmp_buf);
   return MPI_SUCCESS;
 }
-}
-}
+} // namespace simgrid::smpi
