@@ -28,8 +28,7 @@
  * Author: Ahmad Faraj
 
  ****************************************************************************/
-namespace simgrid{
-namespace smpi{
+namespace simgrid::smpi {
 int alltoall__pair_rma(const void *send_buff, int send_count, MPI_Datatype send_type,
                        void *recv_buff, int recv_count, MPI_Datatype recv_type,
                        MPI_Comm comm)
@@ -58,7 +57,7 @@ int alltoall__pair_rma(const void *send_buff, int send_count, MPI_Datatype send_
             rank /* send_chunk*/, send_count, send_type);
   }
   win->fence(assert);
-  delete win;
+  simgrid::smpi::Win::del(win);
   return 0;
 }
 
@@ -96,5 +95,4 @@ int alltoall__pair(const void *send_buff, int send_count,
 
   return MPI_SUCCESS;
 }
-}
-}
+} // namespace simgrid::smpi
