@@ -26,8 +26,7 @@
  * Author: Ahmad Faraj
 
  ****************************************************************************/
-namespace simgrid{
-namespace smpi{
+namespace simgrid::smpi {
 int alltoallv__pair_one_barrier(const void *send_buff, const int *send_counts, const int *send_disps,
                                 MPI_Datatype send_type,
                                 void *recv_buff,  const int *recv_counts, const int *recv_disps,                                                                                  MPI_Datatype recv_type, MPI_Comm comm)
@@ -60,5 +59,4 @@ int alltoallv__pair_one_barrier(const void *send_buff, const int *send_counts, c
 
   return MPI_SUCCESS;
 }
-}
-}
+} // namespace simgrid::smpi
