@@ -11,8 +11,7 @@ static int bcast_NTSL_segment_size_in_byte = 8192;
 /* Non-topology-specific pipelined linear-bcast function
    0->1, 1->2 ,2->3, ....., ->last node : in a pipeline fashion
 */
-namespace simgrid{
-namespace smpi{
+namespace simgrid::smpi {
 int bcast__NTSL_Isend(void *buf, int count, MPI_Datatype datatype,
                       int root, MPI_Comm comm)
 {
@@ -123,5 +122,4 @@ int bcast__NTSL_Isend(void *buf, int count, MPI_Datatype datatype,
   return MPI_SUCCESS;
 }
 
-}
-}
+} // namespace simgrid::smpi
