@@ -7,8 +7,7 @@
 #include "../colls_private.hpp"
 
 int bcast_SMP_linear_segment_byte = 8192;
-namespace simgrid{
-namespace smpi{
+namespace simgrid::smpi {
 int bcast__SMP_linear(void *buf, int count,
                       MPI_Datatype datatype, int root,
                       MPI_Comm comm)
@@ -171,5 +170,4 @@ int bcast__SMP_linear(void *buf, int count,
   return MPI_SUCCESS;
 }
 
-}
-}
+} // namespace simgrid::smpi
