@@ -9,9 +9,10 @@
 #include "private.hpp"
 #include "simgrid/s4u/Mailbox.hpp"
 #include "src/instr/instr_smpi.hpp"
+#include "xbt/xbt_os_time.h"
+#include <string_view>
 
-namespace simgrid {
-namespace smpi {
+namespace simgrid::smpi {
 
 class ActorExt {
   double simulated_ = 0 /* Used to time with simulated_start/elapsed */;
@@ -56,11 +57,13 @@ public:
   int finalized() const;
   int initializing() const;
   int initialized() const;
+  int finalizing() const;
   void mark_as_initialized();
+  void mark_as_finalizing();
   void set_replaying(bool value);
   bool replaying() const;
   std::string get_instance_id() const { return instance_id_;}
-  void set_tracing_category(const std::string& category) { tracing_category_ = category; }
+  void set_tracing_category(std::string_view category) { tracing_category_ = category; }
   const std::string& get_tracing_category() const { return tracing_category_; }
   smpi_trace_call_location_t* call_location();
   void set_privatized_region(smpi_privatization_region_t region);
@@ -91,7 +94,6 @@ public:
   int set_bsend_buffer(void* buf, int size);
 };
 
-} // namespace smpi
-} // namespace simgrid
+} // namespace simgrid::smpi
 
 #endif
