@@ -15,12 +15,11 @@
 #include "smpi_topo.hpp"
 #include "smpi_config.hpp"
 
-namespace simgrid{
-namespace smpi{
+namespace simgrid::smpi {
 
 class Comm : public F2C, public Keyval{
   friend Topo;
-  MPI_Group group_;
+  MPI_Group group_         = MPI_GROUP_NULL;
   SMPI_Topo_type topoType_ = MPI_INVALID_TOPO;
   std::shared_ptr<Topo> topo_; // to be replaced by an union
   int refcount_          = 1;
@@ -28,18 +27,23 @@ class Comm : public F2C, public Keyval{
   MPI_Comm intra_comm_   = MPI_COMM_NULL; // intra-node communicator. For MPI_COMM_WORLD this can't be used, as var is
                                           // global. Use an intracomm stored in the process data instead
   int* leaders_map_     = nullptr;        // who is the leader of each process
-  int is_uniform_       = 1;
+  bool is_uniform_      = true;
   int* non_uniform_map_ = nullptr; // set if smp nodes have a different number of processes allocated
-  int is_blocked_       = 0;       // are ranks allocated on the same smp node contiguous ?
+  bool is_blocked_      = false;   // are ranks allocated on the same smp node contiguous?
   bool is_smp_comm_     = false;   // set to false in case this is already an intra-comm or a leader-comm to avoid
                                    // recursion
   std::list<MPI_Win> rma_wins_; // attached windows for synchronization.
   std::string name_;
   MPI_Info info_ = MPI_INFO_NULL;
-  int id_;
+  int id_                      = MPI_UNDEFINED;
   MPI_Errhandler errhandler_ =  _smpi_cfg_default_errhandler_is_error ? MPI_ERRORS_ARE_FATAL : MPI_ERRORS_RETURN;;
   MPI_Errhandler* errhandlers_ = nullptr; //for MPI_COMM_WORLD only
 
+  std::unordered_map<std::string, unsigned int> sent_messages_;
+  std::unordered_map<std::string, unsigned int> recv_messages_;
+  unsigned int collectives_count_ = 0;
+  std::vector<unsigned int> collectives_counts_; // for MPI_COMM_WORLD only
+
 public:
   static std::unordered_map<int, smpi_key_elem> keyvals_;
   static int keyval_id_;
@@ -90,9 +94,14 @@ public:
   void remove_rma_win(MPI_Win win);
   void finish_rma_calls() const;
   MPI_Comm split_type(int type, int key, const Info* info);
+  unsigned int get_sent_messages_count(int src, int dst, int tag);
+  void increment_sent_messages_count(int src, int dst, int tag);
+  unsigned int get_received_messages_count(int src, int dst, int tag);
+  void increment_received_messages_count(int src, int dst, int tag);
+  unsigned int get_collectives_count();
+  void increment_collectives_count();
 };
 
-} // namespace smpi
-} // namespace simgrid
+} // namespace simgrid::smpi
 
 #endif
