@@ -5,13 +5,11 @@
 
 #include "private.hpp"
 #include <boost/algorithm/string.hpp>
-#include <simgrid/s4u/Actor.hpp>
-#include <cctype>
-#include <cstdarg>
-#include <cwchar>
 #include <deque>
-#include <simgrid/sg_config.hpp>
+#include <simgrid/host.h>
+#include <simgrid/s4u/Actor.hpp>
 #include <simgrid/s4u/Host.hpp>
+#include <simgrid/sg_config.hpp>
 #include <string>
 #include <vector>
 
@@ -88,9 +86,9 @@ static const char* instr_find_color(const char* c_state)
   if (smpi_colors.find(state) != smpi_colors.end()) { // Exact match in the map?
     return smpi_colors.find(state)->second.c_str();
   }
-  for (const auto& pair : smpi_colors) { // Is an entry of our map a substring of this state name?
-    if (std::strstr(state.c_str(), pair.first.c_str()) != nullptr)
-      return pair.second.c_str();
+  for (const auto& [smpi_state, color] : smpi_colors) { // Is an entry of our map a substring of this state name?
+    if (state.find(smpi_state) != std::string::npos)
+      return color.c_str();
   }
 
   return "0.5 0.5 0.5"; // Just in case we find nothing in the map ...
@@ -122,8 +120,7 @@ static std::string TRACE_smpi_get_key(aid_t src, aid_t dst, int tag, int send)
   std::string key;
   std::string aux = std::to_string(src) + "#" + std::to_string(dst) + "#" + std::to_string(tag) + "#" +
                     std::to_string(send == 1 ? 0 : 1);
-  auto it = keys.find(aux);
-  if (it == keys.end()) {
+  if (auto it = keys.find(aux); it == keys.end()) {
     // first posted
     key = TRACE_smpi_put_key(src, dst, tag, send);
   } else {
@@ -169,12 +166,12 @@ void TRACE_smpi_init(aid_t pid, const std::string& calling_func)
   const simgrid::instr::Container* container = smpi_container(pid);
   papi_counter_t counters = smpi_process()->papi_counters();
 
-  for (auto const& it : counters) {
+  for (auto const& [counter, _] : counters) {
     /**
      * Check whether this variable already exists or not. Otherwise, it will be created
      * multiple times but only the last one would be used...
      */
-    container->get_type()->by_name_or_create(it.first, "");
+    container->get_type()->by_name_or_create(counter, "");
   }
 #endif
 }
