@@ -10,6 +10,7 @@
 #include "smpi_comm.hpp"
 #include "smpi_info.hpp"
 #include "src/mc/mc_replay.hpp"
+#include "xbt/str.h"
 
 #if HAVE_PAPI
 #include "papi.h"
@@ -17,8 +18,7 @@
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(smpi_process, smpi, "Logging specific to SMPI (kernel)");
 
-namespace simgrid {
-namespace smpi {
+namespace simgrid::smpi {
 simgrid::xbt::Extension<simgrid::s4u::Actor, ActorExt> ActorExt::EXTENSION_ID;
 
 ActorExt::ActorExt(s4u::Actor* actor) : actor_(actor)
@@ -99,6 +99,19 @@ void ActorExt::mark_as_initialized()
     state_ = SmpiProcessState::INITIALIZED;
 }
 
+/** @brief Mark a process as finalizing (=MPI_Finalize called) */
+void ActorExt::mark_as_finalizing()
+{
+  if (state_ != SmpiProcessState::FINALIZED)
+    state_ = SmpiProcessState::FINALIZING;
+}
+
+/** @brief Check if a process is finalizing */
+int ActorExt::finalizing() const
+{
+  return (state_ == SmpiProcessState::FINALIZING);
+}
+
 void ActorExt::set_replaying(bool value)
 {
   if (state_ != SmpiProcessState::FINALIZED)
@@ -222,7 +235,7 @@ void ActorExt::init()
 
   const simgrid::s4u::Actor* self = simgrid::s4u::Actor::self();
   ext->instance_id_ = self->get_property("instance_id");
-  const int rank    = xbt_str_parse_int(self->get_property("rank"), "Cannot parse rank");
+  const int rank = static_cast<int>(xbt_str_parse_int(self->get_property("rank"), "Cannot parse rank"));
 
   ext->state_ = SmpiProcessState::INITIALIZING;
   smpi_deployment_register_process(ext->instance_id_, rank, self);
@@ -259,5 +272,4 @@ int ActorExt::set_bsend_buffer(void* buf, int size)
   return MPI_SUCCESS;
 }
 
-} // namespace smpi
-} // namespace simgrid
+} // namespace simgrid::smpi
