@@ -13,9 +13,7 @@
 
 XBT_LOG_EXTERNAL_DEFAULT_CATEGORY(smpi);
 
-namespace simgrid {
-namespace smpi {
-namespace app {
+namespace simgrid::smpi::app {
 
 static int universe_size = 0;
 
@@ -26,16 +24,14 @@ public:
     auto* group = new simgrid::smpi::Group(size_);
     comm_world_ = new simgrid::smpi::Comm(group, nullptr, false, -1);
     universe_size += max_no_processes;
-    bar_ = std::make_shared<s4u::Barrier>(size_);
+    bar_ = s4u::Barrier::create(size_);
   }
-  std::shared_ptr<s4u::Barrier> bar_;
+  s4u::BarrierPtr bar_;
   unsigned int size_;
   unsigned int finalized_ranks_ = 0;
   MPI_Comm comm_world_;
 };
-}
-}
-}
+} // namespace simgrid::smpi::app
 
 using simgrid::smpi::app::Instance;
 
@@ -56,9 +52,7 @@ void SMPI_app_instance_register(const char *name, xbt_main_func_t code, int num_
   if (code != nullptr) // When started with smpirun, we will not execute a function
     simgrid::s4u::Engine::get_instance()->register_function(name, code);
 
-  Instance instance(num_processes);
-
-  smpi_instances.insert(std::pair<std::string, Instance>(name, instance));
+  smpi_instances.try_emplace(name, num_processes);
 }
 
 void smpi_deployment_register_process(const std::string& instance_id, int rank, const simgrid::s4u::Actor* actor)
@@ -95,9 +89,8 @@ MPI_Comm* smpi_deployment_comm_world(const std::string& instance_id)
 }
 
 void smpi_deployment_cleanup_instances(){
-  for (auto const& item : smpi_instances) {
-    XBT_INFO("Stalling SMPI instance: %s. Do all your MPI ranks call MPI_Finalize()?", item.first.c_str());
-    Instance instance = item.second;
+  for (auto const& [name, instance] : smpi_instances) {
+    XBT_INFO("Stalling SMPI instance: %s. Do all your MPI ranks call MPI_Finalize()?", name.c_str());
     simgrid::smpi::Comm::destroy(instance.comm_world_);
   }
   smpi_instances.clear();
