@@ -104,9 +104,7 @@ CREATE_MPI_DATATYPE(PTR, 58, void*, DT_FLAG_PREDEFINED)
 CREATE_MPI_DATATYPE(COUNT, 59, long long, DT_FLAG_MULTILANG)
 MPI_Datatype MPI_PTR = &smpi_MPI_PTR;
 
-
-namespace simgrid{
-namespace smpi{
+namespace simgrid::smpi {
 
 std::unordered_map<int, smpi_key_elem> Datatype::keyvals_; // required by the Keyval class implementation
 int Datatype::keyval_id_=0; // required by the Keyval class implementation
@@ -128,7 +126,7 @@ Datatype::Datatype(int size, MPI_Aint lb, MPI_Aint ub, int flags) : size_(size),
 Datatype::Datatype(const char* name, int ident, int size, MPI_Aint lb, MPI_Aint ub, int flags)
     : name_(name), id(std::to_string(ident)), size_(size), lb_(lb), ub_(ub), flags_(flags), refcount_(0)
 {
-  id2type_lookup.insert({id, this});
+  id2type_lookup.try_emplace(id, this);
 #if SIMGRID_HAVE_MC
   if(MC_is_active())
     MC_ignore(&refcount_, sizeof refcount_);
@@ -166,19 +164,19 @@ int Datatype::copy_attrs(Datatype* datatype){
   flags_ &= ~DT_FLAG_PREDEFINED;
 
   set_contents(MPI_COMBINER_DUP, 0, nullptr, 0, nullptr, 1, &datatype);
-  for (auto const& it : datatype->attributes()) {
-    auto elem_it = keyvals_.find(it.first);
-    xbt_assert(elem_it != keyvals_.end(), "Keyval not found for Datatype: %d", it.first);
+  for (auto const& [key, value] : datatype->attributes()) {
+    auto elem_it = keyvals_.find(key);
+    xbt_assert(elem_it != keyvals_.end(), "Keyval not found for Datatype: %d", key);
 
     smpi_key_elem& elem = elem_it->second;
     int ret             = MPI_SUCCESS;
     int flag            = 0;
     void* value_out     = nullptr;
     if (elem.copy_fn.type_copy_fn == MPI_TYPE_DUP_FN) {
-      value_out = it.second;
+      value_out = value;
       flag      = 1;
     } else if (elem.copy_fn.type_copy_fn != MPI_NULL_COPY_FN) {
-      ret = elem.copy_fn.type_copy_fn(datatype, it.first, elem.extra_state, it.second, &value_out, &flag);
+      ret = elem.copy_fn.type_copy_fn(datatype, key, elem.extra_state, value, &value_out, &flag);
     }
     if (ret != MPI_SUCCESS)
       return ret;
@@ -186,10 +184,10 @@ int Datatype::copy_attrs(Datatype* datatype){
     if (elem.copy_fn.type_copy_fn_fort != MPI_NULL_COPY_FN) {
       value_out = xbt_new(int, 1);
       if (*(int*)*elem.copy_fn.type_copy_fn_fort == 1) { // MPI_TYPE_DUP_FN
-        memcpy(value_out, it.second, sizeof(int));
+        memcpy(value_out, value, sizeof(int));
         flag = 1;
       } else { // not null, nor dup
-        elem.copy_fn.type_copy_fn_fort(datatype, it.first, elem.extra_state, it.second, value_out, &flag, &ret);
+        elem.copy_fn.type_copy_fn_fort(datatype, key, elem.extra_state, value, value_out, &flag, &ret);
       }
       if (ret != MPI_SUCCESS) {
         xbt_free(value_out);
@@ -198,7 +196,7 @@ int Datatype::copy_attrs(Datatype* datatype){
     }
     if (flag) {
       elem.refcount++;
-      attributes().emplace(it.first, value_out);
+      attributes().try_emplace(key, value_out);
     }
   }
   return MPI_SUCCESS;
@@ -654,5 +652,4 @@ Datatype* Datatype::f2c(int id)
   return static_cast<Datatype*>(F2C::f2c(id));
 }
 
-} // namespace smpi
-} // namespace simgrid
+} // namespace simgrid::smpi
