@@ -13,8 +13,7 @@ int mpi_bottom_;
 int mpi_status_ignore_;
 int mpi_statuses_ignore_;
 
-namespace simgrid{
-namespace smpi{
+namespace simgrid::smpi {
 
 std::unique_ptr<F2C::f2c_lookup_type> F2C::f2c_lookup_    = nullptr;
 int F2C::f2c_id_ = 0;
@@ -26,8 +25,7 @@ F2C::F2C() = default;
 int F2C::add_f()
 {
   allocate_lookup();
-  auto loc = smpi_process()->call_location();
-  if(loc && loc->linenumber != 0)
+  if (auto loc = smpi_process()->call_location(); loc && loc->linenumber != 0)
     call_location_= std::string (loc->filename + ":" + std::to_string(loc->linenumber));
   my_f2c_id_                 = global_f2c_id();
   (*f2c_lookup_)[my_f2c_id_] = this;
@@ -57,5 +55,4 @@ F2C* F2C::f2c(int id)
     return nullptr;
 }
 
-}
-}
+} // namespace simgrid::smpi
