@@ -238,9 +238,8 @@ static void no_func(void*, void*, int*, MPI_Datatype*)
   /* obviously a no-op */
 }
 
-
-#define CREATE_MPI_OP(name, func, types)                                                                                      \
-  SMPI_Op _XBT_CONCAT(smpi_MPI_, name)(&(func) /* func */, true, true, types);
+#define CREATE_MPI_OP(name, func, types)                                                                               \
+  SMPI_Op _XBT_CONCAT(smpi_MPI_, name)(&(func), true, true, types, _XBT_STRINGIFY(MPI_##name));
 
 #define MAX_TYPES DT_FLAG_C_INTEGER|DT_FLAG_F_INTEGER|DT_FLAG_FP|DT_FLAG_MULTILANG
 #define LAND_TYPES DT_FLAG_C_INTEGER|DT_FLAG_FP|DT_FLAG_LOGICAL|DT_FLAG_MULTILANG
@@ -261,8 +260,7 @@ CREATE_MPI_OP(MINLOC, minloc_func, DT_FLAG_REDUCTION)
 CREATE_MPI_OP(REPLACE, replace_func, 0)
 CREATE_MPI_OP(NO_OP, no_func, 0)
 
-namespace simgrid{
-namespace smpi{
+namespace simgrid::smpi {
 
 void Op::apply(const void* invec, void* inoutvec, const int* len, MPI_Datatype datatype) const
 {
@@ -300,5 +298,4 @@ void Op::unref(MPI_Op* op){
   }
 }
 
-}
-}
+} // namespace simgrid::smpi
