@@ -8,14 +8,17 @@
 #include "mc/mc.h"
 #include "private.hpp"
 #include "simgrid/Exception.hpp"
+#include "simgrid/s4u/ConditionVariable.hpp"
 #include "simgrid/s4u/Exec.hpp"
 #include "simgrid/s4u/Mutex.hpp"
-#include "simgrid/s4u/ConditionVariable.hpp"
 #include "smpi_comm.hpp"
 #include "smpi_datatype.hpp"
 #include "smpi_host.hpp"
 #include "smpi_op.hpp"
+#include "src/kernel/EngineImpl.hpp"
 #include "src/kernel/activity/CommImpl.hpp"
+#include "src/kernel/actor/ActorImpl.hpp"
+#include "src/kernel/actor/SimcallObserver.hpp"
 #include "src/mc/mc_replay.hpp"
 #include "src/smpi/include/smpi_actor.hpp"
 
@@ -31,10 +34,9 @@ static simgrid::config::Flag<double> smpi_test_sleep(
 
 std::vector<s_smpi_factor_t> smpi_ois_values;
 
-extern void (*smpi_comm_copy_data_callback)(simgrid::kernel::activity::CommImpl*, void*, size_t);
+extern std::function<void(simgrid::kernel::activity::CommImpl*, void*, size_t)> smpi_comm_copy_data_callback;
 
-namespace simgrid{
-namespace smpi{
+namespace simgrid::smpi {
 
 Request::Request(const void* buf, int count, MPI_Datatype datatype, aid_t src, aid_t dst, int tag, MPI_Comm comm,
                  unsigned flags, MPI_Op op)
@@ -58,8 +60,7 @@ Request::Request(const void* buf, int count, MPI_Datatype datatype, aid_t src, a
   detached_sender_ = nullptr;
   real_src_        = 0;
   // get src_host if it's available (src is valid)
-  auto src_process = simgrid::s4u::Actor::by_pid(src);
-  if (src_process)
+  if (auto src_process = simgrid::s4u::Actor::by_pid(src))
     src_host_ = src_process->get_host();
   truncated_       = false;
   unmatched_types_ = false;
@@ -69,6 +70,7 @@ Request::Request(const void* buf, int count, MPI_Datatype datatype, aid_t src, a
     refcount_ = 1;
   else
     refcount_ = 0;
+  message_id_ = 0;
   init_buffer(count);
   this->add_f();
 }
@@ -142,13 +144,10 @@ bool Request::match_common(MPI_Request req, MPI_Request sender, MPI_Request rece
     }
     if (receiver->tag_ == MPI_ANY_TAG)
       receiver->real_tag_ = sender->tag_;
-    if ((receiver->flags_ & MPI_REQ_PROBE) == 0 ){
-      if (receiver->real_size_ < sender->real_size_){
-        XBT_DEBUG("Truncating message - should not happen: receiver size : %zu < sender size : %zu", receiver->real_size_, sender->real_size_);
-        receiver->truncated_ = true;
-      } else if (receiver->real_size_ > sender->real_size_){
-        receiver->real_size_=sender->real_size_;
-      }
+    if ((receiver->flags_ & MPI_REQ_PROBE) == 0 && receiver->real_size_ < sender->real_size_) {
+      XBT_DEBUG("Truncating message - should not happen: receiver size : %zu < sender size : %zu", receiver->real_size_,
+                sender->real_size_);
+      receiver->truncated_ = true;
     }
     //0-sized datatypes/counts should not interfere and match
     if ( sender->real_size_ != 0 && receiver->real_size_ != 0 &&
@@ -186,7 +185,35 @@ bool Request::match_recv(void* a, void* b, simgrid::kernel::activity::CommImpl*)
 {
   auto ref = static_cast<MPI_Request>(a);
   auto req = static_cast<MPI_Request>(b);
-  return match_common(req, req, ref);
+  bool match = match_common(req, req, ref);
+  if (not match || ref->comm_ == MPI_COMM_UNINITIALIZED || ref->comm_->is_smp_comm())
+    return match;
+
+  if (ref->comm_->get_received_messages_count(ref->comm_->group()->rank(req->src_),
+                                              ref->comm_->group()->rank(req->dst_), req->tag_) == req->message_id_) {
+    if (((ref->flags_ & MPI_REQ_PROBE) == 0) && ((req->flags_ & MPI_REQ_PROBE) == 0)) {
+      XBT_DEBUG("increasing count in comm %p, which was %u from pid %ld, to pid %ld with tag %d", ref->comm_,
+                ref->comm_->get_received_messages_count(ref->comm_->group()->rank(req->src_),
+                                                        ref->comm_->group()->rank(req->dst_), req->tag_),
+                req->src_, req->dst_, req->tag_);
+      ref->comm_->increment_received_messages_count(ref->comm_->group()->rank(req->src_),
+                                                    ref->comm_->group()->rank(req->dst_), req->tag_);
+      if (ref->real_size_ > req->real_size_) {
+        ref->real_size_ = req->real_size_;
+      }
+    }
+  } else {
+    match = false;
+    req->flags_ &= ~MPI_REQ_MATCHED;
+    ref->detached_sender_ = nullptr;
+    XBT_DEBUG("Refusing to match message, as its ID is not the one I expect. in comm %p, %u != %u, "
+              "from pid %ld to pid %ld, with tag %d",
+              ref->comm_,
+              ref->comm_->get_received_messages_count(ref->comm_->group()->rank(req->src_),
+                                                      ref->comm_->group()->rank(req->dst_), req->tag_),
+              req->message_id_, req->src_, req->dst_, req->tag_);
+  }
+  return match;
 }
 
 bool Request::match_send(void* a, void* b, simgrid::kernel::activity::CommImpl*)
@@ -396,8 +423,7 @@ void Request::sendrecv(const void *sendbuf, int sendcount, MPI_Datatype sendtype
 
   std::array<MPI_Request, 2> requests;
   std::array<MPI_Status, 2> stats;
-  aid_t myid = simgrid::s4u::this_actor::get_pid();
-  if ((destination == myid) && (source == myid)) {
+  if (aid_t myid = simgrid::s4u::this_actor::get_pid(); (destination == myid) && (source == myid)) {
     Datatype::copy(sendbuf, sendcount, sendtype, recvbuf, recvcount, recvtype);
     if (status != MPI_STATUS_IGNORE) {
       status->MPI_SOURCE = source;
@@ -444,6 +470,9 @@ void Request::start()
     if (smpi_cfg_async_small_thresh() != 0 || (flags_ & MPI_REQ_RMA) != 0)
       mut->lock();
 
+    bool is_probe = ((flags_ & MPI_REQ_PROBE) != 0);
+    flags_ |= MPI_REQ_PROBE;
+
     if (smpi_cfg_async_small_thresh() == 0 && (flags_ & MPI_REQ_RMA) == 0) {
       mailbox = process->mailbox();
     } else if (((flags_ & MPI_REQ_RMA) != 0) || static_cast<int>(size_) < smpi_cfg_async_small_thresh()) {
@@ -463,7 +492,7 @@ void Request::start()
           mailbox = process->mailbox_small();
         }
       } else {
-        XBT_DEBUG("yes there was something for us in the large mailbox");
+        XBT_DEBUG("yes there was something for us in the small mailbox");
       }
     } else {
       mailbox = process->mailbox_small();
@@ -477,10 +506,22 @@ void Request::start()
         XBT_DEBUG("yes there was something for us in the small mailbox");
       }
     }
+    if(!is_probe)
+      flags_ &= ~MPI_REQ_PROBE;
+    kernel::actor::CommIrecvSimcall observer{process->get_actor()->get_impl(),
+                                             mailbox->get_impl(),
+                                             static_cast<unsigned char*>(buf_),
+                                             &real_size_,
+                                             &match_recv,
+                                             process->replaying() ? &smpi_comm_null_copy_buffer_callback
+                                                                  : smpi_comm_copy_data_callback,
+                                             this,
+                                             -1.0};
+    observer.set_tag(tag_);
+
+    action_ = kernel::actor::simcall_answered([&observer] { return kernel::activity::CommImpl::irecv(&observer); },
+                                              &observer);
 
-    action_   = simcall_comm_irecv(
-        process->get_actor()->get_impl(), mailbox->get_impl(), buf_, &real_size_, &match_recv,
-        process->replaying() ? &smpi_comm_null_copy_buffer_callback : smpi_comm_copy_data_callback, this, -1.0);
     XBT_DEBUG("recv simcall posted");
 
     if (smpi_cfg_async_small_thresh() != 0 || (flags_ & MPI_REQ_RMA) != 0)
@@ -492,6 +533,9 @@ void Request::start()
       TRACE_smpi_send(src_, src_, dst_, tag_, size_);
     this->print_request("New send");
 
+    message_id_=comm_->get_sent_messages_count(comm_->group()->rank(src_), comm_->group()->rank(dst_), tag_);
+    comm_->increment_sent_messages_count(comm_->group()->rank(src_), comm_->group()->rank(dst_), tag_);
+
     void* buf = buf_;
     if ((flags_ & MPI_REQ_SSEND) == 0 &&
         ((flags_ & MPI_REQ_RMA) != 0 || (flags_ & MPI_REQ_BSEND) != 0 ||
@@ -541,10 +585,12 @@ void Request::start()
     if (not(smpi_cfg_async_small_thresh() != 0 || (flags_ & MPI_REQ_RMA) != 0)) {
       mailbox = process->mailbox();
     } else if (((flags_ & MPI_REQ_RMA) != 0) || static_cast<int>(size_) < smpi_cfg_async_small_thresh()) { // eager mode
+      bool is_probe = ((flags_ & MPI_REQ_PROBE) != 0);
+      flags_ |= MPI_REQ_PROBE;
+
       mailbox = process->mailbox();
       XBT_DEBUG("Is there a corresponding recv already posted in the large mailbox %s?", mailbox->get_cname());
-      simgrid::kernel::activity::ActivityImplPtr action = mailbox->iprobe(1, &match_send, static_cast<void*>(this));
-      if (action == nullptr) {
+      if (not mailbox->iprobe(1, &match_send, static_cast<void*>(this))) {
         if ((flags_ & MPI_REQ_SSEND) == 0) {
           mailbox = process->mailbox_small();
           XBT_DEBUG("No, nothing in the large mailbox, message is to be sent on the small one %s",
@@ -553,8 +599,7 @@ void Request::start()
           mailbox = process->mailbox_small();
           XBT_DEBUG("SSEND : Is there a corresponding recv already posted in the small mailbox %s?",
                     mailbox->get_cname());
-          action = mailbox->iprobe(1, &match_send, static_cast<void*>(this));
-          if (action == nullptr) {
+          if (not mailbox->iprobe(1, &match_send, static_cast<void*>(this))) {
             XBT_DEBUG("No, we are first, send to large mailbox");
             mailbox = process->mailbox();
           }
@@ -562,19 +607,24 @@ void Request::start()
       } else {
         XBT_DEBUG("Yes there was something for us in the large mailbox");
       }
+      if(!is_probe)
+        flags_ &= ~MPI_REQ_PROBE;
     } else {
       mailbox = process->mailbox();
       XBT_DEBUG("Send request %p is in the large mailbox %s (buf: %p)", this, mailbox->get_cname(), buf_);
     }
 
     size_t payload_size_ = size_ + 16;//MPI enveloppe size (tag+dest+communicator)
-    action_              = simcall_comm_isend(
-        simgrid::kernel::actor::ActorImpl::by_pid(src_), mailbox->get_impl(), payload_size_, -1.0, buf, real_size_,
-        &match_send,
+    kernel::actor::CommIsendSimcall observer{
+        simgrid::kernel::EngineImpl::get_instance()->get_actor_by_pid(src_), mailbox->get_impl(),
+        static_cast<double>(payload_size_), -1, static_cast<unsigned char*>(buf), real_size_, &match_send,
         &xbt_free_f, // how to free the userdata if a detached send fails
         process->replaying() ? &smpi_comm_null_copy_buffer_callback : smpi_comm_copy_data_callback, this,
         // detach if msg size < eager/rdv switch limit
-        detached_);
+        detached_};
+    observer.set_tag(tag_);
+    action_ = kernel::actor::simcall_answered([&observer] { return kernel::activity::CommImpl::isend(&observer); },
+                                              &observer);
     XBT_DEBUG("send simcall posted");
 
     /* FIXME: detached sends are not traceable (action_ == nullptr) */
@@ -630,7 +680,10 @@ int Request::test(MPI_Request * request, MPI_Status * status, int* flag) {
   if (((*request)->flags_ & (MPI_REQ_PREPARED | MPI_REQ_FINISHED)) == 0) {
     if ((*request)->action_ != nullptr && ((*request)->flags_ & MPI_REQ_CANCELLED) == 0){
       try{
-        *flag = simcall_comm_test((*request)->action_.get());
+        kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
+        kernel::actor::ActivityTestSimcall observer{issuer, (*request)->action_.get()};
+        *flag = kernel::actor::simcall_answered(
+            [&observer] { return observer.get_activity()->test(observer.get_issuer()); }, &observer);
       } catch (const Exception&) {
         *flag = 0;
         return ret;
@@ -672,8 +725,7 @@ int Request::testsome(int incount, MPI_Request requests[], int *count, int *indi
   *count = 0;
   for (int i = 0; i < incount; i++) {
     if (requests[i] != MPI_REQUEST_NULL && not (requests[i]->flags_ & MPI_REQ_FINISHED)) {
-      int ret = test(&requests[i], pstat, &flag);
-      if(ret!=MPI_SUCCESS)
+      if (test(&requests[i], pstat, &flag) != MPI_SUCCESS)
         error = 1;
       if(flag) {
         indices[*count] = i;
@@ -696,7 +748,7 @@ int Request::testsome(int incount, MPI_Request requests[], int *count, int *indi
 
 int Request::testany(int count, MPI_Request requests[], int *index, int* flag, MPI_Status * status)
 {
-  std::vector<simgrid::kernel::activity::CommImpl*> comms;
+  std::vector<simgrid::kernel::activity::ActivityImpl*> comms;
   comms.reserve(count);
 
   *flag = 0;
@@ -706,7 +758,7 @@ int Request::testany(int count, MPI_Request requests[], int *index, int* flag, M
   std::vector<int> map; /** Maps all matching comms back to their location in requests **/
   for (int i = 0; i < count; i++) {
     if ((requests[i] != MPI_REQUEST_NULL) && requests[i]->action_ && not(requests[i]->flags_ & MPI_REQ_PREPARED)) {
-      comms.push_back(static_cast<simgrid::kernel::activity::CommImpl*>(requests[i]->action_.get()));
+      comms.push_back(requests[i]->action_.get());
       map.push_back(i);
     }
   }
@@ -717,7 +769,13 @@ int Request::testany(int count, MPI_Request requests[], int *index, int* flag, M
       simgrid::s4u::this_actor::sleep_for(nsleeps * smpi_test_sleep);
     ssize_t i;
     try{
-      i = simcall_comm_testany(comms.data(), comms.size()); // The i-th element in comms matches!
+      kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
+      kernel::actor::ActivityTestanySimcall observer{issuer, comms};
+      i = kernel::actor::simcall_answered(
+          [&observer] {
+            return kernel::activity::ActivityImpl::test_any(observer.get_issuer(), observer.get_activities());
+          },
+          &observer);
     } catch (const Exception&) {
       XBT_DEBUG("Exception in testany");
       return 0;
@@ -966,9 +1024,9 @@ void Request::finish_wait(MPI_Request* request, MPI_Status * status)
   if(req->detached_sender_ != nullptr){
     //integrate pseudo-timing for buffering of small messages, do not bother to execute the simcall if 0
     simgrid::s4u::Host* dst_host = simgrid::s4u::Actor::by_pid(req->dst_)->get_host();
-    double sleeptime             = simgrid::s4u::Actor::self()->get_host()->extension<simgrid::smpi::Host>()->orecv(
-        req->real_size(), req->src_host_, dst_host);
-    if (sleeptime > 0.0) {
+    if (double sleeptime = simgrid::s4u::Actor::self()->get_host()->extension<simgrid::smpi::Host>()->orecv(
+            req->real_size(), req->src_host_, dst_host);
+        sleeptime > 0.0) {
       simgrid::s4u::this_actor::sleep_for(sleeptime);
       XBT_DEBUG("receiving size of %zu : sleep %f ", req->real_size_, sleeptime);
     }
@@ -1027,7 +1085,10 @@ int Request::wait(MPI_Request * request, MPI_Status * status)
   if ((*request)->action_ != nullptr){
       try{
         // this is not a detached send
-        simcall_comm_wait((*request)->action_.get(), -1.0);
+        kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
+        kernel::actor::ActivityWaitSimcall observer{issuer, (*request)->action_.get(), -1};
+        kernel::actor::simcall_blocking([issuer, &observer] { observer.get_activity()->wait_for(issuer, -1); },
+                                        &observer);
       } catch (const CancelException&) {
         XBT_VERB("Request cancelled");
       }
@@ -1068,7 +1129,7 @@ int Request::waitany(int count, MPI_Request requests[], MPI_Status * status)
 
   if(count > 0) {
     // Wait for a request to complete
-    std::vector<simgrid::kernel::activity::CommImpl*> comms;
+    std::vector<simgrid::kernel::activity::ActivityImpl*> comms;
     std::vector<int> map;
     XBT_DEBUG("Wait for one of %d", count);
     for(int i = 0; i < count; i++) {
@@ -1076,7 +1137,7 @@ int Request::waitany(int count, MPI_Request requests[], MPI_Status * status)
           not(requests[i]->flags_ & MPI_REQ_FINISHED)) {
         if (requests[i]->action_ != nullptr) {
           XBT_DEBUG("Waiting any %p ", requests[i]);
-          comms.push_back(static_cast<simgrid::kernel::activity::CommImpl*>(requests[i]->action_.get()));
+          comms.push_back(requests[i]->action_.get());
           map.push_back(i);
         } else {
           // This is a finished detached request, let's return this one
@@ -1095,7 +1156,14 @@ int Request::waitany(int count, MPI_Request requests[], MPI_Status * status)
       XBT_DEBUG("Enter waitany for %zu comms", comms.size());
       ssize_t i;
       try{
-        i = simcall_comm_waitany(comms.data(), comms.size(), -1);
+        kernel::actor::ActorImpl* issuer = kernel::actor::ActorImpl::self();
+        kernel::actor::ActivityWaitanySimcall observer{issuer, comms, -1};
+        i = kernel::actor::simcall_blocking(
+            [&observer] {
+              kernel::activity::ActivityImpl::wait_any_for(observer.get_issuer(), observer.get_activities(),
+                                                           observer.get_timeout());
+            },
+            &observer);
       } catch (const CancelException&) {
         XBT_INFO("request cancelled");
         i = -1;
@@ -1223,8 +1291,6 @@ void Request::free_f(int id)
 
 int Request::get_status(const Request* req, int* flag, MPI_Status* status)
 {
-  *flag=0;
-
   if(req != MPI_REQUEST_NULL && req->action_ != nullptr) {
     req->iprobe(req->comm_->group()->rank(req->src_), req->tag_, req->comm_, flag, status);
     if(*flag)
@@ -1286,5 +1352,4 @@ std::vector<MPI_Request> Request::get_nbc_requests() const
 {
   return nbc_requests_;
 }
-}
-}
+} // namespace simgrid::smpi
