@@ -3,6 +3,7 @@
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
+#include <simgrid/modelchecker.h>
 #include "smpi_win.hpp"
 
 #include "private.hpp"
@@ -13,6 +14,7 @@
 #include "smpi_keyvals.hpp"
 #include "smpi_request.hpp"
 #include "src/smpi/include/smpi_actor.hpp"
+#include "src/mc/mc_replay.hpp"
 
 #include <algorithm>
 
@@ -33,8 +35,7 @@ XBT_LOG_NEW_DEFAULT_SUBCATEGORY(smpi_rma, smpi, "Logging specific to SMPI (RMA o
       return MPI_ERR_WIN;                                                                                              \
   }
 
-namespace simgrid{
-namespace smpi{
+namespace simgrid::smpi {
 std::unordered_map<int, smpi_key_elem> Win::keyvals_;
 int Win::keyval_id_=0;
 
@@ -53,46 +54,54 @@ Win::Win(void* base, MPI_Aint size, int disp_unit, MPI_Info info, MPI_Comm comm,
   if(info!=MPI_INFO_NULL)
     info->ref();
   connected_wins_[rank_] = this;
-  if(rank_==0){
-    bar_ = new s4u::Barrier(comm->size());
-  }
   errhandler_->ref();
   comm->add_rma_win(this);
   comm->ref();
 
   colls::allgather(&connected_wins_[rank_], sizeof(MPI_Win), MPI_BYTE, connected_wins_.data(), sizeof(MPI_Win),
                    MPI_BYTE, comm);
-
-  colls::bcast(&bar_, sizeof(s4u::Barrier*), MPI_BYTE, 0, comm);
-
-  colls::barrier(comm);
+  if  (MC_is_active() || MC_record_replay_is_active()){
+    s4u::Barrier* bar_ptr;
+    if (rank_ == 0) {
+      bar_ = s4u::Barrier::create(comm->size());
+      bar_ptr = bar_.get();
+    }
+    colls::bcast(&bar_ptr, sizeof(s4u::Barrier*), MPI_BYTE, 0, comm);
+    if (rank_ != 0)
+      bar_ = s4u::BarrierPtr(bar_ptr);
+  }
   this->add_f();
 }
 
-Win::~Win(){
+int Win::del(Win* win){
   //As per the standard, perform a barrier to ensure every async comm is finished
-  bar_->wait();
+  if  (MC_is_active() || MC_record_replay_is_active())
+    win->bar_->wait();
+  else
+    colls::barrier(win->comm_);
+  win->flush_local_all();
 
-  flush_local_all();
+  if (win->info_ != MPI_INFO_NULL)
+    simgrid::smpi::Info::unref(win->info_);
+  if (win->errhandler_ != MPI_ERRHANDLER_NULL)
+    simgrid::smpi::Errhandler::unref(win->errhandler_);
 
-  if (info_ != MPI_INFO_NULL)
-    simgrid::smpi::Info::unref(info_);
-  if (errhandler_ != MPI_ERRHANDLER_NULL)
-    simgrid::smpi::Errhandler::unref(errhandler_);
+  win->comm_->remove_rma_win(win);
 
-  comm_->remove_rma_win(this);
+  colls::barrier(win->comm_);
+  Comm::unref(win->comm_);
+  if (!win->lockers_.empty() || win->opened_ < 0){
+    XBT_WARN("Freeing a locked or opened window");
+    return MPI_ERR_WIN;
+  }
+  if (win->allocated_)
+    xbt_free(win->base_);
 
-  colls::barrier(comm_);
-  Comm::unref(comm_);
+  F2C::free_f(win->f2c_id());
+  win->cleanup_attr<Win>();
 
-  if (rank_ == 0)
-    delete bar_;
-
-  if (allocated_)
-    xbt_free(base_);
-
-  F2C::free_f(this->f2c_id());
-  cleanup_attr<Win>();
+  delete win;
+  return MPI_SUCCESS;
 }
 
 int Win::attach(void* /*base*/, MPI_Aint size)
@@ -182,7 +191,10 @@ int Win::fence(int assert)
   opened_++;
   if (not (assert & MPI_MODE_NOPRECEDE)) {
     // This is not the first fence => finalize what came before
-    bar_->wait();
+    if (MC_is_active() || MC_record_replay_is_active())
+      bar_->wait();
+    else
+      colls::barrier(comm_);
     flush_local_all();
     count_=0;
   }
@@ -190,8 +202,10 @@ int Win::fence(int assert)
   if (assert & MPI_MODE_NOSUCCEED) // there should be no ops after this one, tell we are closed.
     opened_=0;
   assert_ = assert;
-
-  bar_->wait();
+  if (MC_is_active() || MC_record_replay_is_active())
+    bar_->wait();
+  else
+    colls::barrier(comm_);
   XBT_DEBUG("Leaving fence");
 
   return MPI_SUCCESS;
@@ -422,7 +436,7 @@ int Win::start(MPI_Group group, int /*assert*/)
 
   group->ref();
   dst_group_ = group;
-  opened_++; // we're open for business !
+  opened_--; // we're open for business !
   XBT_DEBUG("Leaving MPI_Win_Start");
   return MPI_SUCCESS;
 }
@@ -447,7 +461,7 @@ int Win::post(MPI_Group group, int /*assert*/)
 
   group->ref();
   src_group_ = group;
-  opened_++; // we're open for business !
+  opened_--; // we're open for business !
   XBT_DEBUG("Leaving MPI_Win_Post");
   return MPI_SUCCESS;
 }
@@ -473,7 +487,7 @@ int Win::complete(){
 
   flush_local_all();
 
-  opened_--; //we're closed for business !
+  opened_++; //we're closed for business !
   Group::unref(dst_group_);
   dst_group_ = MPI_GROUP_NULL;
   return MPI_SUCCESS;
@@ -499,7 +513,7 @@ int Win::wait(){
 
   flush_local_all();
 
-  opened_--; //we're closed for business !
+  opened_++; //we're closed for business !
   Group::unref(src_group_);
   src_group_ = MPI_GROUP_NULL;
   return MPI_SUCCESS;
@@ -669,5 +683,4 @@ void Win::set_errhandler(MPI_Errhandler errhandler)
   if (errhandler_ != MPI_ERRHANDLER_NULL)
     errhandler_->ref();
 }
-} // namespace smpi
-} // namespace simgrid
+} // namespace simgrid::smpi
