@@ -6,6 +6,7 @@
 #include "cpu_ti.hpp"
 #include "simgrid/kernel/routing/NetZoneImpl.hpp"
 #include "simgrid/s4u/Engine.hpp"
+#include "xbt/asserts.h"
 #include "src/kernel/EngineImpl.hpp"
 #include "src/kernel/resource/profile/Event.hpp"
 #include "src/kernel/resource/profile/Profile.hpp"
@@ -18,9 +19,7 @@ constexpr double EPSILON = 0.000000001;
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(cpu_ti, res_cpu, "CPU resource, Trace Integration model");
 
-namespace simgrid {
-namespace kernel {
-namespace resource {
+namespace simgrid::kernel::resource {
 
 /*********
  * Trace *
@@ -30,15 +29,26 @@ CpuTiProfile::CpuTiProfile(const profile::Profile* profile)
 {
   double integral    = 0;
   double time        = 0;
-  unsigned long nb_points = profile->get_event_list().size() + 1;
+  double prev_value  = 1;
+  const std::vector<profile::DatedValue>& events=profile->get_event_list();
+  xbt_assert(not events.empty());
+  unsigned long nb_points = events.size() + 1;
   time_points_.reserve(nb_points);
   integral_.reserve(nb_points);
-  for (auto const& val : profile->get_event_list()) {
+  for (auto const& val :  events) {
+    time += val.date_;
+    integral += val.date_ * prev_value;
     time_points_.push_back(time);
     integral_.push_back(integral);
-    time += val.date_;
-    integral += val.date_ * val.value_;
+    prev_value = val.value_;
   }
+
+  double delay=profile->get_repeat_delay()+ events.at(0).date_;
+
+  xbt_assert( events.back().value_==prev_value,"Profiles need to end as they start");
+  time += delay;
+  integral += delay*prev_value;
+
   time_points_.push_back(time);
   integral_.push_back(integral);
 }
@@ -162,15 +172,12 @@ double CpuTiTmgr::solve(double a, double amount) const
   XBT_DEBUG("Quotient: %g reduced_amount: %f reduced_a: %f", quotient, reduced_amount, reduced_a);
 
   /* Now solve for new_amount which is <= trace_total */
-  double reduced_b;
   XBT_DEBUG("Solve integral: [%.2f, amount=%.2f]", reduced_a, reduced_amount);
-  double amount_till_end = integrate(reduced_a, last_time_);
 
-  if (amount_till_end > reduced_amount) {
-    reduced_b = profile_->solve_simple(reduced_a, reduced_amount);
-  } else {
-    reduced_b = last_time_ + profile_->solve_simple(0.0, reduced_amount - amount_till_end);
-  }
+  double amount_till_end = integrate(reduced_a, last_time_);
+  double reduced_b       = amount_till_end > reduced_amount
+                               ? profile_->solve_simple(reduced_a, reduced_amount)
+                               : last_time_ + profile_->solve_simple(0.0, reduced_amount - amount_till_end);
 
   /* Re-map to the original b and amount */
   return last_time_ * floor(a / last_time_) + (quotient * last_time_) + reduced_b;
@@ -228,6 +235,8 @@ CpuTiTmgr::CpuTiTmgr(kernel::profile::Profile* speed_profile, double value) : sp
     return;
   }
 
+  xbt_assert(speed_profile->is_repeating());
+
   /* only one point available, fixed trace */
   if (speed_profile->get_event_list().size() == 1) {
     value_ = speed_profile->get_event_list().front().value_;
@@ -239,6 +248,7 @@ CpuTiTmgr::CpuTiTmgr(kernel::profile::Profile* speed_profile, double value) : sp
   /* count the total time of trace file */
   for (auto const& val : speed_profile->get_event_list())
     total_time += val.date_;
+  total_time += speed_profile->get_repeat_delay();
 
   profile_   = std::make_unique<CpuTiProfile>(speed_profile);
   last_time_ = total_time;
@@ -336,7 +346,7 @@ CpuImpl* CpuTi::set_speed_profile(kernel::profile::Profile* profile)
   if (profile && profile->get_event_list().size() > 1) {
     kernel::profile::DatedValue val = profile->get_event_list().back();
     if (val.date_ < 1e-12) {
-      auto* prof   = new kernel::profile::Profile();
+      auto* prof   = profile::ProfileBuilder::from_void();
       speed_.event = prof->schedule(&profile::future_evt_set, this);
     }
   }
@@ -607,6 +617,4 @@ double CpuTiAction::get_remains()
   return get_remains_no_update();
 }
 
-} // namespace resource
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::resource
