@@ -45,15 +45,13 @@ void surf_network_model_init_IB()
   simgrid::config::set_default<double>("network/weight-S", 8775);
 }
 
-namespace simgrid {
-namespace kernel {
-namespace resource {
+namespace simgrid::kernel::resource {
 
 void NetworkIBModel::IB_create_host_callback(s4u::Host const& host)
 {
   static int id = 0;
   auto* ibModel = static_cast<NetworkIBModel*>(host.get_netpoint()->get_englobing_zone()->get_network_model().get());
-  ibModel->active_nodes.emplace(host.get_name(), IBNode(id));
+  ibModel->active_nodes.try_emplace(host.get_name(), id);
   id++;
 }
 
@@ -61,11 +59,11 @@ void NetworkIBModel::IB_action_state_changed_callback(NetworkAction& action, Act
 {
   if (action.get_state() != Action::State::FINISHED)
     return;
-  auto* ibModel                    = static_cast<NetworkIBModel*>(action.get_model());
-  std::pair<IBNode*, IBNode*> pair = ibModel->active_comms[&action];
+  auto* ibModel   = static_cast<NetworkIBModel*>(action.get_model());
+  auto [src, dst] = ibModel->active_comms[&action];
 
   XBT_DEBUG("IB callback - action %p finished", &action);
-  ibModel->update_IB_factors(&action, pair.first, pair.second, 1);
+  ibModel->update_IB_factors(&action, src, dst, 1);
   ibModel->active_comms.erase(&action);
 }
 
@@ -129,8 +127,7 @@ void NetworkIBModel::compute_IB_factors(IBNode* root) const
   for (ActiveComm* comm : root->active_comms_up_) {
     // compute inbound penalty
     double my_penalty_in = 1.0;
-    int nb_comms         = comm->destination->nb_active_comms_down_; // total number of incoming comms
-    if (nb_comms != 1)
+    if (comm->destination->nb_active_comms_down_ != 1)                      // total number of incoming comms
       my_penalty_in = (comm->destination->active_comms_down_)[root]         // number of comm sent to dest by root node
                       * Be_ * comm->destination->active_comms_down_.size(); // number of different nodes sending to dest
 
@@ -165,9 +162,9 @@ void NetworkIBModel::update_IB_factors_rec(IBNode* root, std::vector<bool>& upda
       if (not updatedlist[comm->destination->id_])
         update_IB_factors_rec(comm->destination, updatedlist);
     }
-    for (std::map<IBNode*, int>::value_type const& comm : root->active_comms_down_) {
-      if (not updatedlist[comm.first->id_])
-        update_IB_factors_rec(comm.first, updatedlist);
+    for (auto const& [comm, _] : root->active_comms_down_) {
+      if (not updatedlist[comm->id_])
+        update_IB_factors_rec(comm, updatedlist);
     }
   }
 }
@@ -184,9 +181,9 @@ void NetworkIBModel::update_IB_factors(NetworkAction* action, IBNode* from, IBNo
       to->active_comms_down_[from] -= 1;
 
     to->nb_active_comms_down_--;
-    auto it = std::find_if(begin(from->active_comms_up_), end(from->active_comms_up_),
-                           [action](const ActiveComm* comm) { return comm->action == action; });
-    if (it != std::end(from->active_comms_up_)) {
+    if (auto it = std::find_if(begin(from->active_comms_up_), end(from->active_comms_up_),
+                               [action](const ActiveComm* comm) { return comm->action == action; });
+        it != std::end(from->active_comms_up_)) {
       delete *it;
       from->active_comms_up_.erase(it);
     }
@@ -206,6 +203,4 @@ void NetworkIBModel::update_IB_factors(NetworkAction* action, IBNode* from, IBNo
   update_IB_factors_rec(from, updated);
   XBT_DEBUG("IB - Finished updating %d", from->id_);
 }
-} // namespace resource
-} // namespace kernel
-} // namespace simgrid
+} // namespace simgrid::kernel::resource
