@@ -30,7 +30,6 @@ XBT_LOG_NEW_DEFAULT_SUBCATEGORY(surf_kernel, surf, "Logging specific to SURF (ke
 simgrid::kernel::profile::FutureEvtSet future_evt_set;
 std::vector<std::string> surf_path;
 
-/* Don't forget to update the option description in smx_config when you change this */
 const std::vector<surf_model_description_t> surf_network_model_description = {
     {"LV08",
      "Realistic network analytic model (slow-start modeled by multiplying latency by 13.01, bandwidth by .97; "
@@ -166,9 +165,9 @@ void model_help(const char* category, const std::vector<surf_model_description_t
 const surf_model_description_t* find_model_description(const std::vector<surf_model_description_t>& table,
                                                        const std::string& name)
 {
-  auto pos = std::find_if(table.begin(), table.end(),
-                          [&name](const surf_model_description_t& item) { return item.name == name; });
-  if (pos != table.end())
+  if (auto pos = std::find_if(table.begin(), table.end(),
+                              [&name](const surf_model_description_t& item) { return item.name == name; });
+      pos != table.end())
     return &*pos;
 
   std::string sep;
