@@ -8,22 +8,21 @@
 #include <condition_variable>
 #include <mutex>
 
-namespace simgrid {
-namespace xbt {
+namespace simgrid::xbt {
 class XBT_PUBLIC OsSemaphore {
 public:
   explicit inline OsSemaphore(unsigned int capa) : capa_(capa) {}
 
   inline void acquire()
   {
-    std::unique_lock<std::mutex> lock(mutex_);
+    std::unique_lock lock(mutex_);
     condition_.wait(lock, [this]() { return capa_ > 0; });
     --capa_;
   }
 
   inline void release()
   {
-    std::unique_lock<std::mutex> lock(mutex_);
+    std::unique_lock lock(mutex_);
     ++capa_;
     condition_.notify_one();
   }
@@ -33,5 +32,4 @@ private:
   std::mutex mutex_;
   std::condition_variable condition_;
 };
-} // namespace xbt
-} // namespace simgrid
+} // namespace simgrid::xbt
