@@ -10,6 +10,7 @@
 #include "simgrid/config.h"
 #include "simgrid/sg_config.hpp"
 #include "src/internal_config.h"
+#include "src/sthread/sthread.h" // sthread_inside_simgrid
 #include "xbt/config.hpp"
 #include "xbt/coverage.h"
 #include "xbt/dynar.h"
@@ -35,12 +36,11 @@ XBT_LOG_NEW_DEFAULT_SUBCATEGORY(module, xbt, "module handling");
 
 XBT_LOG_NEW_CATEGORY(smpi, "All SMPI categories"); /* lives here even if that's a bit odd to solve linking issues: this is used in xbt_log_file_appender to detect whether SMPI is used (and thus whether we should unbench the writing to disk) */
 
-namespace simgrid {
-namespace xbt {
+namespace simgrid::xbt {
 std::string binary_name;          /* Name of the system process containing us (mandatory to retrieve neat backtraces) */
 std::vector<std::string> cmdline; /* all we got in argv */
-} // namespace xbt
-} // namespace simgrid
+} // namespace simgrid::xbt
+
 
 int xbt_initialized = 0;
 simgrid::config::Flag<bool> cfg_dbg_clean_atexit{
@@ -56,6 +56,12 @@ int xbt_pagebits = 0;
  */
 static void xbt_preinit() XBT_ATTRIB_CONSTRUCTOR(200);
 static void xbt_postexit();
+void sthread_enable()
+{ // These symbols are used from ContextSwapped in any case, but they are only useful
+}
+void sthread_disable()
+{ //  when libsthread is LD_PRELOADED. In this case, sthread's implem gets used instead.
+}
 
 #ifdef _WIN32
 #include <windows.h>
@@ -109,9 +115,6 @@ static void xbt_postexit()
   xbt_initialized--;
   xbt_dict_postexit();
   xbt_log_postexit();
-#if SIMGRID_HAVE_MC
-  mmalloc_postexit();
-#endif
 }
 
 /** @brief Initialize the xbt mechanisms. */
@@ -125,7 +128,8 @@ void xbt_init(int *argc, char **argv)
 
   simgrid::xbt::install_exception_handler();
 
-  simgrid::xbt::binary_name = argv[0];
+  if (*argc > 0)
+    simgrid::xbt::binary_name = argv[0];
   for (int i = 0; i < *argc; i++)
     simgrid::xbt::cmdline.emplace_back(argv[i]);
 
@@ -158,3 +162,10 @@ void xbt_abort()
 #endif
   abort();
 }
+
+#ifndef HAVE_SMPI
+int SMPI_is_inited()
+{
+  return false;
+}
+#endif
