@@ -1,6 +1,6 @@
 /* check_defaults -- simple program displaying its context factory          */
 
-/* Copyright (c) 2013-2021. The SimGrid Team.
+/* Copyright (c) 2013-2022. The SimGrid Team.
  * All rights reserved.                                                     */
 
 /* This program is free software; you can redistribute it and/or modify it
@@ -12,7 +12,7 @@
 int main(int argc, char* argv[])
 {
   xbt_log_control_set("root.fmt:[%c/%p]%e%m%n");
-  xbt_log_control_set("simix_context.threshold:verbose");
+  xbt_log_control_set("ker_context.threshold:verbose");
   XBT_ATTRIB_UNUSED simgrid::s4u::Engine e(&argc, argv);
   return 0;
 }
