@@ -5,16 +5,16 @@
 
 #include "catch_simgrid.hpp"
 
-TEST_CASE("Activity lifecycle: direct communication activities")
+TEST_CASE("Activity lifecycle: direct communication (sendto) activities")
 {
   XBT_INFO("#####[ launch next \"direct-comm\" test ]#####");
 
-  BEGIN_SECTION("dcomm")
+  BEGIN_SECTION("sendto")
   {
-    XBT_INFO("Launch a dcomm(5s), and let it proceed");
+    XBT_INFO("Launch a sendto(5s), and let it proceed");
     bool global = false;
 
-    simgrid::s4u::ActorPtr dcomm5 = simgrid::s4u::Actor::create("dcomm5", all_hosts[1], [&global]() {
+    simgrid::s4u::ActorPtr sendto5 = simgrid::s4u::Actor::create("sendto5", all_hosts[1], [&global]() {
       assert_exit(true, 5.);
       simgrid::s4u::Comm::sendto(all_hosts[1], all_hosts[2], 5000);
       global = true;
@@ -27,74 +27,74 @@ TEST_CASE("Activity lifecycle: direct communication activities")
     END_SECTION;
   }
 
-  BEGIN_SECTION("dcomm actor killed at start")
+  BEGIN_SECTION("sendto actor killed at start")
   {
-    XBT_INFO("Launch a dcomm(5s), and kill it right after start");
-    simgrid::s4u::ActorPtr dcomm5 = simgrid::s4u::Actor::create("dcomm5_killed", all_hosts[1], []() {
+    XBT_INFO("Launch a sendto(5s), and kill it right after start");
+    simgrid::s4u::ActorPtr sendto5 = simgrid::s4u::Actor::create("sendto5_killed", all_hosts[1], []() {
       assert_exit(false, 0);
       simgrid::s4u::Comm::sendto(all_hosts[1], all_hosts[2], 5000);
       FAIL("I should be dead now");
     });
 
     simgrid::s4u::this_actor::yield();
-    dcomm5->kill();
+    sendto5->kill();
 
     END_SECTION;
   }
 
-  BEGIN_SECTION("dcomm actor killed in middle")
+  BEGIN_SECTION("sendto actor killed in middle")
   {
-    XBT_INFO("Launch a dcomm(5s), and kill it after 2 secs");
-    simgrid::s4u::ActorPtr dcomm5 = simgrid::s4u::Actor::create("dcomm5_killed", all_hosts[1], []() {
+    XBT_INFO("Launch a sendto(5s), and kill it after 2 secs");
+    simgrid::s4u::ActorPtr sendto5 = simgrid::s4u::Actor::create("sendto5_killed", all_hosts[1], []() {
       assert_exit(false, 2);
       simgrid::s4u::Comm::sendto(all_hosts[1], all_hosts[2], 5000);
       FAIL("I should be dead now");
     });
 
     simgrid::s4u::this_actor::sleep_for(2);
-    dcomm5->kill();
+    sendto5->kill();
 
     END_SECTION;
   }
 
-  BEGIN_SECTION("dcomm host restarted at start")
+  BEGIN_SECTION("sendto host restarted at start")
   {
-    XBT_INFO("Launch a dcomm(5s), and restart its host right after start");
-    simgrid::s4u::ActorPtr dcomm5 = simgrid::s4u::Actor::create("dcomm5_restarted", all_hosts[1], []() {
+    XBT_INFO("Launch a sendto(5s), and restart its host right after start");
+    simgrid::s4u::ActorPtr sendto5 = simgrid::s4u::Actor::create("sendto5_restarted", all_hosts[1], []() {
       assert_exit(false, 0);
       simgrid::s4u::Comm::sendto(all_hosts[1], all_hosts[2], 5000);
       FAIL("I should be dead now");
     });
 
     simgrid::s4u::this_actor::yield();
-    dcomm5->get_host()->turn_off();
-    dcomm5->get_host()->turn_on();
+    sendto5->get_host()->turn_off();
+    sendto5->get_host()->turn_on();
 
     END_SECTION;
   }
 
-  BEGIN_SECTION("dcomm host restarted in middle")
+  BEGIN_SECTION("sendto host restarted in middle")
   {
-    XBT_INFO("Launch a dcomm(5s), and restart its host after 2 secs");
-    simgrid::s4u::ActorPtr dcomm5 = simgrid::s4u::Actor::create("dcomm5_restarted", all_hosts[1], []() {
+    XBT_INFO("Launch a sendto(5s), and restart its host after 2 secs");
+    simgrid::s4u::ActorPtr sendto5 = simgrid::s4u::Actor::create("sendto5_restarted", all_hosts[1], []() {
       assert_exit(false, 2);
       simgrid::s4u::Comm::sendto(all_hosts[1], all_hosts[2], 5000);
       FAIL("I should be dead now");
     });
 
     simgrid::s4u::this_actor::sleep_for(2);
-    dcomm5->get_host()->turn_off();
-    dcomm5->get_host()->turn_on();
+    sendto5->get_host()->turn_off();
+    sendto5->get_host()->turn_on();
 
     END_SECTION;
   }
 
-  BEGIN_SECTION("dcomm host restarted at end")
+  BEGIN_SECTION("sendto host restarted at end")
   {
-    XBT_INFO("Launch a dcomm(5s), and restart its host right when it stops");
+    XBT_INFO("Launch a sendto(5s), and restart its host right when it stops");
     bool execution_done = false;
 
-    simgrid::s4u::Actor::create("dcomm5_restarted", all_hosts[1], [&execution_done]() {
+    simgrid::s4u::Actor::create("sendto5_restarted", all_hosts[1], [&execution_done]() {
       assert_exit(true, 5);
       simgrid::s4u::Comm::sendto(all_hosts[1], all_hosts[2], 5000);
       execution_done = true;
@@ -114,10 +114,10 @@ TEST_CASE("Activity lifecycle: direct communication activities")
     END_SECTION;
   }
 
-  BEGIN_SECTION("dcomm link restarted at start")
+  BEGIN_SECTION("sendto link restarted at start")
   {
-    XBT_INFO("Launch a dcomm(5s), and restart the used link right after start");
-    simgrid::s4u::ActorPtr dcomm5 = simgrid::s4u::Actor::create("dcomm5_restarted", all_hosts[1], []() {
+    XBT_INFO("Launch a sendto(5s), and restart the used link right after start");
+    simgrid::s4u::ActorPtr sendto5 = simgrid::s4u::Actor::create("sendto5_restarted", all_hosts[1], []() {
       assert_exit(true, 0);
       REQUIRE_NETWORK_FAILURE(simgrid::s4u::Comm::sendto(all_hosts[1], all_hosts[2], 5000));
     });
@@ -130,10 +130,10 @@ TEST_CASE("Activity lifecycle: direct communication activities")
     END_SECTION;
   }
 
-  BEGIN_SECTION("dcomm link restarted in middle")
+  BEGIN_SECTION("sendto link restarted in middle")
   {
-    XBT_INFO("Launch a dcomm(5s), and restart the used link after 2 secs");
-    simgrid::s4u::ActorPtr dcomm5 = simgrid::s4u::Actor::create("dcomm5_restarted", all_hosts[1], []() {
+    XBT_INFO("Launch a sendto(5s), and restart the used link after 2 secs");
+    simgrid::s4u::ActorPtr sendto5 = simgrid::s4u::Actor::create("sendto5_restarted", all_hosts[1], []() {
       assert_exit(true, 2);
       REQUIRE_NETWORK_FAILURE(simgrid::s4u::Comm::sendto(all_hosts[1], all_hosts[2], 5000));
     });
@@ -146,12 +146,12 @@ TEST_CASE("Activity lifecycle: direct communication activities")
     END_SECTION;
   }
 
-  BEGIN_SECTION("dcomm link restarted at end")
+  BEGIN_SECTION("sendto link restarted at end")
   {
-    XBT_INFO("Launch a dcomm(5s), and restart the used link right when it stops");
+    XBT_INFO("Launch a sendto(5s), and restart the used link right when it stops");
     bool execution_done = false;
 
-    simgrid::s4u::Actor::create("dcomm5_restarted", all_hosts[1], [&execution_done]() {
+    simgrid::s4u::Actor::create("sendto5_restarted", all_hosts[1], [&execution_done]() {
       assert_exit(true, 5);
       simgrid::s4u::Comm::sendto(all_hosts[1], all_hosts[2], 5000);
       execution_done = true;
