@@ -10,13 +10,12 @@ XBT_LOG_NEW_DEFAULT_CATEGORY(s4u_test, "Messages specific for this s4u example")
 static void dummy()
 {
   XBT_INFO("I start");
-    simgrid::s4u::this_actor::sleep_for(200);
-    XBT_INFO("I stop");
+  simgrid::s4u::this_actor::sleep_for(200);
+  XBT_INFO("I stop");
 }
 
 static void dummy_daemon()
 {
-  simgrid::s4u::Actor::self()->daemonize();
   while (simgrid::s4u::this_actor::get_host()->is_on()) {
     XBT_INFO("Hello from the infinite loop");
     simgrid::s4u::this_actor::sleep_for(80.0);
@@ -29,14 +28,14 @@ static void autostart()
 
   XBT_INFO("starting a dummy process on %s", host->get_cname());
   simgrid::s4u::ActorPtr dummy_actor = simgrid::s4u::Actor::create("Dummy", host, dummy);
-  dummy_actor->on_exit([](bool) { XBT_INFO("On_exit callback set before autorestart"); });
+  dummy_actor->on_exit([](bool failed) { XBT_INFO("Dummy actor %s.", failed ? "failed" : "terminating"); });
   dummy_actor->set_auto_restart(true);
   dummy_actor->on_exit([](bool) { XBT_INFO("On_exit callback set after autorestart"); });
 
   XBT_INFO("starting a daemon process on %s", host->get_cname());
   simgrid::s4u::ActorPtr daemon_actor = simgrid::s4u::Actor::create("Daemon", host, dummy_daemon);
-  daemon_actor->on_exit([](bool) { XBT_INFO("On_exit callback set before autorestart"); });
-  daemon_actor->set_auto_restart(true);
+  daemon_actor->on_exit([](bool failed) { XBT_INFO("Daemon actor %s.", failed ? "failed" : "terminating"); });
+  daemon_actor->daemonize()->set_auto_restart(true);
   daemon_actor->on_exit([](bool) { XBT_INFO("On_exit callback set after autorestart"); });
 
   simgrid::s4u::this_actor::sleep_for(50);
