@@ -17,8 +17,8 @@ static void display_disk_properties(const simgrid::s4u::Disk* disk)
   if (not props->empty()) {
     XBT_INFO("  Properties of disk: %s", disk->get_cname());
 
-    for (auto const& elm : *props) {
-      XBT_INFO("    %s->%s", elm.first.c_str(), elm.second.c_str());
+    for (auto const& [key, value] : *props) {
+      XBT_INFO("    %s->%s", key.c_str(), value.c_str());
     }
   } else {
     XBT_INFO("  No property attached.");
@@ -27,19 +27,21 @@ static void display_disk_properties(const simgrid::s4u::Disk* disk)
 
 static sg_size_t write_local_file(const std::string& dest, sg_size_t file_size)
 {
-  simgrid::s4u::File file(dest, nullptr);
-  sg_size_t written = file.write(file_size);
+  auto* file        = simgrid::s4u::File::open(dest, nullptr);
+  sg_size_t written = file->write(file_size);
   XBT_INFO("%llu bytes on %llu bytes have been written by %s on /sd1", written, file_size,
            simgrid::s4u::Actor::self()->get_cname());
+  file->close();
   return written;
 }
 
 static sg_size_t read_local_file(const std::string& src)
 {
-  simgrid::s4u::File file(src, nullptr);
-  sg_size_t file_size = file.size();
-  sg_size_t read      = file.read(file_size);
+  auto* file          = simgrid::s4u::File::open(src, nullptr);
+  sg_size_t file_size = file->size();
+  sg_size_t read      = file->read(file_size);
   XBT_INFO("%s has read %llu on %s", simgrid::s4u::Actor::self()->get_cname(), read, src.c_str());
+  file->close();
   return read;
 }
 
@@ -63,8 +65,8 @@ static void display_disk_content(const simgrid::s4u::Disk* disk)
   XBT_INFO("Print the content of the disk: %s", disk->get_cname());
   const auto* content = disk->extension<simgrid::s4u::FileSystemDiskExt>()->get_content();
   if (not content->empty()) {
-    for (auto const& entry : *content)
-      XBT_INFO("  %s size: %llu bytes", entry.first.c_str(), entry.second);
+    for (auto const& [name, size] : *content)
+      XBT_INFO("  %s size: %llu bytes", name.c_str(), size);
   } else {
     XBT_INFO("  No content.");
   }
