@@ -22,12 +22,6 @@ echo "XXXX Let's go"
 
 set -e
 
-# Help older cmakes
-if [ -e /usr/lib/jvm/java-7-openjdk-amd64 ] ;
-then
-  export JAVA_HOME=/usr/lib/jvm/java-7-openjdk-amd64
-fi
-
 # usage: die status message...
 die () {
   status=${1:-1}
@@ -146,18 +140,23 @@ mkdir "$WORKSPACE"/build
 cd "$WORKSPACE"/build
 
 have_NS3="no"
-if [ "$os" = "Debian" ] || [ "$os" = "Ubuntu" ] ; then
+if [ "$os" = "Debian" ] ; then
   if dpkg --compare-versions "$(dpkg-query -f '${Version}' -W libns3-dev)" ge 3.28; then
     have_NS3="yes"
   fi
 fi
-if [ "$os" = "NixOS" ] ; then
+MAY_HINT_AT_NS3=""
+if [ $NODE_NAME = "ubuntu-lts" ] ; then
+  MAY_HINT_AT_NS3="-DNS3_HINT=/builds/ns-3-dev/build/"
+  have_NS3="yes"
+fi
+if [ "$os" = "nixos" ] ; then
   have_NS3="yes"
 fi
 echo "XX have_NS3: ${have_NS3}"
 
 SIMGRID_PYTHON_LIBDIR=""
-if [ "$os" = "NixOS" ] ; then
+if [ "$os" = "nixos" ] ; then
   SIMGRID_PYTHON_LIBDIR="/home/ci/simgrid_install/lib64"
 fi
 echo "XX SIMGRID_PYTHON_LIBDIR: ${SIMGRID_PYTHON_LIBDIR}"
@@ -197,17 +196,24 @@ else
   MAY_DISABLE_SOURCE_CHANGE="-DCMAKE_DISABLE_SOURCE_CHANGES=ON"
 fi
 
-if [ "$os" = "CentOS" ] && [ "$(ld -v | cut -d\  -f4 | cut -c1-4)" = "2.30" ]; then
-  echo "Temporary disable LTO, believed to be broken on this system."
-  MAY_DISABLE_LTO=-Denable_lto=OFF
-else
-  MAY_DISABLE_LTO=
+if [ "$os" = "CentOS" ]; then
+    if [ "$(ld -v | cut -d\  -f4 | cut -c1-4)" = "2.30" ]; then
+        echo "Temporary disable LTO, believed to be broken on this system."
+        MAY_DISABLE_LTO=-Denable_lto=OFF
+    else
+        MAY_DISABLE_LTO=
+    fi
+fi
+
+if [ $NODE_NAME = "armv8" ]; then
+    echo "disable LTO, believed to be too heavy for this particular system"
+    MAY_DISABLE_LTO=-Denable_lto=OFF
 fi
 
 cmake -G"$GENERATOR" ${INSTALL:+-DCMAKE_INSTALL_PREFIX=$INSTALL} \
   -Denable_debug=ON -Denable_documentation=OFF -Denable_coverage=OFF \
   -Denable_model-checking=$(onoff test "$build_mode" = "ModelChecker") \
-  -Denable_smpi_ISP_testsuite=$(onoff test "$build_mode" = "ModelChecker") \
+  -Denable_smpi_MBI_testsuite=OFF \
   -Denable_compile_optimizations=$(onoff test "$build_mode" != "DynamicAnalysis") \
   -Denable_smpi_MPICH3_testsuite=$(onoff test "$build_mode" = "Debug") \
   -Denable_mallocators=$(onoff test "$build_mode" != "DynamicAnalysis") \
@@ -215,10 +221,11 @@ cmake -G"$GENERATOR" ${INSTALL:+-DCMAKE_INSTALL_PREFIX=$INSTALL} \
   -Denable_compile_warnings=$(onoff test "$GENERATOR" != "MSYS Makefiles") -Denable_smpi=ON \
   -Denable_ns3=$(onoff test "$have_NS3" = "yes" -a "$build_mode" = "Debug") \
   -DSIMGRID_PYTHON_LIBDIR=${SIMGRID_PYTHON_LIBDIR} \
-  ${MAY_DISABLE_SOURCE_CHANGE} ${MAY_DISABLE_LTO} \
+  ${MAY_DISABLE_SOURCE_CHANGE} ${MAY_DISABLE_LTO} ${MAY_HINT_AT_NS3} \
   -Denable_java=$(onoff test "$build_mode" = "ModelChecker") \
   -Denable_msg=$(onoff test "$build_mode" = "ModelChecker") \
   -DLTO_EXTRA_FLAG="auto" \
+  -DCMAKE_CXX_COMPILER_LAUNCHER=ccache \
   "$SRCFOLDER"
 set +x
 
